@@ -41,6 +41,7 @@ $Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 #include "../version/version.h"
 #include "../processeventblocker.h"
 #include "../connectors/connectoritem.h"
+#include "../connectors/svgidlayer.h"
 
 #include "cmrouter/tileutils.h"
 
@@ -54,6 +55,8 @@ $Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 
 static int OutlineLayer = 0;
 static int SilkTopLayer = 0;
+static QString PanelizerOutputPath;
+static QSet<QString> PanelizerFileNames;
 
 ///////////////////////////////////////////////////////////
 
@@ -226,6 +229,9 @@ PanelItem::PanelItem(PanelItem * from) {
 
 void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool customPartsOnly) 
 {
+    QString msg = "panelize";
+    if (customPartsOnly) msg += " custom parts";
+    initPanelizerOutput(panelFilename, msg);
 
 	QFile panelizerFile(panelFilename);
 
@@ -233,7 +239,7 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
     QDir copyDir = info.absoluteDir();
     copyDir.cd("copies");
     if (!copyDir.exists()) {
-		DebugDialog::debug(QString("unable to create 'copies' folder in '%1'").arg(info.absoluteDir().absolutePath()));
+		writePanelizerOutput(QString("unable to create 'copies' folder in '%1'").arg(info.absoluteDir().absolutePath()));
 		return;
 	}
 
@@ -246,13 +252,13 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 
 	QDomDocument panelizerDocument;
 	if (!panelizerDocument.setContent(&panelizerFile, true, &errorStr, &errorLine, &errorColumn)) {
-		DebugDialog::debug(QString("Unable to parse '%1': '%2' line:%3 column:%4").arg(panelFilename).arg(errorStr).arg(errorLine).arg(errorColumn));
+		writePanelizerOutput(QString("Unable to parse '%1': '%2' line:%3 column:%4").arg(panelFilename).arg(errorStr).arg(errorLine).arg(errorColumn));
 		return;
 	}
 
 	QDomElement panelizerRoot = panelizerDocument.documentElement();
 	if (panelizerRoot.isNull() || panelizerRoot.tagName() != "panelizer") {
-		DebugDialog::debug(QString("root element is not 'panelizer'"));
+		writePanelizerOutput(QString("root element is not 'panelizer'"));
 		return;
 	}
 
@@ -274,7 +280,7 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 	QDir svgDir(outputDir);
 	svgDir.cd("svg");
 	if (!svgDir.exists()) {
-		DebugDialog::debug(QString("unable to create svg folder in '%1'").arg(pinfo.absolutePath()));
+		writePanelizerOutput(QString("unable to create svg folder in '%1'").arg(pinfo.absolutePath()));
 		return;
 	}
 
@@ -283,7 +289,7 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 	QDir gerberDir(outputDir);
 	gerberDir.cd("gerber");
 	if (!gerberDir.exists()) {
-		DebugDialog::debug(QString("unable to create gerber folder in '%1'").arg(pinfo.absolutePath()));
+		writePanelizerOutput(QString("unable to create gerber folder in '%1'").arg(pinfo.absolutePath()));
 		return;
 	}
 
@@ -292,7 +298,7 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 	QDir fzDir(outputDir);
 	fzDir.cd("fz");
 	if (!fzDir.exists()) {
-		DebugDialog::debug(QString("unable to create fz folder in '%1'").arg(pinfo.absolutePath()));
+		writePanelizerOutput(QString("unable to create fz folder in '%1'").arg(pinfo.absolutePath()));
 		return;
 	}
 
@@ -302,7 +308,7 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 	QDomElement boards = panelizerRoot.firstChildElement("boards");
 	QDomElement board = boards.firstChildElement("board");
 	if (board.isNull()) {
-		DebugDialog::debug(QString("no <board> elements found"));
+		writePanelizerOutput(QString("no <board> elements found"));
 		return;
 	}
 
@@ -310,13 +316,13 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 	QDomElement paths = panelizerRoot.firstChildElement("paths");
 	QDomElement path = paths.firstChildElement("path");
 	if (path.isNull()) {
-		DebugDialog::debug(QString("no <path> elements found"));
+		writePanelizerOutput(QString("no <path> elements found"));
 		return;
 	}
 
 	collectFiles(pinfo.absoluteDir(), path, fzzFilePaths);
     if (fzzFilePaths.count() == 0) {
-		DebugDialog::debug(QString("no fzz files found in paths"));
+		writePanelizerOutput(QString("no fzz files found in paths"));
 		return;
 	}
 	
@@ -430,6 +436,20 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 
 		TextUtils::mergeSvg(doc, merger, "");
 		merger = TextUtils::mergeSvgFinish(doc);
+
+        int endix = merger.lastIndexOf("</svg>");
+        QString text = "<text x='%1' y='%2' text-anchor='end' fill='#000000' stroke='none' stroke-width='0' font-size='250' font-family='OCRA'>%3 panel %4  %5 %6</text>\n";
+        text = text
+                .arg(planePair->panelWidth * GraphicsUtils::StandardFritzingDPI)
+                .arg(planePair->panelHeight * GraphicsUtils::StandardFritzingDPI + (250 / 2))
+                .arg(outputDir.dirName())
+                .arg(planePair->index)
+                .arg(panelParams.prefix)
+                .arg(QTime::currentTime().toString())
+                ;
+
+        merger.insert(endix, text);
+
 		QString fname = svgDir.absoluteFilePath(QString("%1.%2.svg").arg(prefix).arg("identification"));
 		TextUtils::writeUtf8(fname, merger);
 
@@ -475,12 +495,10 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 
     TextUtils::writeUtf8(panelFilename, panelizerDocument.toString(4));
 
-    DebugDialog::debug("");
-    DebugDialog::debug(QString("Panelizer finished: %1 panel(s), with %2 additional copy(ies) for each panel").arg(planePairs.count()).arg(duplicates - 1));
-    QMessageBox::information(NULL, QObject::tr("Fritzing"), 
-        QObject::tr("Panelizer finished: %1 panel(s), with %2 additional copy(ies) for each panel").arg(planePairs.count()).arg(duplicates - 1)
-    );
-
+    QString message = QString("Panelizer finished: %1 panel(s), with %2 additional copy(ies) for each panel").arg(planePairs.count()).arg(duplicates - 1);
+    writePanelizerOutput("--------------------------------");
+    writePanelizerOutput(message);
+    QMessageBox::information(NULL, QObject::tr("Fritzing"), message);
 }
 
 
@@ -745,32 +763,32 @@ bool Panelizer::checkBoards(QDomElement & board, QHash<QString, QString> & fzzFi
 		bool ok;
 		int optional = board.attribute("maxOptionalCount", "").toInt(&ok);
 		if (!ok) {
-			DebugDialog::debug(QString("maxOptionalCount for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("maxOptionalCount")));
+			writePanelizerOutput(QString("maxOptionalCount for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("maxOptionalCount")));
 			return false;
 		}
 
 		int optionalPriority = board.attribute("optionalPriority", "").toInt(&ok);
         Q_UNUSED(optionalPriority);
 		if (!ok) {
-			DebugDialog::debug(QString("optionalPriority for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("optionalPriority")));
+			writePanelizerOutput(QString("optionalPriority for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("optionalPriority")));
 			return false;
 		}
 
 		int required = board.attribute("requiredCount", "").toInt(&ok);
 		if (!ok) {
-			DebugDialog::debug(QString("required for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("maxOptionalCount")));
+			writePanelizerOutput(QString("required for board '%1' not an integer: '%2'").arg(boardname).arg(board.attribute("maxOptionalCount")));
 			return false;
 		}
 
         if (optional > 0 || required> 0) {
 		    QString path = fzzFilePaths.value(boardname, "");
 		    if (path.isEmpty()) {
-			    DebugDialog::debug(QString("File for board '%1' not found in search paths").arg(boardname));
+			    writePanelizerOutput(QString("File for board '%1' not found in search paths").arg(boardname));
 			    return false;
 		    }
         }
         else {
-            DebugDialog::debug(QString("skipping board '%1'").arg(boardname));
+            writePanelizerOutput(QString("skipping board '%1'").arg(boardname));
         }
 
 		board = board.nextSiblingElement("board");
@@ -800,7 +818,7 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
     }
 
     if (bigPanelType == NULL) {
-        DebugDialog::debug("No panel types defined");
+        writePanelizerOutput("No panel types defined");
         return false;
     }
 
@@ -824,17 +842,17 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
         QFileInfo copyInfo(copyPath);
 
         if (!copyInfo.exists()) {
-            DebugDialog::debug(QString("failed to load copy'%1'").arg(copyPath));
+            writePanelizerOutput(QString("failed to load copy'%1'").arg(copyPath));
             return false;
         }
 
         if (!originalInfo.exists()) {
-            DebugDialog::debug(QString("failed to find original'%1'").arg(originalPath));
+            writePanelizerOutput(QString("failed to find original'%1'").arg(originalPath));
             return false;
         }
 
         if (originalInfo.lastModified() > copyInfo.lastModified()) {
-            DebugDialog::debug(QString("copy %1 is not up to date--rerun the inscriber").arg(copyPath));
+            writePanelizerOutput(QString("copy %1 is not up to date--rerun the inscriber").arg(copyPath));
             return false;
         }
 
@@ -843,8 +861,8 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
 
 		FolderUtils::setOpenSaveFolderAux(fzDir.absolutePath());
 
-		if (!mainWindow->loadWhich(copyPath, false, false, "")) {
-			DebugDialog::debug(QString("failed to load '%1'").arg(copyPath));
+		if (!mainWindow->loadWhich(copyPath, false, false, false, "")) {
+			writePanelizerOutput(QString("failed to load '%1'").arg(copyPath));
 			return false;
 		}
 
@@ -924,11 +942,10 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
 		    }
 
 		    if (tooBig) {
-			    DebugDialog::debug(QString("board is too big for panel '%1'").arg(originalPath));
+			    writePanelizerOutput(QString("board is too big for panel '%1'").arg(originalPath));
 			    return false;
 		    }
 
-
             makeSVGs(mainWindow, boardItem, boardName, layerThingList, norotateDir, copyInfo);
 
 		    refPanelItems << panelItem;
@@ -956,7 +973,7 @@ bool Panelizer::initPanelParams(QDomElement & root, PanelParams & panelParams)
 {
 	panelParams.prefix = root.attribute("prefix");
 	if (panelParams.prefix.isEmpty()) {
-		DebugDialog::debug(QString("Output file prefix not specified"));
+		writePanelizerOutput(QString("Output file prefix not specified"));
 		return false;
 	}
 
@@ -970,25 +987,25 @@ bool Panelizer::initPanelParams(QDomElement & root, PanelParams & panelParams)
         bool ok;
 	    panelType->width = TextUtils::convertToInches(panel.attribute("width"), &ok, false);
 	    if (!ok) {
-		    DebugDialog::debug(QString("Can't parse panel width '%1'").arg(panel.attribute("width")));
+		    writePanelizerOutput(QString("Can't parse panel width '%1'").arg(panel.attribute("width")));
 		    return false;
 	    }
 
 	    panelType->height = TextUtils::convertToInches(panel.attribute("height"), &ok, false);
 	    if (!ok) {
-		    DebugDialog::debug(QString("Can't parse panel height '%1'").arg(panel.attribute("height")));
+		    writePanelizerOutput(QString("Can't parse panel height '%1'").arg(panel.attribute("height")));
 		    return false;
 	    }
 
 	    panelType->c1 = panel.attribute("c1").toDouble(&ok);
 	    if (!ok) {
-		    DebugDialog::debug(QString("Can't parse panel c1 '%1'").arg(panel.attribute("c1")));
+		    writePanelizerOutput(QString("Can't parse panel c1 '%1'").arg(panel.attribute("c1")));
 		    return false;
 	    }
 
 	    panelType->c2 = panel.attribute("c2").toDouble(&ok);
 	    if (!ok) {
-		    DebugDialog::debug(QString("Can't parse panel c2 '%1'").arg(panel.attribute("c2")));
+		    writePanelizerOutput(QString("Can't parse panel c2 '%1'").arg(panel.attribute("c2")));
 		    return false;
 	    }
 
@@ -998,20 +1015,20 @@ bool Panelizer::initPanelParams(QDomElement & root, PanelParams & panelParams)
     }
 
     if (panelParams.panelTypes.count() == 0) {
-		DebugDialog::debug(QString("No panel types defined."));
+		writePanelizerOutput(QString("No panel types defined."));
 		return false;
     }
 
     bool ok;
 	panelParams.panelSpacing = TextUtils::convertToInches(root.attribute("spacing"), &ok, false);
 	if (!ok) {
-		DebugDialog::debug(QString("Can't parse panel spacing '%1'").arg(root.attribute("spacing")));
+		writePanelizerOutput(QString("Can't parse panel spacing '%1'").arg(root.attribute("spacing")));
 		return false;
 	}
 
 	panelParams.panelBorder = TextUtils::convertToInches(root.attribute("border"), &ok, false);
 	if (!ok) {
-		DebugDialog::debug(QString("Can't parse panel border '%1'").arg(root.attribute("border")));
+		writePanelizerOutput(QString("Can't parse panel border '%1'").arg(root.attribute("border")));
 		return false;
 	}
 
@@ -1240,8 +1257,10 @@ void Panelizer::addOptional(int optionalCount, QList<PanelItem *> & refPanelItem
 
 /////////////////////////////////////////////////////////////////////////////////
 
-void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool drc) 
+void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool drc, bool noMessages) 
 {
+    initPanelizerOutput(panelFilename, "inscribe");
+
 	QFile file(panelFilename);
 
     QFileInfo info(panelFilename);
@@ -1261,13 +1280,13 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 
 	QDomDocument domDocument;
 	if (!domDocument.setContent(&file, true, &errorStr, &errorLine, &errorColumn)) {
-		DebugDialog::debug(QString("Unable to parse '%1': '%2' line:%3 column:%4").arg(panelFilename).arg(errorStr).arg(errorLine).arg(errorColumn));
+        writePanelizerOutput(QString("Unable to parse '%1': '%2' line:%3 column:%4").arg(panelFilename).arg(errorStr).arg(errorLine).arg(errorColumn));
 		return;
 	}
 
 	QDomElement root = domDocument.documentElement();
 	if (root.isNull() || root.tagName() != "panelizer") {
-		DebugDialog::debug(QString("root element is not 'panelizer'"));
+		writePanelizerOutput(QString("root element is not 'panelizer'"));
 		return;
 	}
 
@@ -1278,7 +1297,7 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 	QDir fzDir(outputDir);
 	fzDir.cd("fz");
 	if (!fzDir.exists()) {
-		DebugDialog::debug(QString("unable to create fz folder in '%1'").arg(outputDir.absolutePath()));
+		writePanelizerOutput(QString("unable to create fz folder in '%1'").arg(outputDir.absolutePath()));
 		return;
 	}
 
@@ -1287,7 +1306,7 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 	QDomElement boards = root.firstChildElement("boards");
 	QDomElement board = boards.firstChildElement("board");
 	if (board.isNull()) {
-		DebugDialog::debug(QString("no <board> elements found"));
+		writePanelizerOutput(QString("no <board> elements found"));
 		return;
 	}
 
@@ -1295,14 +1314,14 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 	QDomElement paths = root.firstChildElement("paths");
 	QDomElement path = paths.firstChildElement("path");
 	if (path.isNull()) {
-		DebugDialog::debug(QString("no <path> elements found"));
+		writePanelizerOutput(QString("no <path> elements found"));
 		return;
 	}
 
     QFileInfo pinfo(panelFilename);
 	collectFiles(pinfo.absoluteDir(), path, fzzFilePaths);
 	if (fzzFilePaths.count() == 0) {
-		DebugDialog::debug(QString("no fzz files found in paths"));
+		writePanelizerOutput(QString("no fzz files found in paths"));
 		return;
 	}
 	
@@ -1315,7 +1334,7 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 
 	board = boards.firstChildElement("board");
 	while (!board.isNull()) {
-		MainWindow * mainWindow = inscribeBoard(board, fzzFilePaths, app, fzDir, drc, copyDir);
+		MainWindow * mainWindow = inscribeBoard(board, fzzFilePaths, app, fzDir, drc, noMessages, copyDir);
 		if (mainWindow) {
 			mainWindow->setCloseSilently(true);
 			mainWindow->close();
@@ -1324,11 +1343,13 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 		board = board.nextSiblingElement("board");
 	}
 
+    writePanelizerFilenames(panelFilename);
+
 	// TODO: delete temp fz folder
 
 }
 
-MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QString> & fzzFilePaths, FApplication * app, QDir & fzDir, bool drc, QDir & copyDir)
+MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QString> & fzzFilePaths, FApplication * app, QDir & fzDir, bool drc, bool noMessages, QDir & copyDir)
 {
 	QString boardName = board.attribute("name");
 	int optional = board.attribute("maxOptionalCount", "").toInt();
@@ -1355,8 +1376,7 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
     }
 
     QFile file(originalPath);
-    QFile::remove(copyPath);
-    bool ok = file.copy(copyPath);
+    bool ok = FolderUtils::slamCopy(file, copyPath);
     if (!ok) {
         QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("unable to copy file '%1' to '%2'.").arg(originalPath).arg(copyPath));
         return NULL;
@@ -1366,17 +1386,28 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
 
 	FolderUtils::setOpenSaveFolderAux(fzDir.absolutePath());
 
-	if (!mainWindow->loadWhich(copyPath, false, false, "")) {
-		DebugDialog::debug(QString("failed to load '%1'").arg(copyPath));
+	if (!mainWindow->loadWhich(copyPath, false, false, false, "")) {
+		writePanelizerOutput(QString("failed to load '%1'").arg(copyPath));
 		return mainWindow;
 	}
 
 	mainWindow->showPCBView();
 
+    QList<ItemBase *> items = mainWindow->pcbView()->selectAllObsolete();
+	if (items.count() > 0) {
+        QFileInfo info(copyPath);
+        writePanelizerOutput(QString("%2 ... %1 obsolete items").arg(items.count()).arg(info.fileName()));
+    }
+
     int moved = mainWindow->pcbView()->checkLoadedTraces();
     if (moved > 0) {
-        QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("%1 wires moved from their saved position in %2.").arg(moved).arg(originalPath));
-        DebugDialog::debug(QString("\ncheckloadedtraces %1\n").arg(originalPath)); 
+        QFileInfo info(originalPath);
+        QString message = QObject::tr("%2 ... %1 wires moved from their saved position").arg(moved).arg(info.fileName());
+        if (!noMessages) {
+            QMessageBox::warning(NULL, QObject::tr("Fritzing"), message);
+        }
+        writePanelizerOutput(message); 
+        collectFilenames(info.fileName());
     }
 
 	foreach (QGraphicsItem * item, mainWindow->pcbView()->scene()->items()) {
@@ -1431,14 +1462,23 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
 		DebugDialog::debug(QString("%1 filled:%2").arg(copyPath).arg(filled));
 	}
 
-    checkDonuts(mainWindow, true);
-    checkText(mainWindow, true);
+    checkDonuts(mainWindow, !noMessages);
+    checkText(mainWindow, !noMessages);
+    checkCopperBoth(mainWindow, !noMessages);
 
     if (drc) {
 	    foreach (ItemBase * boardItem, boards) {
             mainWindow->pcbView()->selectAllItems(false, false);
             boardItem->setSelected(true);
-            mainWindow->newDesignRulesCheck(false);
+            QStringList messages = mainWindow->newDesignRulesCheck(false);
+            if (messages.count() > 0) {
+                QFileInfo info(mainWindow->fileName());
+                writePanelizerOutput(QString("%2 ... %1 drc complaints").arg(messages.count()).arg(info.fileName()));
+                collectFilenames(info.fileName());
+                //foreach (QString message, messages) {
+                //    writePanelizerOutput("\t" + message);
+                //}
+            }
         }
     }
 
@@ -1701,6 +1741,14 @@ int Panelizer::checkText(MainWindow * mainWindow, bool displayMessage) {
         QMessageBox::warning(NULL, "Text", QString("There are %1 possible instances of parts with <path> elements missing stroke/fill/stroke-width attributes").arg(missing.count()));
     }
 
+    if (missing.count() > 0) {
+        QFileInfo info(mainWindow->fileName());
+        writePanelizerOutput(QString("%2 ... There are %1 possible instances of parts with <path> elements missing stroke/fill/stroke-width attributes")
+                .arg(missing.count()).arg(info.fileName())
+            );
+        collectFilenames(info.fileName());
+    }
+
     return  missing.count();
 }
 
@@ -1726,12 +1774,129 @@ int Panelizer::checkDonuts(MainWindow * mainWindow, bool displayMessage) {
         }
         mainWindow->pcbView()->selectItems(itemBases.toList());
         QMessageBox::warning(NULL, "Donuts", QString("There are %1 possible donut connectors").arg(donuts.count() / 2));
-        DebugDialog::debug(QString("possible donuts in %1").arg(mainWindow->fileName()));
+    }
+
+    if (donuts.count() > 0) {
+        QFileInfo info(mainWindow->fileName());
+        writePanelizerOutput(QString("%2 ... %1 possible donuts").arg(donuts.count() / 2).arg(info.fileName()));
+        collectFilenames(mainWindow->fileName());
     }
 
     return donuts.count() / 2;
 }
 
+int Panelizer::checkCopperBoth(MainWindow * mainWindow, bool displayMessage) {
+    QList<ItemBase *> missing;
+
+    QList<ItemBase *> visited;
+    foreach (QGraphicsItem * item, mainWindow->pcbView()->scene()->items()) {
+        ItemBase * itemBase = dynamic_cast<ItemBase *>(item);
+        if (itemBase == NULL) continue;
+        if (!itemBase->isEverVisible()) continue;
+        if (itemBase->modelPart()->isCore()) continue;
+
+        itemBase = itemBase->layerKinChief();
+        if (visited.contains(itemBase)) continue;
+
+        visited << itemBase;
+
+        QString fzpPath = itemBase->modelPart()->path();
+        QFile file(fzpPath);
+        if (!file.open(QFile::ReadOnly)) {
+            DebugDialog::debug(QString("unable to open %1").arg(fzpPath));
+            continue;
+        }
+
+        QString fzp = file.readAll();
+        file.close();
+
+        bool copper0 = fzp.contains("copper0");
+        bool copper1 = fzp.contains("copper1");
+        if (!copper1 && !copper0) continue;
+
+        QString svgPath = itemBase->fsvgRenderer()->filename();
+        QFile file2(svgPath);
+        if (!file2.open(QFile::ReadOnly)) {
+            DebugDialog::debug(QString("itembase svg file open failure %1").arg(itemBase->id()));
+            continue;
+        }
+
+        QString svg = file2.readAll();
+        file2.close();
+
+        if (copper1 && !svg.contains("copper1")) {
+            missing << itemBase;
+            continue;
+        }
+
+        if (copper0 && !svg.contains("copper0")) {
+            missing << itemBase;
+            continue;
+        }
+
+        QDomDocument doc;
+        QString errorStr;
+	    int errorLine;
+	    int errorColumn;
+	    if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
+            DebugDialog::debug(QString("itembase svg xml failure %1 %2 %3 %4").arg(itemBase->id()).arg(errorStr).arg(errorLine).arg(errorColumn));
+            continue;
+        }
+
+        QDomElement root = doc.documentElement();
+    
+        if (copper1) {
+            if (!gotCopper("copper1", ViewLayer::Copper1, itemBase, root)) {
+                missing << itemBase;
+                continue;
+            }
+        }
+
+        if (copper0) {
+            if (!gotCopper("copper0", ViewLayer::Copper0, itemBase, root)) {
+                missing << itemBase;
+                continue;
+            }
+        }
+    }
+
+    if (displayMessage && missing.count() > 0) {
+        mainWindow->pcbView()->selectAllItems(false, false);
+        mainWindow->pcbView()->selectItems(missing);
+        QMessageBox::warning(NULL, "Text", QString("There are %1 possible instances of part svgs missing a copper id").arg(missing.count()));
+    }
+
+    if (missing.count() > 0) {
+        QFileInfo info(mainWindow->fileName());
+        writePanelizerOutput(QString("%2 ... There are %1 possible instances of part svgs missing a copper id")
+                .arg(missing.count()).arg(info.fileName())
+            );
+        collectFilenames(info.fileName());
+    }
+
+    return  missing.count();
+}
+
+bool Panelizer::gotCopper(const QString & layerName, ViewLayer::ViewLayerID viewLayerID, ItemBase * itemBase, const QDomElement & root) 
+{
+    QDomElement copperElement = TextUtils::findElementWithAttribute(root, "id", layerName);
+    
+    foreach (ConnectorItem * connectorItem, itemBase->cachedConnectorItems()) {
+        SvgIdLayer * svgIdLayer = connectorItem->connector()->fullPinInfo(itemBase->viewID(), viewLayerID);
+        if (svgIdLayer == NULL) {
+            DebugDialog::debug(QString("missing pin info for %1").arg(itemBase->id()));
+            return false;
+        }
+
+        QDomElement element = TextUtils::findElementWithAttribute(copperElement, "id", svgIdLayer->m_svgId);
+        if (element.isNull()) {
+            return false;
+        }
+    }
+
+    return true;
+}
+
 int Panelizer::bestFitLoop(QList<PanelItem *> & refPanelItems, PanelParams & panelParams, bool customPartsOnly, QList<PlanePair *> & returnPlanePairs, QList<PanelItem *> & returnInsertPanelItems, const QDir & svgDir) 
 {
 	int optionalCount = 0;
@@ -1833,3 +1998,51 @@ double Panelizer::calcCost(PanelParams & panelParams, QList<PlanePair *> & plane
 
     return total;
 }
+
+void Panelizer::writePanelizerOutput(const QString & message) {
+    DebugDialog::debug(message);
+    if (PanelizerOutputPath.length() > 0) {
+        QFile file(PanelizerOutputPath);
+        if (file.open(QFile::Append)) {
+		    QTextStream out(&file);
+		    out.setCodec("UTF-8");
+		    out << message << "\n";
+		    file.close();
+        }
+    }
+}
+
+void Panelizer::initPanelizerOutput(const QString & panelFilename, const QString & msg) {
+    PanelizerFileNames.clear();
+    QFileInfo info(panelFilename);
+    PanelizerOutputPath = info.absoluteDir().absoluteFilePath("panelizer_output.txt");
+
+    QDateTime dt = QDateTime::currentDateTime();
+    writePanelizerOutput(QString("\n--------- %1 --- %2 ---")
+                            .arg(msg).arg(dt.toString())
+                        );
+}
+
+void Panelizer::collectFilenames(const QString & filename) {
+    if (filename.endsWith(".fz")) {
+        PanelizerFileNames.insert(filename + "z");
+    }
+    else PanelizerFileNames.insert(filename);
+}
+
+void Panelizer::writePanelizerFilenames(const QString & panelFilename) {
+    if (PanelizerFileNames.count() == 0) return;
+
+    QFileInfo info(panelFilename);
+    QDateTime dt = QDateTime::currentDateTime();
+    QString path = info.absoluteDir().absoluteFilePath("panelizer_files_%1.txt").arg(dt.toString().replace(":", "."));
+    QFile file(path);
+    if (file.open(QFile::WriteOnly)) {
+        QTextStream out(&file);
+		out.setCodec("UTF-8");
+        foreach (QString name, PanelizerFileNames) {
+            out << name << "\n";
+        }
+        file.close();
+    }
+}
