@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6138 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-04 14:08:48 +0200 (Wed, 04 Jul 2012) $
+$Revision: 6954 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-05 10:22:00 +0200 (Fr, 05. Apr 2013) $
 
 ********************************************************************/
 
@@ -34,9 +34,10 @@ $Date: 2012-07-04 14:08:48 +0200 (Wed, 04 Jul 2012) $
 #include "ercdata.h"
 
 QHash <Connector::ConnectorType, QString > Connector::Names;
+static const QList<SvgIdLayer *> EmptySvgIdLayerList;
 
-static inline int QuickHash(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
-	return (1000 * viewIdentifier) + viewLayerID;
+static inline int QuickHash(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
+	return (1000 * viewID) + viewLayerID;
 }
 
 Connector::Connector( ConnectorShared * connectorShared, ModelPart * modelPart)
@@ -79,7 +80,7 @@ const QString & Connector::connectorNameFromType(ConnectorType type) {
 	return Names[type];
 }
 
-Connector::ConnectorType Connector::connectorType() {
+Connector::ConnectorType Connector::connectorType() const {
 	if (m_connectorShared != NULL) {
 		return m_connectorShared->connectorType();
 	}
@@ -93,12 +94,12 @@ ConnectorShared * Connector::connectorShared() {
 
 void Connector::addViewItem(ConnectorItem * item) {
 	//item->debugInfo(QString("add view item c:%1 ci:%2 b:%3").arg((long) this, 0, 16).arg((long) item, 0, 16).arg((long) m_bus.data(), 0, 16));
-	m_connectorItems.insert(QuickHash(item->attachedToViewIdentifier(), item->attachedToViewLayerID()), item);	
+	m_connectorItems.insert(QuickHash(item->attachedToViewID(), item->attachedToViewLayerID()), item);	
 }
 
 void Connector::removeViewItem(ConnectorItem * item) {
 	//DebugDialog::debug(QString("remove view item c:%1 ci:%2 b:%3").arg((long) this, 0, 16).arg((long) item, 0, 16).arg((long) m_bus.data(), 0, 16));
-	m_connectorItems.remove(QuickHash(item->attachedToViewIdentifier(), item->attachedToViewLayerID()));
+	m_connectorItems.remove(QuickHash(item->attachedToViewID(), item->attachedToViewLayerID()));
 }
 
 void Connector::connectTo(Connector * connector) {
@@ -129,10 +130,11 @@ void Connector::saveAsPart(QXmlStreamWriter & writer) {
 	writer.writeAttribute("type", connectorShared()->connectorTypeString());
 	writer.writeAttribute("name", connectorShared()->sharedName());
 	writer.writeTextElement("description", connectorShared()->description());
+	writer.writeTextElement("replacedby", connectorShared()->replacedby());
 	writer.writeStartElement("views");
-	QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer *> pins = m_connectorShared->pins();
-	foreach (ViewIdentifierClass::ViewIdentifier currView, pins.uniqueKeys()) {
-		writer.writeStartElement(ViewIdentifierClass::viewIdentifierXmlName(currView));
+	QMultiHash<ViewLayer::ViewID,SvgIdLayer *> pins = m_connectorShared->pins();
+	foreach (ViewLayer::ViewID currView, pins.uniqueKeys()) {
+		writer.writeStartElement(ViewLayer::viewIDXmlName(currView));
 		foreach (SvgIdLayer * svgIdLayer, pins.values(currView)) {
 			writer.writeStartElement("p");
 			writeLayerAttr(writer, svgIdLayer->m_svgViewLayerID);
@@ -150,13 +152,13 @@ void Connector::writeLayerAttr(QXmlStreamWriter &writer, ViewLayer::ViewLayerID
 	writer.writeAttribute("layer",ViewLayer::viewLayerXmlNameFromID(viewLayerID));
 }
 
-void Connector::writeSvgIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString connId) {
+void Connector::writeSvgIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewID view, QString connId) {
 	Q_UNUSED(view);
 	writer.writeAttribute("svgId",connId);
 }
 
-void Connector::writeTerminalIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString terminalId) {
-        if((view == ViewIdentifierClass::BreadboardView || view == ViewIdentifierClass::SchematicView)
+void Connector::writeTerminalIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewID view, QString terminalId) {
+        if((view == ViewLayer::BreadboardView || view == ViewLayer::SchematicView)
             &&
            (!terminalId.isNull() && !terminalId.isEmpty()) ) {
 		writer.writeAttribute("terminalId",terminalId);
@@ -169,8 +171,16 @@ const QList<Connector *> & Connector::toConnectors() {
 	return m_toConnectors;
 }
 
-ConnectorItem * Connector::connectorItemByViewLayerID(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
-	return m_connectorItems.value(QuickHash(viewIdentifier, viewLayerID), NULL);
+ConnectorItem * Connector::connectorItemByViewLayerID(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
+	return m_connectorItems.value(QuickHash(viewID, viewLayerID), NULL);
+}
+
+ConnectorItem * Connector::connectorItem(ViewLayer::ViewID viewID) {
+	foreach (ConnectorItem * connectorItem, m_connectorItems.values()) {
+        if (connectorItem->attachedToViewID() == viewID) return connectorItem;
+    }
+
+    return NULL;
 }
 
 bool Connector::connectionIsAllowed(Connector* that)
@@ -186,13 +196,13 @@ bool Connector::connectionIsAllowed(Connector* that)
 	return (thisConnectorType != thatConnectorType);		// otherwise heterosexual
 }
 
-const QString & Connector::connectorSharedID() {
+const QString & Connector::connectorSharedID() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	return m_connectorShared->id();
 }
 
-const QString & Connector::connectorSharedName() {
+const QString & Connector::connectorSharedName() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	if (!m_connectorLocalName.isEmpty()) {
@@ -202,12 +212,18 @@ const QString & Connector::connectorSharedName() {
 	return m_connectorShared->sharedName();
 }
 
-const QString & Connector::connectorSharedDescription() {
+const QString & Connector::connectorSharedDescription() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	return m_connectorShared->description();
 }
 
+const QString & Connector::connectorSharedReplacedby() const {
+	if (m_connectorShared == NULL) return ___emptyString___;
+
+	return m_connectorShared->replacedby();
+}
+
 ErcData * Connector::connectorSharedErcData() {
 	if (m_connectorShared == NULL) return NULL;
 
@@ -228,17 +244,17 @@ void Connector::setBus(Bus * bus) {
 	m_bus = bus;
 }
 
-void Connector::unprocess(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
-	SvgIdLayer * svgIdLayer = m_connectorShared->fullPinInfo(viewIdentifier, viewLayerID);
+void Connector::unprocess(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
+	SvgIdLayer * svgIdLayer = m_connectorShared->fullPinInfo(viewID, viewLayerID);
 	if (svgIdLayer != NULL) {
-		svgIdLayer->m_processed = false;
+		svgIdLayer->unprocess();
 	}
 }
 
-SvgIdLayer * Connector::fullPinInfo(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+SvgIdLayer * Connector::fullPinInfo(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_connectorShared == NULL) return NULL;
 
-	return m_connectorShared->fullPinInfo(viewIdentifier, viewLayerID);
+	return m_connectorShared->fullPinInfo(viewID, viewLayerID);
 }
 
 long Connector::modelIndex() {
@@ -261,7 +277,7 @@ QList< QPointer<ConnectorItem> > Connector::viewItems() {
 	return m_connectorItems.values();
 }
 
-const QString & Connector::legID(ViewIdentifierClass::ViewIdentifier viewID, ViewLayer::ViewLayerID viewLayerID) {
+const QString & Connector::legID(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_connectorShared) return m_connectorShared->legID(viewID, viewLayerID);
 
 	return ___emptyString___;
@@ -280,3 +296,13 @@ const QString & Connector::connectorLocalName() {
 	return m_connectorLocalName;
 }
 
+const QList<SvgIdLayer *> Connector::svgIdLayers() const {
+    if (m_connectorShared) return m_connectorShared->svgIdLayers();
+
+    return EmptySvgIdLayerList;
+}
+
+void Connector::addPin(ViewLayer::ViewID viewID, const QString & svgId, ViewLayer::ViewLayerID viewLayerId, const QString & terminalId, const QString & legId, bool hybrid)
+{
+    if (m_connectorShared) m_connectorShared->addPin(viewID, svgId, viewLayerId, terminalId, legId, hybrid);
+}
