@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6138 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-04 14:08:48 +0200 (Wed, 04 Jul 2012) $
+$Revision: 6955 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-06 23:14:37 +0200 (Sa, 06. Apr 2013) $
 
 ********************************************************************/
 
@@ -49,6 +49,7 @@ ConnectorShared::ConnectorShared( const QDomElement & domElement )
 	m_ercData = NULL;
 	m_id = domElement.attribute("id", "");
 	m_name = domElement.attribute("name", "");
+	m_replacedby = domElement.attribute("replacedby", "");
 	//DebugDialog::debug(QString("\tname:%1 id:%2").arg(m_name).arg(m_id));
 	m_typeString = domElement.attribute("type", "");
 	m_type = Connector::connectorTypeFromName(m_typeString);
@@ -85,7 +86,7 @@ ConnectorShared::~ConnectorShared() {
 }
 
 
-const QString & ConnectorShared::id() {
+const QString & ConnectorShared::id() const {
 	return m_id;
 }
 
@@ -104,6 +105,7 @@ void ConnectorShared::setDescription(QString description) {
 const QString & ConnectorShared::sharedName() {
 	return m_name;
 }
+
 void ConnectorShared::setSharedName(QString name) {
 	m_name = name;
 }
@@ -121,35 +123,50 @@ void ConnectorShared::setConnectorType(QString type) {
 	m_type = Connector::connectorTypeFromName(type);
 }
 
-const QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer*> & ConnectorShared::pins() {
+void ConnectorShared::setConnectorType(Connector::ConnectorType type) {
+	m_typeString = Connector::connectorNameFromType(type);
+	m_type = type;
+}
+
+const QString & ConnectorShared::replacedby() const {
+	return m_replacedby;
+}
+
+void ConnectorShared::setReplacedby(QString replacedby) {
+	m_replacedby = replacedby;
+}
+
+const QMultiHash<ViewLayer::ViewID,SvgIdLayer*> & ConnectorShared::pins() {
 	return m_pins;
 }
 
-void ConnectorShared::insertPin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
+void ConnectorShared::insertPin(ViewLayer::ViewID layer, SvgIdLayer * svgIdLayer) {
 	m_pins.insert(layer, svgIdLayer);
 }
 
-void ConnectorShared::addPin(ViewIdentifierClass::ViewIdentifier layer, QString connectorId, ViewLayer::ViewLayerID viewLayerID, QString terminalId) {
-	SvgIdLayer * svgIdLayer = new SvgIdLayer;
+void ConnectorShared::addPin(ViewLayer::ViewID viewID, const QString & svgId, ViewLayer::ViewLayerID viewLayerID, const QString & terminalId, const QString & legId, bool hybrid) {
+	SvgIdLayer * svgIdLayer = new SvgIdLayer(viewID);
 	svgIdLayer->m_svgViewLayerID = viewLayerID;
-	svgIdLayer->m_svgId = connectorId;
+	svgIdLayer->m_svgId = svgId;
 	svgIdLayer->m_terminalId = terminalId;
-	m_pins.insert(layer, svgIdLayer);
+    svgIdLayer->m_hybrid = hybrid;
+    svgIdLayer->m_legId = legId;
+	m_pins.insert(viewID, svgIdLayer);
 	// DebugDialog::debug(QString("insert a %1 %2 %3").arg(layer).arg(connectorId).arg(viewLayerID));
 }
 
-void ConnectorShared::removePins(ViewIdentifierClass::ViewIdentifier layer) {
+void ConnectorShared::removePins(ViewLayer::ViewID layer) {
 	m_pins.remove(layer);
 	if (m_pins.values(layer).size() != 0) {
 		throw "ConnectorShared::removePins";
 	}
 }
 
-void ConnectorShared::removePin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
+void ConnectorShared::removePin(ViewLayer::ViewID layer, SvgIdLayer * svgIdLayer) {
 	m_pins.remove(layer, svgIdLayer);
 }
 
-SvgIdLayer * ConnectorShared::fullPinInfo(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
+SvgIdLayer * ConnectorShared::fullPinInfo(ViewLayer::ViewID viewId, ViewLayer::ViewLayerID viewLayerID) {
 	QList<SvgIdLayer *> svgLayers = m_pins.values(viewId);
 	foreach ( SvgIdLayer * svgIdLayer, svgLayers) {
 		if (svgIdLayer->m_svgViewLayerID == viewLayerID) {
@@ -160,7 +177,7 @@ SvgIdLayer * ConnectorShared::fullPinInfo(ViewIdentifierClass::ViewIdentifier vi
 	return NULL;
 }
 
-const QString & ConnectorShared::legID(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
+const QString & ConnectorShared::legID(ViewLayer::ViewID viewId, ViewLayer::ViewLayerID viewLayerID) {
 	QList<SvgIdLayer *> svgLayers = m_pins.values(viewId);
 	foreach ( SvgIdLayer * svgIdLayer, svgLayers) {
 		if (svgIdLayer->m_svgViewLayerID == viewLayerID) {
@@ -177,12 +194,12 @@ void ConnectorShared::loadPins(const QDomElement & domElement) {
 
 	// TODO: this is view-related stuff and it would be nice if the model didn't know about it
 	QDomElement viewsTag = domElement.firstChildElement("views");
-	loadPin(viewsTag.firstChildElement("breadboardView"),ViewIdentifierClass::BreadboardView);
-	loadPin(viewsTag.firstChildElement("schematicView"),ViewIdentifierClass::SchematicView);
-	loadPin(viewsTag.firstChildElement("pcbView"),ViewIdentifierClass::PCBView);
+	loadPin(viewsTag.firstChildElement("breadboardView"),ViewLayer::BreadboardView);
+	loadPin(viewsTag.firstChildElement("schematicView"),ViewLayer::SchematicView);
+	loadPin(viewsTag.firstChildElement("pcbView"),ViewLayer::PCBView);
 }
 
-void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentifier viewId) {
+void ConnectorShared::loadPin(QDomElement elem, ViewLayer::ViewID viewID) {
 	QDomElement pinElem = elem.firstChildElement("p");
 	while (!pinElem.isNull()) {
 		//QString temp;
@@ -192,7 +209,7 @@ void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentif
 		QString svgId = pinElem.attribute("svgId");
 		//svgId = svgId.left(svgId.lastIndexOf(QRegExp("\\d"))+1);
 		QString layer = pinElem.attribute("layer");
-		SvgIdLayer * svgIdLayer = new SvgIdLayer;
+		SvgIdLayer * svgIdLayer = new SvgIdLayer(viewID);
 		svgIdLayer->m_hybrid = (pinElem.attribute("hybrid").compare("yes") == 0);
 		svgIdLayer->m_legId = pinElem.attribute("legId");
 		svgIdLayer->m_svgId = svgId;
@@ -203,7 +220,7 @@ void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentif
 		//if (!svgIdLayer->m_terminalId.isEmpty()) {
 		//	DebugDialog::debug("terminalid " + svgIdLayer->m_terminalId);
 		//}
-		m_pins.insert(viewId, svgIdLayer);
+		m_pins.insert(viewID, svgIdLayer);
 		//DebugDialog::debug(QString("insert b %1 %2 %3").arg(viewId).arg(svgId).arg(layer));
 
 		pinElem = pinElem.nextSiblingElement("p");
@@ -227,3 +244,7 @@ ErcData * ConnectorShared::ercData() {
 	return m_ercData;
 }
 
+const QList<SvgIdLayer *> ConnectorShared::svgIdLayers() const
+{
+    return m_pins.values();
+}
