@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6955 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-06 23:14:37 +0200 (Sa, 06. Apr 2013) $
 
 ********************************************************************/
 
@@ -44,7 +44,7 @@ public:
 	ConnectorShared(const QDomElement & domElement);
 	~ConnectorShared();
 
-	const QString & id();
+	const QString & id() const;
 	void setId(QString id);
 	const QString & description();
 	void setDescription(QString description);
@@ -52,15 +52,19 @@ public:
 	void setSharedName(QString name);
 	const QString & connectorTypeString();
 	void setConnectorType(QString type);
+	void setConnectorType(Connector::ConnectorType);
 	Connector::ConnectorType connectorType();
+	const QString & replacedby() const;
+	void setReplacedby(QString);
 
-	const QString & legID(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
-	const QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer *> &pins();
-	SvgIdLayer * fullPinInfo(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
-	void addPin(ViewIdentifierClass::ViewIdentifier layer, QString connectorId, ViewLayer::ViewLayerID, QString terminalId);
-	void insertPin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
-	void removePins(ViewIdentifierClass::ViewIdentifier layer);
-	void removePin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
+	const QString & legID(ViewLayer::ViewID viewId, ViewLayer::ViewLayerID viewLayerID);
+	const QMultiHash<ViewLayer::ViewID,SvgIdLayer *> &pins();
+	SvgIdLayer * fullPinInfo(ViewLayer::ViewID viewId, ViewLayer::ViewLayerID viewLayerID);
+    const QList<SvgIdLayer *> svgIdLayers() const;
+	void addPin(ViewLayer::ViewID, const QString & svgId, ViewLayer::ViewLayerID, const QString & terminalId, const QString & legId, bool hybrid);
+	void insertPin(ViewLayer::ViewID layer, SvgIdLayer * svgIdLayer);
+	void removePins(ViewLayer::ViewID layer);
+	void removePin(ViewLayer::ViewID layer, SvgIdLayer * svgIdLayer);
 
 	class BusShared * bus();
 	void setBus(class BusShared *);
@@ -69,18 +73,19 @@ public:
 
 protected:
 	void loadPins(const QDomElement & domElement);
-	void loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentifier viewId);
+	void loadPin(QDomElement elem, ViewLayer::ViewID viewId);
 
 	QString m_description;
 	QString m_id;
 	QString m_name;
 	QString m_typeString;
+    QString m_replacedby;
 	Connector::ConnectorType m_type;
 	QString m_ercType;
 	class ErcData * m_ercData;
 	class BusShared * m_bus;
 
-	QMultiHash<ViewIdentifierClass::ViewIdentifier, SvgIdLayer*> m_pins;
+	QMultiHash<ViewLayer::ViewID, SvgIdLayer*> m_pins;
 };
 
 static QList<ConnectorShared *> ___emptyConnectorSharedList___;
