@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6732 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-12-27 08:26:48 +0100 (Do, 27. Dez 2012) $
 
 ********************************************************************/
 
@@ -89,6 +89,8 @@ protected:
 	QPointer<QTabWidget> m_tabWidget;
 	QPointer<QWidget> m_general;
 	QPointer<QWidget> m_breadboard;
+	QPointer<QWidget> m_schematic;
+	QPointer<QWidget> m_pcb;
 	QPointer<QLabel> m_wheelLabel[3];
 	QHash<QString, QString> m_settings;
 	QHash<QString, QString> m_tempSettings;
