@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6469 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-23 00:54:30 +0200 (So, 23. Sep 2012) $
 
 ********************************************************************/
 
@@ -31,7 +31,6 @@ $Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
 #include <QChar>
 #include <QTime>
 #include <QKeyEvent>
-#include <QCloseEvent>
 #include <QScrollBar>
 #include <QMessageBox>
 
