@@ -31,17 +31,16 @@ $Date: 2013-04-19 12:51:22 +0200 (Fr, 19. Apr 2013) $
 #include "fsplashscreen.h"
 #include "version/version.h"
 #include "dialogs/prefsdialog.h"
-#include "help/helper.h"
 #include "fsvgrenderer.h"
 #include "version/versionchecker.h"
 #include "version/updatedialog.h"
 #include "itemdrag.h"
-#include "dock/viewswitcher.h"
 #include "items/wire.h"
 #include "partsbinpalette/binmanager/binmanager.h"
 #include "help/tipsandtricks.h"
 #include "utils/folderutils.h"
 #include "utils/lockmanager.h"
+#include "utils/fmessagebox.h"
 #include "dialogs/translatorlistmodel.h"
 #include "partsbinpalette/partsbinview.h"
 #include "partsbinpalette/svgiconwidget.h"
@@ -66,6 +65,7 @@ $Date: 2013-04-19 12:51:22 +0200 (Fr, 19. Apr 2013) $
 #include "autoroute/panelizer.h"
 #include "sketch/sketchwidget.h"
 #include "sketch/pcbsketchwidget.h"
+#include "help/firsttimehelpdialog.h"
 
 // dependency injection :P
 #include "referencemodel/sqlitereferencemodel.h"
@@ -348,12 +348,12 @@ bool FApplication::init() {
 			toRemove << i << i + 1;
 		}
 
-		if ((m_arguments[i].compare("-drc", Qt::CaseInsensitive) == 0) ||
-			(m_arguments[i].compare("--drc", Qt::CaseInsensitive) == 0)) {
-			m_serviceType = DRCService;
-			m_outputFolder = m_arguments[i + 1];
-			toRemove << i << i + 1;
-		}
+		//if ((m_arguments[i].compare("-drc", Qt::CaseInsensitive) == 0) ||
+		//	(m_arguments[i].compare("--drc", Qt::CaseInsensitive) == 0)) {
+		//	m_serviceType = DRCService;
+		//	m_outputFolder = m_arguments[i + 1];
+		//	toRemove << i << i + 1;
+		//}
 
 		if ((m_arguments[i].compare("-db", Qt::CaseInsensitive) == 0) ||
             (m_arguments[i].compare("-database", Qt::CaseInsensitive) == 0) ||
@@ -508,7 +508,6 @@ bool FApplication::init() {
 	ItemBase::initNames();
 	ViewLayer::initNames();
 	Connector::initNames();
-	Helper::initText();
 	BinManager::initNames();
 	PaletteModel::initNames();
 	SvgIconWidget::initNames();
@@ -534,10 +533,10 @@ FApplication::~FApplication(void)
 	ItemBase::cleanup();
 	Wire::cleanup();
 	DebugDialog::cleanup();
-	ViewSwitcher::cleanup();
 	ItemDrag::cleanup();
 	Version::cleanup();
 	TipsAndTricks::cleanup();
+	FirstTimeHelpDialog::cleanup();
 	TranslatorListModel::cleanup();
 	FolderUtils::cleanup();
 	SearchLineEdit::cleanup();
@@ -668,13 +667,18 @@ void FApplication::registerFonts() {
 	registerFont(":/resources/fonts/DroidSansMono.ttf", false);
 	registerFont(":/resources/fonts/OCRA.ttf", true);
 
-	/*	
+    // "Droid Sans" 
+    // "Droid Sans Mono" 
+		
+    /*
 		QFontDatabase database;
 		QStringList families = database.families (  );
 		foreach (QString string, families) {
 			DebugDialog::debug(string);			// should print out the name of the fonts you loaded
 		}
-	*/	
+*/
+
+
 }
 
 ReferenceModel * FApplication::loadReferenceModel(const QString & databaseName, bool fullLoad) {
@@ -723,6 +727,17 @@ int FApplication::serviceStartup() {
 	}
 
 	switch (m_serviceType) {
+        case PortService:
+            initService();
+            {
+                MainWindow * sketch = MainWindow::newMainWindow(m_referenceModel, "", true, true);
+                if (sketch) {
+                    sketch->show();
+                    sketch->clearFileProgressDialog();
+                }
+            }
+            return 1;
+
 		case GedaService:
 			runGedaService();
 			return 0;
@@ -788,7 +803,7 @@ void FApplication::runGerberServiceAux()
 		m_started = true;
         
 		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
-		if (mainWindow->loadWhich(filepath, false, false, "")) {
+		if (mainWindow->loadWhich(filepath, false, false, false, "")) {
             QFileInfo info(filepath);
             GerberGenerator::exportToGerber(info.completeBaseName(), m_outputFolder, NULL, mainWindow->pcbView(), false);
 		}
@@ -807,7 +822,7 @@ void FApplication::initService()
 
 void FApplication::runSvgService()
 {
-    initService();
+
     runSvgServiceAux();
 }
 
@@ -824,7 +839,7 @@ void FApplication::runSvgServiceAux()
 		m_started = true;
         
 		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
-		if (mainWindow->loadWhich(filepath, false, false, "")) {
+		if (mainWindow->loadWhich(filepath, false, false, false, "")) {
             QFileInfo info(filepath);
             QList<ViewLayer::ViewID> ids;
             ids << ViewLayer::BreadboardView << ViewLayer::SchematicView << ViewLayer::PCBView;
@@ -911,7 +926,7 @@ void FApplication::runDRCService() {
 
             mainWindow->setCloseSilently(true);
 
-	        if (!mainWindow->loadWhich(filepath, false, false, "")) {
+	        if (!mainWindow->loadWhich(filepath, false, false, false, "")) {
 		        DebugDialog::debug(QString("failed to load '%1'").arg(filepath));
 		        mainWindow->close();
                 delete mainWindow;
@@ -1140,7 +1155,7 @@ void FApplication::registerFont(const QString &fontFile, bool reallyRegister) {
 		foreach (QString family, familyNames) {
 			InstalledFonts::InstalledFontsNameMapper.insert(family, finfo.completeBaseName());
 			InstalledFonts::InstalledFontsList << family;
-			//DebugDialog::debug("registering font family: "+family);
+			DebugDialog::debug(QString("registering font family: %1 %2").arg(family).arg(finfo.completeBaseName()));
 		}
 	}
 }
@@ -1154,7 +1169,7 @@ void FApplication::finish()
 
 void FApplication::loadNew(QString path) {
 	MainWindow * mw = MainWindow::newMainWindow(m_referenceModel, path, true, true);
-	if (!mw->loadWhich(path, false, true, "")) {
+	if (!mw->loadWhich(path, false, true, true, "")) {
 		mw->close();
 	}
 	mw->clearFileProgressDialog();
@@ -1163,7 +1178,7 @@ void FApplication::loadNew(QString path) {
 void FApplication::loadOne(MainWindow * mw, QString path, int loaded) {
 	if (loaded == 0) {
 		mw->showFileProgressDialog(path);
-		mw->loadWhich(path, true, true, "");
+		mw->loadWhich(path, true, true, true, "");
 	}
 	else {
 		loadNew(path);
@@ -1487,8 +1502,9 @@ which is really not intended for hundreds of widgets.
 
 bool FApplication::runAsService() {
     if (m_serviceType == PortService) {
+        DebugDialog::setEnabled(true);
         initServer();
-        return false;
+        //return false;
     }
 
 	return m_serviceType != NoService;
@@ -1515,11 +1531,16 @@ bool FApplication::notify(QObject *receiver, QEvent *e)
         return QApplication::notify(receiver, e);
     }
 	catch (char const *str) {
-        QMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception %1 from %2 in event %3")
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception %1 from %2 in event %3")
 			.arg(str).arg(receiver->objectName()).arg(e->type()));
 	}
+    catch (std::exception& exp) {
+        // suggested in https://code.google.com/p/fritzing/issues/detail?id=2698
+        qDebug() << QString("notify %1 %2").arg(receiver->metaObject()->className()).arg(e->type());
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2: %3").arg(receiver->objectName()).arg(e->type()).arg(exp.what()));
+    }
     catch (...) {
-        QMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2").arg(receiver->objectName()).arg(e->type()));
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2").arg(receiver->objectName()).arg(e->type()));
     }
 	closeAllWindows2();
 	QApplication::exit(-1);
@@ -1558,7 +1579,12 @@ void FApplication::loadSomething(const QString & prevVersion) {
         foreach (QString filename, m_filesToLoad) {
             DebugDialog::debug(QString("Loading non-service file %1").arg(filename));
             MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, filename, true, true);
-            mainWindow->loadWhich(filename, true, true, "");
+            mainWindow->loadWhich(filename, true, true, true, "");
+            if (filename.endsWith(FritzingSketchExtension) || filename.endsWith(FritzingBundleExtension)) {
+            }
+            else {
+                mainWindow->addDefaultParts();
+            }
             sketchesToLoad << mainWindow;
         }
 	}
@@ -1566,7 +1592,8 @@ void FApplication::loadSomething(const QString & prevVersion) {
     // Find any previously open sketches to reload
     if (!loadPrevious && sketchesToLoad.isEmpty()) {
 		DebugDialog::debug(QString("load last open"));
-		sketchesToLoad = loadLastOpenSketch();
+        // new logic here, we no longer open the most recent sketch, since it can be reached in one click from the welcome page
+		//sketchesToLoad = loadLastOpenSketch();
 	}
 
 	MainWindow * newBlankSketch = NULL;
@@ -1593,6 +1620,8 @@ void FApplication::loadSomething(const QString & prevVersion) {
 	}
 	else if (newBlankSketch) {
 		newBlankSketch->hideTempPartsBin();
+        // new empty sketch defaults to welcome view
+        newBlankSketch->showWelcomeView();
 	}
 }
 
@@ -1610,7 +1639,7 @@ QList<MainWindow *> FApplication::loadLastOpenSketch() {
     DebugDialog::debug(QString("Loading last open sketch %1").arg(lastSketchPath));
     settings.remove("lastOpenSketch");				// clear the preference, in case the load crashes
     MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, lastSketchPath, true, true);
-    mainWindow->loadWhich(lastSketchPath, true, true, "");
+    mainWindow->loadWhich(lastSketchPath, true, true, true, "");
     sketches << mainWindow;
     settings.setValue("lastOpenSketch", lastSketchPath);	// the load works, so restore the preference
 	return sketches;
@@ -1621,7 +1650,7 @@ void FApplication::doLoadPrevious(MainWindow * sketchWindow) {
     // This should be done before any files are loaded as it requires a restart.
     // As this can generate UI it should come after the splash screen has closed.
 
-    QMessageBox messageBox(sketchWindow);
+    FMessageBox messageBox(sketchWindow);
     messageBox.setWindowTitle(tr("Import files from previous version?"));
     messageBox.setText(tr("Do you want to import parts and bins that you have created with earlier versions of Fritzing?\n"));
     messageBox.setInformativeText(tr("\nNote: You can import them later using the \"Help\" > \"Import parts and bins "
@@ -1668,10 +1697,9 @@ QList<MainWindow *> FApplication::recoverBackups()
 			QString bundledFileName = FolderUtils::getSaveFileName(NULL, tr("Please specify an .fzz file name to save to (cancel will delete the backup)"), originalPath, tr("Fritzing (*%1)").arg(FritzingBundleExtension), &fileExt);
 			if (!bundledFileName.isEmpty()) {
 				MainWindow *currentRecoveredSketch = MainWindow::newMainWindow(m_referenceModel, originalBaseName, true, true);
-    			currentRecoveredSketch->mainLoad(backupName, bundledFileName);
+    			currentRecoveredSketch->mainLoad(backupName, bundledFileName, true);
 				currentRecoveredSketch->saveAsShareable(bundledFileName, true);
 				currentRecoveredSketch->setCurrentFile(bundledFileName, true, true);
-				currentRecoveredSketch->showAllFirstTimeHelp(false);
 				recoveredSketches << currentRecoveredSketch;
 
 				/*
@@ -1735,12 +1763,16 @@ void FApplication::runInscriptionService()
 {	
 	m_started = true;
     bool drc = false;
+    bool noMessages = false;
     foreach (QString arg, m_arguments) {
         if (arg.compare("-drc", Qt::CaseInsensitive) == 0) {
             drc = true;
         }
+        if (arg.compare("-nm", Qt::CaseInsensitive) == 0) {
+            noMessages = true;
+        }
     }
-	Panelizer::inscribe(this, m_panelFilename, drc);
+	Panelizer::inscribe(this, m_panelFilename, drc, noMessages);
 }
 
 QList<MainWindow *> FApplication::orderedTopLevelMainWindows() {
@@ -1775,12 +1807,14 @@ void FApplication::runExampleService(QDir & dir) {
 
 		FolderUtils::setOpenSaveFolderAux(dir.absolutePath());
 
-		if (!mainWindow->loadWhich(path, false, false, "")) {
+		if (!mainWindow->loadWhich(path, false, false, true, "")) {
 			DebugDialog::debug(QString("failed to load"));
 		}
 		else {
-			mainWindow->selectAllObsolete(false);
-			mainWindow->swapObsolete(false);
+			QList<ItemBase *> items = mainWindow->selectAllObsolete(false);
+			if (items.count() > 0) {
+                mainWindow->swapObsolete(false, items);
+            }
 			mainWindow->saveAsAux(path);    //   path + "z"
 			mainWindow->setCloseSilently(true);
 			mainWindow->close();
@@ -1804,6 +1838,7 @@ void FApplication::cleanFzzs() {
 }
 
 void FApplication::initServer() {
+    FMessageBox::BlockMessages = true;
     m_fServer = new FServer(this);
     connect(m_fServer, SIGNAL(newConnection(int)), this, SLOT(newConnection(int)));
     m_fServer->listen(QHostAddress::Any, m_portNumber);
