@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6289 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-14 04:06:50 +0200 (Tue, 14 Aug 2012) $
+$Revision: 6940 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-26 14:00:34 +0100 (Di, 26. Mrz 2013) $
 
 ********************************************************************/
 
@@ -34,10 +34,54 @@ $Date: 2012-08-14 04:06:50 +0200 (Tue, 14 Aug 2012) $
 #include <QPointer>
 #include <QWidget>
 #include <QTimer>
+#include <QTcpServer>
+#include <QTcpSocket>
+#include <QMutex>
+#include <QThread>
 #include <QNetworkReply>
+#include <QNetworkAccessManager>
 
-class FApplication :
-	public QApplication
+class FServer : public QTcpServer
+{
+    Q_OBJECT
+
+public:
+    FServer(QObject *parent = 0);
+
+signals:
+    void newConnection(int socketDescriptor);
+
+protected:
+    void incomingConnection(int socketDescriptor);
+};
+
+class FServerThread : public QThread
+{
+    Q_OBJECT
+
+public:
+    FServerThread(int socketDescriptor, QObject *parent);
+
+    void run();
+    void setDone();
+
+signals:
+    void error(QTcpSocket::SocketError socketError);
+    void doCommand(const QString & command, const QString & params, QString & result, int & status);
+
+protected:
+    void writeResponse(QTcpSocket *, int code, const QString & codeString, const QString & mimeType, const QString & message);
+
+protected:
+    int m_socketDescriptor;
+    bool m_done;
+
+protected:
+   static QMutex m_busy;
+
+ };
+
+class FApplication : public QApplication
 {
 	Q_OBJECT
 
@@ -47,16 +91,16 @@ public:
 
 public:
 	bool init();
-	int startup(bool firstRun);
+	int startup();
 	int serviceStartup();
 	void finish();
-	class ReferenceModel * loadReferenceModel();
+	class ReferenceModel * loadReferenceModel(const QString & databaseName, bool fullLoad);
 	void registerFonts();
-	class MainWindow * loadWindows(int & loaded, bool lockFiles);
+	class MainWindow * openWindowForService(bool lockFiles);
+    bool runAsService();
 
 public:
 	static bool spaceBarIsPressed();
-	static bool runAsService();
 
 signals:
 	void spaceBarIsPressedSignal(bool);
@@ -75,6 +119,8 @@ public slots:
 	void loadedPart(int loaded, int total);
 	void externalProcessSlot(QString & name, QString & path, QStringList & args);
 	void gotOrderFab(QNetworkReply *);
+    void newConnection(int socketDescriptor);
+    void doCommand(const QString & command, const QString & params, QString & result, int & status);
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event);
@@ -86,10 +132,16 @@ protected:
 	void registerFont(const QString &fontFile, bool reallyRegister);
 	void clearModels();
     bool notify(QObject *receiver, QEvent *e);
+    void initService();
+	void runDRCService();
 	void runGedaService();
+	void runDatabaseService();
 	void runKicadFootprintService();
 	void runKicadSchematicService();
 	void runGerberService();
+	void runGerberServiceAux();
+	void runSvgService();
+	void runSvgServiceAux();
 	void runPanelizerService();
 	void runInscriptionService();
 	void runExampleService();
@@ -97,14 +149,14 @@ protected:
 	QList<class MainWindow *> recoverBackups();
 	QList<MainWindow *> loadLastOpenSketch();
 	void doLoadPrevious(MainWindow *);
-	void loadSomething(bool firstRun, const QString & previousVersion);
+	void loadSomething(const QString & previousVersion);
 	void initFilesToLoad();
 	void initBackups();
 	void cleanupBackups();
-	QString makeRequestParamsString();
 	void updatePrefs(class PrefsDialog & prefsDialog);
     QList<MainWindow *> orderedTopLevelMainWindows();
 	void cleanFzzs();
+    void initServer();
 
 	enum ServiceType {
 		PanelizerService = 1,
@@ -114,6 +166,10 @@ protected:
 		KicadSchematicService,
 		KicadFootprintService,
 		ExampleService,
+        DatabaseService,
+        SvgService,
+        PortService,
+        DRCService,
 		NoService
 	};
 
@@ -122,7 +178,6 @@ protected:
 	bool m_mousePressed;
 	QTranslator m_translator;
 	class ReferenceModel * m_referenceModel;
-	class PaletteModel * m_paletteBinModel;
 	bool m_started;
 	QStringList m_filesToLoad;
 	QString m_libPath;
@@ -139,12 +194,12 @@ protected:
 	int m_progressIndex;
 	class FSplashScreen * m_splash;
 	QString m_outputFolder;
+	QString m_portRootFolder;
 	QString m_panelFilename;
 	QHash<QString, struct LockedFile *> m_lockedFiles;
-
-public:
-	static int RestartNeeded;
-
+    bool m_panelizerCustom;
+    int m_portNumber;
+    FServer * m_fServer;
 };
 
 
