@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6245 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-04 08:42:55 +0200 (Sat, 04 Aug 2012) $
+$Revision: 6988 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-26 12:05:48 +0200 (Fr, 26. Apr 2013) $
 
 ********************************************************************/
 
@@ -29,6 +29,7 @@ $Date: 2012-08-04 08:42:55 +0200 (Sat, 04 Aug 2012) $
 #include "svg/svgfilesplitter.h"
 #include "utils/textutils.h"
 #include "utils/graphicsutils.h"
+#include "utils/folderutils.h"
 #include "connectors/svgidlayer.h"
 
 #include <QRegExp>
@@ -38,6 +39,8 @@ $Date: 2012-08-04 08:42:55 +0200 (Sat, 04 Aug 2012) $
 #include <QGraphicsSvgItem>
 #include <qnumeric.h>
 
+/////////////////////////////////////////////
+
 QString FSvgRenderer::NonConnectorName("nonconn");
 
 static ConnectorInfo VanillaConnectorInfo;
@@ -54,7 +57,7 @@ FSvgRenderer::~FSvgRenderer()
 }
 
 void FSvgRenderer::initNames() {
-    VanillaConnectorInfo.gotCircle = false;	
+    VanillaConnectorInfo.gotPath = VanillaConnectorInfo.gotCircle = false;	
 }
 
 void FSvgRenderer::clearConnectorInfoHash(QHash<QString, ConnectorInfo *> & hash) {
@@ -69,17 +72,17 @@ void FSvgRenderer::cleanup() {
 }
 
 QByteArray FSvgRenderer::loadSvg(const QString & filename) {
-	QStringList strings;
-	QString string;
-	return loadSvg(filename, strings, strings, strings, string, string, false);
+    LoadInfo loadInfo;
+    loadInfo.filename = filename;
+	return loadSvg(loadInfo);
 }
 
-QByteArray FSvgRenderer::loadSvg(const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) {
-	if (!QFileInfo(filename).exists() || !QFileInfo(filename).isFile()) {
+QByteArray FSvgRenderer::loadSvg(const LoadInfo & loadInfo) {
+	if (!QFileInfo(loadInfo.filename).exists() || !QFileInfo(loadInfo.filename).isFile()) {
 		return QByteArray();
 	}
 
-    QFile file(filename);
+    QFile file(loadInfo.filename);
     if (!file.open(QFile::ReadOnly | QFile::Text)) {
 		return QByteArray();
 	}
@@ -89,7 +92,7 @@ QByteArray FSvgRenderer::loadSvg(const QString & filename, const QStringList & c
 
 	if (contents.length() <= 0) return QByteArray();
 
-	return loadAux(contents, filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, findNonConnectors);
+	return loadAux(contents, loadInfo);
 
 }
 
@@ -107,94 +110,59 @@ bool FSvgRenderer::loadSvgString(const QString & svg, QString & newSvg) {
 }
 
 QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const QString & filename, bool findNonConnectors) {
-	QStringList strings;
-	QString string;
-	return loadSvg(contents, filename, strings, strings, strings, string, string, findNonConnectors);
+    LoadInfo loadInfo;
+    loadInfo.filename = filename;
+    loadInfo.findNonConnectors = findNonConnectors;
+	return loadAux(contents, loadInfo);
 }
 
-QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) {
-	return loadAux(contents, filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, findNonConnectors);
+QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const LoadInfo & loadInfo) {
+	return loadAux(contents, loadInfo);
 }
 
-QByteArray FSvgRenderer::loadAux(const QByteArray & theContents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) {
-
+QByteArray FSvgRenderer::loadAux(const QByteArray & theContents, const LoadInfo & loadInfo) 
+{
 	QByteArray cleanContents(theContents);
 	bool cleaned = false;
-	if (TextUtils::isIllustratorFile(cleanContents)) {
-		QString string(cleanContents);
 
-		if (string.contains("sodipodi") || string.contains("inkscape")) {
-			// if svg has both Illustrator and Inkscape crap then converting back and forth between strings and QDomDocument
-			// in FixPixelDimensionsIn() can result in invalid xml
-			TextUtils::cleanSodipodi(string);
-#ifndef QT_NO_DEBUG
-			if (!filename.contains("icon", Qt::CaseInsensitive)) {
-				DebugDialog::debug("Illustrator and inkscape:" + filename);
-			}
-#endif
-		}
-
-		//DebugDialog::debug("Illustrator " + filename);
-		if (TextUtils::fixPixelDimensionsIn(string)) {
-			cleaned = true;
-			cleanContents = string.toUtf8();
-		}
-	}
-	
-	if (cleanContents.contains("sodipodi") || cleanContents.contains("inkscape")) {
-		//DebugDialog::debug("inkscape " + filename);
-	}
-
-	if (cleanContents.contains("<tspan")) {
-		QString string(cleanContents);
-		TextUtils::tspanRemove(string);
-		cleanContents = string.toUtf8();
+    QString string(cleanContents);
+    if (TextUtils::fixMuch(string, false)) {
 		cleaned = true;
 	}
+	if (TextUtils::fixPixelDimensionsIn(string)) {
+        cleaned = true;
+    }
+    if (cleaned) {
+        cleanContents = string.toUtf8();
+    }
 
-	if (cleanContents.contains("<use")) {
-		QString string(cleanContents);
-		TextUtils::noUse(string);
-		cleanContents = string.toUtf8();
-		cleaned = true;
-	}
-
-	if (cleanContents.contains("<pattern")) {
-		QString string(cleanContents);
-		TextUtils::noPattern(string);
-		cleanContents = string.toUtf8();
-		cleaned = true;
-	}
-
-	// no it isn't
-
-	if (connectorIDs.count() > 0 || !setColor.isEmpty() || findNonConnectors) {
+	if (loadInfo.connectorIDs.count() > 0 || !loadInfo.setColor.isEmpty() || loadInfo.findNonConnectors) {
 		QString errorStr;
 		int errorLine;
 		int errorColumn;
 		QDomDocument doc;
 		if (!doc.setContent(cleanContents, &errorStr, &errorLine, &errorColumn)) {
-			DebugDialog::debug(QString("renderer loadAux failed %1 %2 %3 %4").arg(filename).arg(errorStr).arg(errorLine).arg(errorColumn));
+			DebugDialog::debug(QString("renderer loadAux failed %1 %2 %3 %4").arg(loadInfo.filename).arg(errorStr).arg(errorLine).arg(errorColumn));
 		}
 
 		bool resetContents = false;
 
 		QDomElement root = doc.documentElement();
-		if (!setColor.isEmpty()) {
-			QDomElement element = TextUtils::findElementWithAttribute(root, "id", colorElementID);
+		if (!loadInfo.setColor.isEmpty()) {
+			QDomElement element = TextUtils::findElementWithAttribute(root, "id", loadInfo.colorElementID);
 			if (!element.isNull()) {
 				QStringList exceptions;
 				exceptions << "black" << "#000000";
-				SvgFileSplitter::fixColorRecurse(element, setColor, exceptions);
+				SvgFileSplitter::fixColorRecurse(element, loadInfo.setColor, exceptions);
 				resetContents = true;
 			}
 		}
-		if (connectorIDs.count() > 0) {
-			bool init =  initConnectorInfo(doc, connectorIDs, terminalIDs, legIDs, filename);
+		if (loadInfo.connectorIDs.count() > 0) {
+			bool init =  initConnectorInfo(doc, loadInfo);
 			resetContents = resetContents || init;
 		}
-		if (findNonConnectors) {
-			initNonConnectorInfo(doc, filename);
+		if (loadInfo.findNonConnectors) {
+			initNonConnectorInfo(doc, loadInfo.filename);
 		}
 
 		if (resetContents) {
@@ -217,6 +185,11 @@ QByteArray FSvgRenderer::loadAux(const QByteArray & theContents, const QString &
 
 	//DebugDialog::debug(cleanContents.data());
 
+    return finalLoad(cleanContents, loadInfo.filename);
+}
+
+QByteArray FSvgRenderer::finalLoad(QByteArray & cleanContents, const QString & filename) {
+
 	QXmlStreamReader xml(cleanContents);
 	bool result = determineDefaultSize(xml);
 	if (!result) {
@@ -310,7 +283,7 @@ void FSvgRenderer::initNonConnectorInfoAux(QDomElement & element, const QString
 {
 	QString id = element.attribute("id");
 	if (id.startsWith(NonConnectorName, Qt::CaseInsensitive)) {
-		ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, filename);
+		ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, filename, false);
 		m_nonConnectorInfoHash.insert(id, connectorInfo);
 	}
 	QDomElement child = element.firstChildElement();
@@ -320,27 +293,27 @@ void FSvgRenderer::initNonConnectorInfoAux(QDomElement & element, const QString
 	}
 }
 
-bool FSvgRenderer::initConnectorInfo(QDomDocument & domDocument, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & filename)
+bool FSvgRenderer::initConnectorInfo(QDomDocument & domDocument, const LoadInfo & loadInfo)
 {
 	bool result = false;
 	clearConnectorInfoHash(m_connectorInfoHash);
 	QDomElement root = domDocument.documentElement();
-	initConnectorInfoAux(root, connectorIDs, filename);
-	if (terminalIDs.count() > 0) {
-		initTerminalInfoAux(root, connectorIDs, terminalIDs);
+	initConnectorInfoAux(root, loadInfo);
+	if (loadInfo.terminalIDs.count() > 0) {
+		initTerminalInfoAux(root, loadInfo);
 	}
-	if (legIDs.count() > 0) {
-		initLegInfoAux(root, connectorIDs, legIDs, result);
+	if (loadInfo.legIDs.count() > 0) {
+		initLegInfoAux(root, loadInfo, result);
 	}
 
 	return result;
 }
 
-void FSvgRenderer::initLegInfoAux(QDomElement & element, const QStringList & connectorIDs, const QStringList & legIDs, bool & gotOne)
+void FSvgRenderer::initLegInfoAux(QDomElement & element, const LoadInfo & loadInfo, bool & gotOne)
 {
 	QString id = element.attribute("id");
 	if (!id.isEmpty()) {
-		int ix = legIDs.indexOf(id);
+		int ix = loadInfo.legIDs.indexOf(id);
 		if (ix >= 0) {
 			//DebugDialog::debug("init leg info " + id);
 			//foreach (QString lid, legIDs) {
@@ -349,7 +322,7 @@ void FSvgRenderer::initLegInfoAux(QDomElement & element, const QStringList & con
 
 			element.setTagName("g");			// don't want this element to actually be drawn
 			gotOne = true;
-			ConnectorInfo * connectorInfo = m_connectorInfoHash.value(connectorIDs.at(ix), NULL);
+			ConnectorInfo * connectorInfo = m_connectorInfoHash.value(loadInfo.connectorIDs.at(ix), NULL);
 			if (connectorInfo) {
 				//QString temp;
 				//QTextStream stream(&temp);
@@ -367,7 +340,7 @@ void FSvgRenderer::initLegInfoAux(QDomElement & element, const QStringList & con
 
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		initLegInfoAux(child, connectorIDs, legIDs, gotOne);
+		initLegInfoAux(child, loadInfo, gotOne);
 		child = child.nextSiblingElement();
 	}
 }
@@ -395,13 +368,13 @@ bool FSvgRenderer::initLegInfoAux(QDomElement & element, ConnectorInfo * connect
 	return true;
 }
 
-void FSvgRenderer::initTerminalInfoAux(QDomElement & element, const QStringList & connectorIDs, const QStringList & terminalIDs)
+void FSvgRenderer::initTerminalInfoAux(QDomElement & element, const LoadInfo & loadInfo)
 {
 	QString id = element.attribute("id");
 	if (!id.isEmpty()) {
-		int ix = terminalIDs.indexOf(id);
+		int ix = loadInfo.terminalIDs.indexOf(id);
 		if (ix >= 0) {
-			ConnectorInfo * connectorInfo = m_connectorInfoHash.value(connectorIDs.at(ix), NULL);
+			ConnectorInfo * connectorInfo = m_connectorInfoHash.value(loadInfo.connectorIDs.at(ix), NULL);
 			if (connectorInfo) {
 				connectorInfo->terminalMatrix = TextUtils::elementToMatrix(element);
 			}
@@ -411,17 +384,17 @@ void FSvgRenderer::initTerminalInfoAux(QDomElement & element, const QStringList
 
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		initTerminalInfoAux(child, connectorIDs, terminalIDs);
+		initTerminalInfoAux(child, loadInfo);
 		child = child.nextSiblingElement();
 	}
 }
 
-void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const QStringList & connectorIDs, const QString & filename)
+void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const LoadInfo & loadInfo)
 {
 	QString id = element.attribute("id");
 	if (!id.isEmpty()) {
-		if (connectorIDs.contains(id)) {
-			ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, filename);
+		if (loadInfo.connectorIDs.contains(id)) {
+			ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, loadInfo.filename, loadInfo.parsePaths);
 			m_connectorInfoHash.insert(id, connectorInfo);
 		}
 		// don't return here, might miss other connectors
@@ -429,36 +402,190 @@ void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const QStringList
 
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		initConnectorInfoAux(child, connectorIDs, filename);
+		initConnectorInfoAux(child, loadInfo);
 		child = child.nextSiblingElement();
 	}
 }
 
-ConnectorInfo * FSvgRenderer::initConnectorInfoStruct(QDomElement & connectorElement, const QString & filename) {
+ConnectorInfo * FSvgRenderer::initConnectorInfoStruct(QDomElement & connectorElement, const QString & filename, bool parsePaths) {
 	ConnectorInfo * connectorInfo = new ConnectorInfo();
 	connectorInfo->radius = connectorInfo->strokeWidth = 0;
-	connectorInfo->gotCircle = false;
+	connectorInfo->gotPath = connectorInfo->gotCircle = false;
 
 	if (connectorElement.isNull()) return connectorInfo;
 
 	connectorInfo->matrix = TextUtils::elementToMatrix(connectorElement);
-	initConnectorInfoStructAux(connectorElement, connectorInfo, filename);
+	initConnectorInfoStructAux(connectorElement, connectorInfo, filename, parsePaths);
 	return connectorInfo;
 }
 
-bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorInfo * connectorInfo, const QString & filename) 
+bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorInfo * connectorInfo, const QString & filename, bool parsePaths) 
 {
-	// right now we only handle circles
-	if (element.nodeName().compare("circle") != 0) {
-		QDomElement child = element.firstChildElement();
-		while (!child.isNull()) {
-			if (initConnectorInfoStructAux(child, connectorInfo, filename)) return true;
+    if (element.nodeName().compare("circle") == 0) {
+        return initConnectorInfoCircle(element, connectorInfo, filename);
+    }
 
-			child = child.nextSiblingElement();
-		}
-		return false;
+    if (element.nodeName().compare("path") == 0) {
+        if (!parsePaths) return false;
+        return initConnectorInfoPath(element, connectorInfo, filename);
+    }
+
+	QDomElement child = element.firstChildElement();
+	while (!child.isNull()) {
+		if (initConnectorInfoStructAux(child, connectorInfo, filename, parsePaths)) return true;
+
+		child = child.nextSiblingElement();
 	}
 
+    return false;
+}
+
+bool FSvgRenderer::initConnectorInfoPath(QDomElement & element, ConnectorInfo * connectorInfo, const QString & filename) 
+{
+    QString id = element.attribute("id");
+    if (id.isEmpty()) return false;         // shouldn't be here
+
+    QString stroke = element.attribute("stroke");
+    if (stroke == "none") return false;     // cannot be a circle with a hole in the center
+
+    connectorInfo->gotPath = true;
+    double sw = TextUtils::getStrokeWidth(element, 1);
+
+    if (!stroke.isEmpty()) element.setAttribute("stroke", "black");
+
+    QString fill = element.attribute("fill");
+    if (!fill.isEmpty() && (fill != "none")) element.setAttribute("fill", "black");
+
+    QDomDocument doc = element.ownerDocument();
+    FSvgRenderer renderer;
+    QByteArray byteArray = doc.toByteArray();
+    renderer.finalLoad(byteArray, filename);
+    QRectF bounds = renderer.boundsOnElement(id);	
+
+    static const int dim = 101;
+    int width = dim;
+    int height = dim;
+    if (bounds.width() - bounds.height() / (bounds.width() + bounds.height()) > .01) {
+        height = (int) (float(dim) * bounds.height() / bounds.width());
+    }
+    else if (bounds.height() - bounds.width() / (bounds.width() + bounds.height()) > .01) {
+        width = (int) (float(dim) * bounds.width() / bounds.height());
+    }
+
+    QImage image(width, height, QImage::Format_Mono);
+    image.fill(0xffffffff);
+    QPainter painter;
+    painter.begin(&image);
+    renderer.render(&painter, id);
+    painter.end();
+
+#ifndef QT_NO_DEBUG
+    //image.save(FolderUtils::getUserDataStorePath("") + "/donutcheck.png");
+#endif
+
+    if (!fill.isEmpty()) element.setAttribute("fill", fill);
+    if (!stroke.isEmpty()) element.setAttribute("stroke", stroke);
+
+    //DebugDialog::debug(QString("checking connector path %1").arg(id));
+
+    int lxStart = -1, lxEnd = -1, rxStart = -1, rxEnd = -1;
+    for (int x = 0; x < width; x++) {
+        if (image.pixel(x, height / 2) == 0xff000000) {
+            lxStart = x;
+            break;
+        }
+    }
+    if (lxStart < 0) return false;
+    if (lxStart >= width / 2) return false;        // not an ellipse
+    for (int x = lxStart + 1; x < width; x++) {
+        if (image.pixel(x, height / 2) == 0xff000000) {
+            lxEnd = x;
+        }
+        else break;
+    }
+    if (lxEnd < 0) return false;         
+    if (lxEnd > width / 2) return false;       // not an ellipse
+
+    for (int x = lxEnd + 1; x < width; x++) {
+        if (image.pixel(x, height / 2) == 0xff000000) {
+            rxStart = x;
+            break;
+        }
+    }
+    if (rxStart < 0) return false;
+    if (rxStart < height / 2) return false;        // not an ellipse;
+    for (int x = rxStart + 1; x < width; x++) {
+        if (image.pixel(x, height / 2) == 0xff000000) {
+            rxEnd = x;
+        }
+        else break;
+    }
+    if (rxEnd < 0) return false; 
+    if (qAbs(rxEnd - rxStart - (lxEnd - lxStart)) > 1) return false;   // sides are not symmetric
+
+
+    int lyStart = -1, lyEnd = -1, ryStart = -1, ryEnd = -1;
+    for (int y = 0; y < height; y++) {
+        if (image.pixel(width / 2, y) == 0xff000000) {
+            lyStart = y;
+            break;
+        }
+    }
+    if (lyStart < 0) return false;
+    if (lyStart >= height / 2) return false;        // not an ellipse
+    for (int y = lyStart + 1; y < height; y++) {
+        if (image.pixel(width / 2, y) == 0xff000000) {
+            lyEnd = y;
+        }
+        else break;
+    }
+    if (lyEnd < 0) return false;         
+    if (lyEnd > height / 2) return false;       // not an ellipse
+
+    for (int y = lyEnd + 1; y < height; y++) {
+        if (image.pixel(width / 2, y) == 0xff000000) {
+            ryStart = y;
+            break;
+        }
+    }
+    if (ryStart < 0) return false;
+    if (ryStart < height / 2) return false;        // not an ellipse
+    for (int y = ryStart + 1; y < height; y++) {
+        if (image.pixel(width / 2, y) == 0xff000000) {
+            ryEnd = y;
+        }
+        else break;
+    }
+    if (ryEnd < 0) return false;         
+    if (qAbs((ryEnd - ryStart) - (lyEnd - lyStart)) > 1) return false;  // tops not symmetric
+
+    if (qAbs((rxStart - lxEnd) - (ryStart - lyEnd)) > 1) return false;  // inner drill hole is not circular
+
+    double r = (qMin(bounds.width(), bounds.height()) -  sw) / 2;
+
+	QMatrix matrix = TextUtils::elementToMatrix(element);
+	if (!matrix.isIdentity()) {
+		QRectF r1(0,0,r,r);
+		QRectF r2 = matrix.mapRect(r1);
+		if (r2.width() != r1.width()) {
+			r = r2.width();
+			sw = sw * r2.width() / r1.width();
+		}
+	}
+
+	connectorInfo->radius = r;
+	connectorInfo->strokeWidth = sw;
+    connectorInfo->gotCircle = true;
+
+    //DebugDialog::debug(QString("got connector path %1").arg(id));
+
+    return true;
+}
+
+bool FSvgRenderer::initConnectorInfoCircle(QDomElement & element, ConnectorInfo * connectorInfo, const QString & filename) 
+{
+    Q_UNUSED(filename);
+
 	bool ok;
 	element.attribute("cx").toDouble(&ok);
 	if (!ok) return false;
@@ -469,35 +596,7 @@ bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorIn
 	double r = element.attribute("r").toDouble(&ok);
 	if (!ok) return false;
 
-	double sw = element.attribute("stroke-width").toDouble(&ok);	
-	if (!ok) {
-        QDomElement parent = element.parentNode().toElement();
-        while (!parent.isNull()) {
-            sw = element.attribute("stroke-width").toDouble(&ok);
-            if (ok) {
-                break;
-            }
-
-            parent = parent.parentNode().toElement();
-        }
-
-        if (!ok) {
-            QString text;
-            QTextStream stream(&text);
-            element.save(stream, 0);
-            //DebugDialog::debug(QString("no circle stroke width set in %1: %2").arg(filename).arg(text));
-            element.setAttribute("stroke-width", 1);
-            sw = 1;
-
-		    //QString strokewidth("stroke-width");
-		    //QString s = element.attribute("style");
-		    //SvgFileSplitter::fixStyleAttribute(connectorElement, s, strokewidth);
-		    //sw = connectorElement.attribute("stroke-width").toDouble(&ok);
-		    //if (!ok) {
-			    //return false;
-		    //}
-        }
-	}
+    double sw = TextUtils::getStrokeWidth(element, 1);
 
 	QMatrix matrix = TextUtils::elementToMatrix(element);
 	if (!matrix.isIdentity()) {
@@ -521,17 +620,15 @@ ConnectorInfo * FSvgRenderer::getConnectorInfo(const QString & connectorID) {
 	return m_connectorInfoHash.value(connectorID, &VanillaConnectorInfo);
 }
 
-bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPoint) {
+bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPoint, ViewLayer::ViewLayerPlacement viewLayerPlacement) {
 
 	if (svgIdLayer == NULL) return false;
 
-	if (svgIdLayer->m_processed) {
+	if (svgIdLayer->processed(viewLayerPlacement)) {
 		// hybrids are not visible in some views
-		return svgIdLayer->m_svgVisible || svgIdLayer->m_hybrid;
+		return svgIdLayer->svgVisible(viewLayerPlacement) || svgIdLayer->m_hybrid;
 	}
 
-	svgIdLayer->m_processed = true;
-
 	QString connectorID = svgIdLayer->m_svgId;
 
 	// boundsOnElement seems to include any matrix on the element itself.
@@ -539,7 +636,7 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 	QRectF bounds = this->boundsOnElement(connectorID);	
 
 	if (bounds.isNull() && !svgIdLayer->m_hybrid) {		// hybrids can have zero size
-		svgIdLayer->m_svgVisible = false;		
+		svgIdLayer->setInvisible(viewLayerPlacement);		
 		DebugDialog::debug("renderer::setupconnector: null bounds");
 		return false;
 	}
@@ -561,17 +658,11 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 				bounds);
 	*/
 
-	if (connectorInfo && connectorInfo->gotCircle) {
-		svgIdLayer->m_radius = connectorInfo->radius * defaultSizeF.width() / viewBox.width();
-		svgIdLayer->m_strokeWidth = connectorInfo->strokeWidth * defaultSizeF.width() / viewBox.width();
-		//bounds = connectorInfo->cbounds;
-	}
-
 	
 	/*DebugDialog::debug(QString("identity matrix %11 %1 %2, viewbox: %3 %4 %5 %6, bounds: %7 %8 %9 %10, size: %12 %13").arg(m_modelPart->title()).arg(connectorSharedID())
 					   .arg(viewBox.x()).arg(viewBox.y()).arg(viewBox.width()).arg(viewBox.height())
 					   .arg(bounds.x()).arg(bounds.y()).arg(bounds.width()).arg(bounds.height())
-					   .arg(viewIdentifier)
+					   .arg(viewID)
 					   .arg(defaultSizeF.width()).arg(defaultSizeF.height())
 	);
 	*/
@@ -580,7 +671,26 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 	// might be a qt problem.
 	//QMatrix matrix0 = connectorInfo->matrix * this->matrixForElement(connectorID);  
 	//QRectF r1 = matrix0.mapRect(bounds);
-	QRectF r1 = this->matrixForElement(connectorID).mapRect(bounds);
+
+    QMatrix elementMatrix = this->matrixForElement(connectorID);
+	QRectF r1 = elementMatrix.mapRect(bounds);
+
+	if (connectorInfo != NULL) {
+        if (connectorInfo->gotCircle) {
+            QLineF l(0,0,connectorInfo->radius, 0);
+            QLineF lm = elementMatrix.map(l);
+		    svgIdLayer->m_radius = lm.length() * defaultSizeF.width() / viewBox.width();
+
+            QLineF k(0,0,connectorInfo->strokeWidth, 0);
+            QLineF km = elementMatrix.map(k);
+		    svgIdLayer->m_strokeWidth = km.length() * defaultSizeF.width() / viewBox.width();
+		    //bounds = connectorInfo->cbounds;
+        }
+        if (connectorInfo->gotPath) {
+            svgIdLayer->m_path = true;
+        }
+	}
+
 
 	/*
 	svgIdLayer->m_rect.setRect(r1.x() * defaultSize.width() / viewBox.width(), 
@@ -588,16 +698,18 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 							   r1.width() * defaultSize.width() / viewBox.width(), 
 							   r1.height() * defaultSize.height() / viewBox.height());
 	*/
-	svgIdLayer->m_rect.setRect(r1.x() * defaultSizeF.width() / viewBox.width(), 
+
+    QRectF svgRect(r1.x() * defaultSizeF.width() / viewBox.width(), 
 							   r1.y() * defaultSizeF.height() / viewBox.height(), 
 							   r1.width() * defaultSizeF.width() / viewBox.width(), 
 							   r1.height() * defaultSizeF.height() / viewBox.height());
 
-	svgIdLayer->m_svgVisible = !bounds.isNull();
 	//if (!svgIdLayer->m_svgVisible) {
 		//DebugDialog::debug("not vis");
 	//}
-	svgIdLayer->m_point = calcTerminalPoint(svgIdLayer->m_terminalId, svgIdLayer->m_rect, ignoreTerminalPoint, viewBox, connectorInfo->terminalMatrix);
+	QPointF terminal = calcTerminalPoint(svgIdLayer->m_terminalId, svgRect, ignoreTerminalPoint, viewBox, connectorInfo->terminalMatrix);
+
+    svgIdLayer->setPointRect(viewLayerPlacement, terminal, svgRect, !bounds.isNull());
 	calcLeg(svgIdLayer, viewBox, connectorInfo);
 	
 	return true;
@@ -629,9 +741,9 @@ void FSvgRenderer::calcLeg(SvgIdLayer * svgIdLayer, const QRectF & viewBox, Conn
 	double y1 = p1.y() * defaultSizeF.height() / viewBox.height();
 	double x2 = p2.x() * defaultSizeF.width() / viewBox.width();
 	double y2 = p2.y() * defaultSizeF.height() / viewBox.height();
-	QPointF center = viewBox.center();
-	double d1 = ((x1 - center.x()) * (x1 - center.x())) + ((y1 - center.y()) * (y1 - center.y()));
-	double d2 = ((x2 - center.x()) * (x2 - center.x())) + ((y2 - center.y()) * (y1 - center.y()));
+	QPointF center(defaultSizeF.width() / 2, defaultSizeF.height() / 2);
+	double d1 = GraphicsUtils::distanceSqd(QPointF(x1, y1), center);
+	double d2 = GraphicsUtils::distanceSqd(QPointF(x2, y2), center);
 
 	// find the end which is closer to the center of the viewBox (which shouldn't include the leg)
 	if (d1 <= d2) {
@@ -653,16 +765,17 @@ QPointF FSvgRenderer::calcTerminalPoint(const QString & terminalId, const QRectF
 		return terminalPoint;
 	}
 
+    if (!this->elementExists(terminalId)) {
+        DebugDialog::debug(QString("missing expected terminal point element %1").arg(terminalId));
+        return terminalPoint;
+    }
+
 	QRectF tBounds = this->boundsOnElement(terminalId);
 	if (tBounds.isNull()) {
 		return terminalPoint;
 	}
 
 	QSizeF defaultSizeF = this->defaultSizeF();
-	if (tBounds.width() >= defaultSizeF.width() && tBounds.height() >= defaultSizeF.height()) {
-		return terminalPoint;
-	}
-
 	//DebugDialog::debug(	QString("terminal %5 rect %1,%2,%3,%4").arg(tBounds.x()).
 										//arg(tBounds.y()).
 										//arg(tBounds.width()).
@@ -684,14 +797,13 @@ QPointF FSvgRenderer::calcTerminalPoint(const QString & terminalId, const QRectF
 	return terminalPoint;
 }
 
-QList<SvgIdLayer *> FSvgRenderer::setUpNonConnectors() {
+QList<SvgIdLayer *> FSvgRenderer::setUpNonConnectors(ViewLayer::ViewLayerPlacement viewLayerPlacement) {
 
 	QList<SvgIdLayer *> list;
 	if (m_nonConnectorInfoHash.count() == 0) return list;
 
 	foreach (QString nonConnectorID, m_nonConnectorInfoHash.keys()) {
-		SvgIdLayer * svgIdLayer = new SvgIdLayer();
-		svgIdLayer->m_processed = true;
+		SvgIdLayer * svgIdLayer = new SvgIdLayer(ViewLayer::PCBView);
 		svgIdLayer->m_svgId = nonConnectorID;
 		QRectF bounds = this->boundsOnElement(nonConnectorID);
 		if (bounds.isNull()) {
@@ -719,10 +831,9 @@ QList<SvgIdLayer *> FSvgRenderer::setUpNonConnectors() {
 		//QMatrix matrix0 = connectorInfo->matrix * this->matrixForElement(nonConnectorID);  
 		//QRectF r1 = matrix0.mapRect(bounds);
 		QRectF r1 = this->matrixForElement(nonConnectorID).mapRect(bounds);
-		svgIdLayer->m_rect.setRect(r1.x() * defaultSize.width() / viewBox.width(), r1.y() * defaultSize.height() / viewBox.height(), r1.width() * defaultSize.width() / viewBox.width(), r1.height() * defaultSize.height() / viewBox.height());
-		svgIdLayer->m_point = svgIdLayer->m_rect.center() - svgIdLayer->m_rect.topLeft();
-		svgIdLayer->m_svgVisible = true;
-
+        QRectF svgRect(r1.x() * defaultSize.width() / viewBox.width(), r1.y() * defaultSize.height() / viewBox.height(), r1.width() * defaultSize.width() / viewBox.width(), r1.height() * defaultSize.height() / viewBox.height());
+        QPointF center = svgRect.center() - svgRect.topLeft();
+        svgIdLayer->setPointRect(viewLayerPlacement, center, svgRect, true);
 		list.append(svgIdLayer);
 	}
 
