@@ -62,7 +62,7 @@ AboutBox::AboutBox(QWidget *parent)
 	// Big Icon
 	QLabel *logoShield = new QLabel(this);
 	logoShield->setPixmap(QPixmap(":/resources/images/AboutBoxLogoShield.png"));
-	logoShield->setGeometry(131, 8, 128, 128);
+    logoShield->setGeometry(17, 8, 356, 128);
 
 	// Version String
 	QLabel *versionMain = new QLabel(this);
@@ -86,6 +86,7 @@ AboutBox::AboutBox(QWidget *parent)
 	versionMain->setFont(smallFont);
 	versionMain->setGeometry(45, 150, 300, 20);
 	versionMain->setAlignment(Qt::AlignBottom | Qt::AlignHCenter);
+    versionMain->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
 	// Link to website
 	QLabel *linkToFritzing = new QLabel(this);
@@ -121,7 +122,8 @@ AboutBox::AboutBox(QWidget *parent)
 	copyrightFHP->setText(tr("<b>2007-%1 Fachhochschule Potsdam</b>").arg(Version::year()));
 	copyrightFHP->setFont(extraSmallFont);
 	copyrightFHP->setGeometry(30 + w, 414, AboutWidth - 30 - 30 - w - w, 16);
-	copyrightFHP->setAlignment(Qt::AlignBottom | Qt::AlignHCenter);
+    copyrightFHP->setAlignment(Qt::AlignBottom | Qt::AlignHCenter);
+
 
 	// Scrolling Credits Text
 
@@ -135,9 +137,9 @@ QString("<br /><br /><br /><br /><br /><br /><br /><br /><br />") +
 	tr("Zach Eveland, Dirk van Oosterbosch, ") +
 	tr("Jonathan Cohen, Marcus Paeschke, Omer Yosha, ") +
 	tr("Travis Robertson, Stefan Hermann, Brendan Howell, ") +
-	tr("Mariano Crowe, Johannes Landstorfer, ") +
-	tr("Jenny Chowdhury, Lionel Michel, Jannis Leidel, ") +
-	tr("Bryant Mairs, Uleshka Asher, and Daniel Tzschentke. ") +
+    tr("Mariano Crowe, Johannes Landstorfer, ") +
+    tr("Jenny Chowdhury, Lionel Michel, Jannis Leidel, ") +
+    tr("Bryant Mairs, Uleshka Asher, and Daniel Tzschentke. ") +
 "</p>" +
 
 "<p>" +
@@ -165,6 +167,7 @@ QString("<br /><br /><br /><br /><br /><br /><br /><br /><br />") +
     tr("to Alexander Kaltsas for the Greek translation, " ) +
     tr("to Lionel Michel and Yvan Kloster for the French translation, " ) +
     tr("to Cihan Mete Bahad&#x0131;r for the Turkish translation, " ) +
+    tr("to Nikolay Stankov for the Bulgarian translation, " ) +
    
 	tr("and to Arthur Zanona, Nuno Pessanha Santos, Leandro Nunes, and Gabriel Ferreira for the Portuguese (Brazilian) translation. " ) +
 "</p>" +
@@ -174,7 +177,7 @@ QString("<br /><br /><br /><br /><br /><br /><br /><br /><br />") +
 	tr("MWFK Brandenburg, the sponsorship of the Design ") +
 	tr("Department of Bauhaus-University Weimar, ") +
 	tr("IxDS, an anonymous donor, Parallax, Picaxe, Sparkfun, ") +
-	tr("and from each purchase of a Fritzing Starter Kit.") +
+	tr("and from each purchase of a Fritzing Starter Kit or a PCB from Fritzing Fab.") +
 "</p>" +
 
 "<p>" +
@@ -188,10 +191,10 @@ tr("<br /><br /><br /><br /><br /><br /><br /><br />");
 	QPixmap fadepixmap(":/resources/images/aboutbox_scrollfade.png");
 
 	m_expandingLabel = new ExpandingLabel(this, AboutWidth);
+    m_expandingLabel->setObjectName("aboutText");
 	m_expandingLabel->setLabelText(data);
 	m_expandingLabel->setFont(smallFont);
 	m_expandingLabel->setGeometry(0, AboutText, AboutWidth, fadepixmap.height());
-	m_expandingLabel->setStyleSheet("border: 0px; background-color: transparent; margin-top: 0px; margin-bottom: 0px;");
 	
 	// setAlignment only aligns the "current paragraph"
 	// the QTextCursor code aligns all paragraphs
