@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6269 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-09 11:22:00 +0200 (Thu, 09 Aug 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -37,23 +37,23 @@ $Date: 2012-08-09 11:22:00 +0200 (Thu, 09 Aug 2012) $
 static QStringList Spacings;
 
 static int MinSipPins = 2;
-static int MaxSipPins = 64;
+static int MaxSipPins = 128;
 static int MinDipPins = 4;
-static int MaxDipPins = 64;
+static int MaxDipPins = 128;
 
 //////////////////////////////////////////////////
 
-Dip::Dip( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: MysteryPart(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+Dip::Dip( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: MysteryPart(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 }
 
 Dip::~Dip() {
 }
 
-bool Dip::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget)
+bool Dip::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide)
 {
-	bool result = MysteryPart::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	bool result = MysteryPart::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 	if (prop.compare("chip label", Qt::CaseInsensitive) == 0) {
 		returnProp = tr("chip label");
 	}
@@ -197,7 +197,7 @@ QString Dip::makeSchematicSvg(const QStringList & labels)
 					"width='%4in' height='%1in' viewBox='0 0 %5 %2' >\n"
 					"<g id='schematic' >\n"
 					"<rect x='315' y='15' fill='none' width='%6' height='%3' stroke='#000000' stroke-linejoin='round' stroke-linecap='round' stroke-width='30' />\n"
-					"<text id='label' x='%7' y='465' font-family='DroidSans' stroke='none' fill='#000000' text-anchor='middle' font-size='235' >IC</text>\n");
+					"<text id='label' x='%7' y='465' font-family='Droid Sans' stroke='none' fill='#000000' text-anchor='middle' font-size='235' >IC</text>\n");
 
 	QString svg = header
 				.arg(totalHeight / 1000)
@@ -212,13 +212,13 @@ QString Dip::makeSchematicSvg(const QStringList & labels)
 	QString repeatL("<line fill='none' stroke='#000000' stroke-linejoin='round' stroke-linecap='round' stroke-width='30' x1='15' y1='%1' x2='300' y2='%1'  />\n"
 					"<rect x='0' y='%2' fill='none' width='300' height='30' stroke='none' id='connector%3pin' stroke-width='0' />\n"
 					"<rect x='0' y='%2' fill='none' width='30' height='30' stroke='none' id='connector%3terminal' stroke-width='0' />\n"
-					"<text id='label%3' x='390' y='%4' font-family='DroidSans' stroke='none' fill='#000000' text-anchor='start' font-size='%6' >%5</text>\n");
+					"<text id='label%3' x='390' y='%4' font-family='Droid Sans' stroke='none' fill='#000000' text-anchor='start' font-size='%6' >%5</text>\n");
 
 	
 	QString repeatR("<line fill='none' stroke='#000000' stroke-linejoin='round' stroke-linecap='round' stroke-width='30' x1='%7' y1='%1' x2='%8' y2='%1'  />\n"
 					"<rect x='%9' y='%2' fill='none' width='300' height='30' id='connector%3pin' stroke='none' stroke-width='0' />\n"
 					"<rect x='%10' y='%2' fill='none' width='30' height='30' id='connector%3terminal' stroke='none' stroke-width='0' />\n"
-					"<text id='label%3' x='%11' y='%4' font-family='DroidSans' stroke='none' fill='#000000' text-anchor='end' font-size='%6' >%5</text>\n");
+					"<text id='label%3' x='%11' y='%4' font-family='Droid Sans' stroke='none' fill='#000000' text-anchor='end' font-size='%6' >%5</text>\n");
 
 
 	int y = 300;
@@ -309,7 +309,7 @@ QString Dip::makeBreadboardDipSvg(const QString & expectedFileName)
 					"<path id='slot' fill='#262626' d='M0.56,{{13.58}}v5.83c1.47-0.17,2.62-1.4,2.62-2.92C3.18,{{14.97}},2.04,{{13.75}},0.56,{{13.58}}z'/>\n"
 					"<path id='cover' fill='#303030' d='M0.75,5.46V{{11.45}}c2.38,0.45,4.19,2.53,4.19,5.04c0,2.51-1.8,4.6-4.19,5.05V{{21.55}}h5.0V5.46H0.75z'/>\n"
 					"<circle fill='#212121' cx='6.5' cy='[23.47]' r='2.06'/>\n"
-					"<text id='label' x='6.5' y='{{16.5}}' fill='#e6e6e6' stroke='none' font-family='OCRA' text-anchor='start' font-size='8' >IC</text>\n"
+					"<text id='label' x='6.5' y='{{16.5}}' fill='#e6e6e6' stroke='none' font-family='%5' text-anchor='start' font-size='8' >IC</text>\n"
 
 					"<rect id='connector0pin' x='3.5' y='[28.66]' fill='#8C8C8C' width='3' height='4.34'/>\n"
 					"<rect id='connector0terminal' x='3.5' y='[30.0]' fill='#8C8C8C' width='3' height='3'/>\n"
@@ -336,7 +336,12 @@ QString Dip::makeBreadboardDipSvg(const QString & expectedFileName)
 	// header came from a 300mil dip, so base case is spacing - (increment * 3)
 
 	header = TextUtils::incrementTemplateString(header, 1, spacing - (increment * 3), TextUtils::incMultiplyPinFunction, TextUtils::noCopyPinFunction, NULL);
-	header = header.arg(TextUtils::getViewBoxCoord(header, 3) / 100.0).arg(pins - 1).arg((pins / 2) - 1).arg(pins / 2);
+	header = header
+        .arg(TextUtils::getViewBoxCoord(header, 3) / 100.0)
+        .arg(pins - 1)
+        .arg((pins / 2) - 1)
+        .arg(pins / 2)
+        .arg(OCRAFontName);
 	header.replace("{{", "[");
 	header.replace("}}", "]");
 	header = TextUtils::incrementTemplateString(header, 1, (spacing - (increment * 3)) / 2, TextUtils::incMultiplyPinFunction, TextUtils::noCopyPinFunction, NULL);
@@ -361,7 +366,7 @@ QString Dip::makeBreadboardDipSvg(const QString & expectedFileName)
 }
 
 bool Dip::changePinLabels(bool singleRow, bool sip) {
-	if (m_viewIdentifier != ViewIdentifierClass::SchematicView) return true;
+	if (m_viewID != ViewLayer::SchematicView) return true;
 
 	bool hasLocal = false;
 	QStringList labels = getPinLabels(hasLocal);
@@ -376,7 +381,17 @@ bool Dip::changePinLabels(bool singleRow, bool sip) {
 		svg = Dip::makeSchematicSvg(labels);
 	}
 
-	resetRenderer(svg);
+    QString chipLabel = modelPart()->localProp("chip label").toString();
+    if (!chipLabel.isEmpty()) {
+        svg =TextUtils::replaceTextElement(svg, "label", chipLabel);
+    }
+
+    QTransform  transform = untransform();
+
+	resetLayerKin(svg);
+    resetConnectors();
+
+    retransform(transform);
 
 	return true;
 }
@@ -385,11 +400,7 @@ void Dip::addedToScene(bool temporary)
 {
     MysteryPart::addedToScene(temporary);
 	if (this->isDIP()) {
-		bool hasLocal = false;
-		QStringList labels = getPinLabels(hasLocal);
-		if (hasLocal) {
-			resetConnectors();
-		}
+		resetConnectors();
 	}
 }
 
