@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6218 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
+$Revision: 6980 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -32,6 +32,7 @@ $Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
 #include "../svg/svgfilesplitter.h"
 #include "../svg/groundplanegenerator.h"
 #include "../sketch/infographicsview.h"
+#include "../layerattributes.h"
 
 #include <QPainterPathStroker>
 
@@ -65,17 +66,17 @@ void loadIconSvg()
 
 /////////////////////////////////////////////////////////
 
-GroundPlane::GroundPlane( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
-	: PaletteItem(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, doLabel)
+GroundPlane::GroundPlane( ModelPart * modelPart, ViewLayer::ViewID viewID,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
+	: PaletteItem(modelPart, viewID,  viewGeometry,  id, itemMenu, doLabel)
 {
 	m_connector0 = NULL;
 }
 
-bool GroundPlane::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool GroundPlane::setUpImage(ModelPart * modelPart, const LayerHash & viewLayers, LayerAttributes & layerAttributes)
 {
-	bool result = PaletteItem::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
+	bool result = PaletteItem::setUpImage(modelPart, viewLayers, layerAttributes);
 
-	if (doConnectors) {
+	if (layerAttributes.doConnectors) {
 		foreach (ConnectorItem * item, cachedConnectorItems()) {
 			// there is only one
 			m_connector0 = item;
@@ -92,28 +93,18 @@ void GroundPlane::saveParams() {
 void GroundPlane::getParams() {
 }
 
-QString GroundPlane::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
+QString GroundPlane::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) 
 {
 	QString xml = "";
 	if (viewLayerID == ViewLayer::GroundPlane0 || viewLayerID == ViewLayer::GroundPlane1) {
 		xml = prop("svg");
 
 		if (!xml.isEmpty()) {
-			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-			SvgFileSplitter splitter;
-			bool result = splitter.splitString(xml, xmlName);
-			if (!result) {
-				return ___emptyString___;
-			}
-			result = splitter.normalize(dpi, xmlName, blackOnly);
-			if (!result) {
-				return ___emptyString___;
-			}
-			return splitter.elementString(xmlName);
+            return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi, factor);
 		}
 	}
 
-	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 }
 
 ConnectorItem * GroundPlane::connector0() {
@@ -121,8 +112,8 @@ ConnectorItem * GroundPlane::connector0() {
 }
 
 bool GroundPlane::hasCustomSVG() {
-	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
+	switch (m_viewID) {
+		case ViewLayer::PCBView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -167,7 +158,7 @@ void GroundPlane::setSvg(const QString & svg) {
 
 void GroundPlane::setSvgAux(const QString & svg) {
 	if (svg.isEmpty()) return;
-	if (m_viewIdentifier == ViewIdentifierClass::BreadboardView || m_viewIdentifier == ViewIdentifierClass::SchematicView) return;
+	if (m_viewID == ViewLayer::BreadboardView || m_viewID == ViewLayer::SchematicView) return;
 
 	QString xmlName = ViewLayer::viewLayerXmlNameFromID(m_viewLayerID);
 	SvgFileSplitter	splitter;
@@ -194,9 +185,9 @@ bool GroundPlane::hasPartLabel() {
 	return false;
 }
 
-void GroundPlane::loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerSpec viewLayerSpec) {
+void GroundPlane::loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerPlacement viewLayerPlacement) {
 	Q_UNUSED(viewLayers);
-	Q_UNUSED(viewLayerSpec);
+	Q_UNUSED(viewLayerPlacement);
 	// GroundPlane is only on one side or another, not both
 }
 
@@ -263,11 +254,11 @@ QPainterPath GroundPlane::shape() const
     return PaletteItemBase::shape();
 }
 
-ViewIdentifierClass::ViewIdentifier GroundPlane::useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier vid, bool) 
+ViewLayer::ViewID GroundPlane::useViewIDForPixmap(ViewLayer::ViewID vid, bool) 
 {
-    if (vid == ViewIdentifierClass::PCBView) {
-        return ViewIdentifierClass::IconView;
+    if (vid == ViewLayer::PCBView) {
+        return ViewLayer::IconView;
     }
 
-    return ViewIdentifierClass::UnknownView;
+    return ViewLayer::UnknownView;
 }
