@@ -108,8 +108,8 @@ QHash<QString, QString> ItemBase::TranslatedPropertyNames;
 
 QPointer<ReferenceModel> ItemBase::TheReferenceModel = NULL;
 
-QString ItemBase::partInstanceDefaultTitle;
-QList<ItemBase *> ItemBase::emptyList;
+QString ItemBase::PartInstanceDefaultTitle;
+const QList<ItemBase *> ItemBase::emptyList;
 
 const QColor ItemBase::hoverColor(0,0,0);
 const double ItemBase::hoverOpacity = .20;
@@ -320,7 +320,7 @@ void ItemBase::initNames() {
 
 	}
 
-	partInstanceDefaultTitle = tr("Part");
+	PartInstanceDefaultTitle = tr("Part");
 
 	QSettings settings;
 	QString colorName = settings.value("ConnectedColor").toString();
@@ -1062,7 +1062,7 @@ void ItemBase::setDefaultTooltip() {
 			return;
 		}
 
-		QString title = ItemBase::partInstanceDefaultTitle;
+		QString title = ItemBase::PartInstanceDefaultTitle;
 		QString inst = instanceTitle();
 		if(!inst.isNull() && !inst.isEmpty()) {
 			title = inst;
@@ -1187,11 +1187,12 @@ void ItemBase::partLabelChanged(const QString & newText) {
 
 bool ItemBase::isPartLabelVisible() {
 	if (m_partLabel == NULL) return false;
+	if (!hasPartLabel()) return false;
 	if (!m_partLabel->initialized()) return false;
+
 	return m_partLabel->isVisible();
 }
 
-
 void ItemBase::clearPartLabel() {
 	m_partLabel = NULL;
 }
@@ -1305,12 +1306,19 @@ void ItemBase::flipItem(Qt::Orientations orientation) {
 }
 
 void ItemBase::transformItem(const QTransform & currTransf, bool includeRatsnest) {
-	//DebugDialog::debug(QString("\ttransform item %1").arg((long) this, 0, 16));
+    //debugInfo("transform item " + TextUtils::svgMatrix(currTransf));
+
+    QTransform trns = getViewGeometry().transform();
+    //debugInfo("\t" + TextUtils::svgMatrix(trns));
+
+    
 
 	if (m_hasRubberBandLeg) {
 		prepareGeometryChange();
 	}
 	QRectF rect = this->boundingRectWithoutLegs();
+
+    //debugInfo(QString("\t bounding rect w:%1, h:%2").arg(rect.width()).arg(rect.height()));
 	double x = rect.width() / 2.0;
 	double y = rect.height() / 2.0;
 	QTransform transf = QTransform().translate(-x, -y) * currTransf * QTransform().translate(x, y);
@@ -1320,8 +1328,10 @@ void ItemBase::transformItem(const QTransform & currTransf, bool includeRatsnest
         QList<ConnectorItem *> already;
 		updateConnections(includeRatsnest, already);
 	}
-	//QTransform t = this->transform();
-	//DebugDialog::debug(QString("matrix m11:%1 m12:%2 m21:%3 m22:%4").arg(t.m11()).arg(t.m12()).arg(t.m21()).arg(t.m22()));
+
+    trns = getViewGeometry().transform();
+    //debugInfo("\t" + TextUtils::svgMatrix(trns));
+
 	update();
 }
 
@@ -1860,13 +1870,9 @@ void ItemBase::updateConnectors()
 {
 	if (!isEverVisible()) return;
 
-	// assumes all connectors have previously been initialized unmarked;
-	//int count = 0;
+    QList<ConnectorItem *> visited;
 	foreach(ConnectorItem * connectorItem, cachedConnectorItems()) {
-		if (connectorItem->marked()) continue;
-
-		connectorItem->restoreColor(false, 0, false);
-		//count++;
+		connectorItem->restoreColor(visited);
 	}
 	//DebugDialog::debug(QString("set up connectors restore:%1").arg(count));
 }
@@ -1929,7 +1935,7 @@ void ItemBase::debugInfo(const QString & msg) const
 
 void ItemBase::debugInfo2(const QString & msg) const
 {
-	DebugDialog::debug(QString("%1 ti:'%2' id:%3 it:'%4' vid:%9 vlid:%5 spec:%6 z:%10 flg:%7 gi:%8")
+	DebugDialog::debug(QString("%1 ti:'%2' id:%3 it:'%4' vid:%9 vlid:%5 spec:%6 x:%11 y:%12 z:%10 flg:%7 gi:%8")
 		.arg(msg)
 		.arg(this->title())
 		.arg(this->id())
@@ -1940,6 +1946,8 @@ void ItemBase::debugInfo2(const QString & msg) const
 		.arg((long) dynamic_cast<const QGraphicsItem *const>(this), 0, 16)
 		.arg(m_viewID)
         .arg(this->zValue())
+        .arg(this->pos().x())
+        .arg(this->pos().y())
 	);
 
 	/*
@@ -2092,6 +2100,7 @@ void ItemBase::setSharedRendererEx(FSvgRenderer * newRenderer) {
 		update();
 	}
 	m_size = newRenderer->defaultSizeF();
+    //debugInfo(QString("set size %1, %2").arg(m_size.width()).arg(m_size.height()));
 }
 
 bool ItemBase::reloadRenderer(const QString & svg, bool fastLoad) {
@@ -2124,6 +2133,8 @@ bool ItemBase::resetRenderer(const QString & svg, QString & newSvg) {
     FSvgRenderer * newRenderer = new FSvgRenderer();
     bool result = newRenderer->loadSvgString(svg, newSvg);
     if (result) {
+        //DebugDialog::debug("reloaded");
+        //DebugDialog::debug(newSvg);
         setSharedRendererEx(newRenderer);
     }
     else {
@@ -2367,7 +2378,7 @@ void ItemBase::createShape(LayerAttributes & layerAttributes) {
     QSize imgSize(qCeil(sourceRes.width()), qCeil(sourceRes.height()));
     QImage image(imgSize, QImage::Format_Mono);
     image.fill(0xffffffff);
-    GraphicsUtils::renderOne(&doc, &image, sourceRes);
+    renderOne(&doc, &image, sourceRes);
     QBitmap bitmap = QBitmap::fromImage(image);
     QRegion region(bitmap);
     m_selectionShape.addRegion(region);
@@ -2387,3 +2398,14 @@ void ItemBase::setTransform2(const QTransform & transform)
 {
     setTransform(transform);
 }
+
+void ItemBase::renderOne(QDomDocument * masterDoc, QImage * image, const QRectF & renderRect) {
+    QByteArray byteArray = masterDoc->toByteArray();
+	QSvgRenderer renderer(byteArray);
+	QPainter painter;
+	painter.begin(image);
+	painter.setRenderHint(QPainter::Antialiasing, false);
+    painter.setRenderHint(QPainter::SmoothPixmapTransform, false);
+	renderer.render(&painter, renderRect);
+	painter.end();
+}
