@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6994 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-27 14:25:24 +0200 (Sa, 27. Apr 2013) $
 
 ********************************************************************/
 
@@ -34,33 +34,36 @@ class JumperItem : public PaletteItem
 	Q_OBJECT
 
 public:
-	JumperItem( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier,  const ViewGeometry & , long id, QMenu* itemMenu, bool doLabel); 
+	JumperItem( ModelPart * modelPart, ViewLayer::ViewID,  const ViewGeometry & , long id, QMenu* itemMenu, bool doLabel); 
 	~JumperItem();
 
     QPainterPath shape() const;
     QPainterPath hoverShape() const;
- 	bool setUpImage(ModelPart* modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, bool doConnectors, LayerAttributes &, QString & error);
+ 	bool setUpImage(ModelPart* modelPart, const LayerHash & viewLayers, LayerAttributes &);
 	void saveParams();
 	void getParams(QPointF & pos, QPointF & c0, QPointF & c1);
 	void resize(QPointF pos, QPointF c0, QPointF c1);
 	void resize(QPointF p0, QPointF p1);   
 	QSizeF footprintSize();
-	QString retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
+	QString retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor);
 	bool getAutoroutable();
 	void setAutoroutable(bool);
 	class ConnectorItem * connector0();
 	class ConnectorItem * connector1();
 	bool hasCustomSVG();
 	bool inDrag();
-	void loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerSpec);
+	void loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerPlacement);
 	PluralType isPlural();
 	void addedToScene(bool temporary);
-	void rotateItem(double degrees);
+	void rotateItem(double degrees, bool includeRatsnest);
 	void calcRotation(QTransform & rotation, QPointF center, ViewGeometry &);
 	QPointF dragOffset();
 	void saveInstanceLocation(QXmlStreamWriter & streamWriter);
 	bool hasPartNumberProperty();
 	QRectF boundingRect() const;
+	bool mousePressEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *);
+	void mouseMoveEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *);
+	void mouseReleaseEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *);
 
 protected:
 	void resize();
@@ -71,10 +74,10 @@ protected:
 	void resizeAux(double r0x, double r0y, double r1x, double r1y);
 	void rotateEnds(QTransform & rotation, QPointF & tc0, QPointF & tc1); 
 	QPointF calcPos(QPointF p0, QPointF p1);
-	void initialResize(ViewIdentifierClass::ViewIdentifier);
+	void initialResize(ViewLayer::ViewID);
 	void paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 	void paintSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
-    ViewIdentifierClass::ViewIdentifier useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier, bool swappingEnabled);
+    ViewLayer::ViewID useViewIDForPixmap(ViewLayer::ViewID, bool swappingEnabled);
 
 signals:
 	void alignMe(JumperItem *, QPointF & p); 
@@ -94,6 +97,7 @@ protected:
 	QPointF m_itemPos;
 	QPointF m_itemC0;
 	QPointF m_itemC1;
+    QPointer<PaletteItemBase> m_originalClickItem;
 };
 
 #endif
