@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6269 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-09 11:22:00 +0200 (Thu, 09 Aug 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -35,7 +35,7 @@ $Date: 2012-08-09 11:22:00 +0200 (Thu, 09 Aug 2012) $
 #include "partlabel.h"
 #include "pinheader.h"
 #include "../connectors/connectoritem.h"
-
+#include "../svg/svgfilesplitter.h"
 
 #include <QDomNodeList>
 #include <QDomDocument>
@@ -47,17 +47,17 @@ static QRegExp Digits("(\\d)+");
 static QRegExp DigitsMil("(\\d)+mil");
 
 static const int MinSipPins = 1;
-static const int MaxSipPins = 64;
+static const int MaxSipPins = 128;
 static const int MinDipPins = 4;
-static const int MaxDipPins = 64;
+static const int MaxDipPins = 128;
 
 static HoleClassThing TheHoleThing;
 
 // TODO
 //	save into parts bin
 
-MysteryPart::MysteryPart( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+MysteryPart::MysteryPart( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: PaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 	m_chipLabel = modelPart->localProp("chip label").toString();
 	if (m_chipLabel.isEmpty()) {
@@ -88,31 +88,34 @@ void MysteryPart::setChipLabel(QString chipLabel, bool force) {
 	m_chipLabel = chipLabel;
 
 	QString svg;
-	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
+	switch (this->m_viewID) {
+		case ViewLayer::BreadboardView:
 			svg = makeSvg(chipLabel, true);
-			break;
-		case ViewIdentifierClass::SchematicView:
-			svg = makeSvg(chipLabel, false);
-			svg = retrieveSchematicSvg(svg);
+            if (!svg.isEmpty()) {
+	            resetRenderer(svg);
+            }			
+            break;
+		case ViewLayer::SchematicView:
+            {
+                QTransform  transform = untransform();
+			    svg = makeSvg(chipLabel, false);
+			    svg = retrieveSchematicSvg(svg);
+                resetLayerKin(svg);
+                retransform(transform);
+            }
 			break;
 		default:
 			break;
 	}
 
-    if (!svg.isEmpty()) {
-	    resetRenderer(svg);
-    }
-
 	modelPart()->setLocalProp("chip label", chipLabel);
 
     if (m_partLabel) m_partLabel->displayTextsIf();
-
 }
 
-QString MysteryPart::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
+QString MysteryPart::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) 
 {
-	QString svg = PaletteItem::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	QString svg = PaletteItem::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 	switch (viewLayerID) {
 		case ViewLayer::Breadboard:
 		case ViewLayer::Icon:
@@ -205,7 +208,7 @@ QStringList MysteryPart::collectValues(const QString & family, const QString & p
 	return PaletteItem::collectValues(family, prop, value);
 }
 
-bool MysteryPart::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget)
+bool MysteryPart::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide)
 {
 	if (prop.compare("chip label", Qt::CaseInsensitive) == 0) {
 		returnProp = tr("label");
@@ -227,7 +230,7 @@ bool MysteryPart::collectExtraInfo(QWidget * parent, const QString & family, con
         return collectHoleSizeInfo(TheHoleThing.holeSizeValue, parent, swappingEnabled, returnProp, returnValue, returnWidget);
 	}
 
-	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 }
 
 QString MysteryPart::getProperty(const QString & key) {
@@ -256,11 +259,11 @@ const QString & MysteryPart::title() {
 }
 
 bool MysteryPart::hasCustomSVG() {
-	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::SchematicView:
-		case ViewIdentifierClass::IconView:
-		case ViewIdentifierClass::PCBView:
+	switch (m_viewID) {
+		case ViewLayer::BreadboardView:
+		case ViewLayer::SchematicView:
+		case ViewLayer::IconView:
+		case ViewLayer::PCBView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -395,11 +398,11 @@ QString MysteryPart::makeSchematicSvg(const QStringList & labels, bool sip)
 					"width='%7in' height='%1in' viewBox='0 0 %8 %2'>\n"
 					"<g id='schematic'>\n"
 					"<rect x='315' y='15' fill='none' width='%9' height='%3' stroke='#000000' stroke-linejoin='round' stroke-linecap='round' stroke-width='30' />\n"
-					"<text id='label' x='%11' y='%4' fill='#000000' stroke='none' font-family='DroidSans' text-anchor='middle' font-size='%5' >%6</text>\n");
+					"<text id='label' x='%11' y='%4' fill='#000000' stroke='none' font-family='Droid Sans' text-anchor='middle' font-size='%5' >%6</text>\n");
 
 	if (!sip) {
 		header +=	"<circle fill='#000000' cx='%10' cy='200' r='150' stroke-width='0' />\n"
-					"<text x='%10' fill='#FFFFFF' y='305' font-family='DroidSans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='275' >?</text>\n";
+					"<text x='%10' fill='#FFFFFF' y='305' font-family='Droid Sans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='275' >?</text>\n";
 	}
 	else {
 		labelText = "IC";
@@ -425,7 +428,7 @@ QString MysteryPart::makeSchematicSvg(const QStringList & labels, bool sip)
 	QString repeat("<line fill='none' stroke='#000000' stroke-linejoin='round' stroke-linecap='round' stroke-width='30' x1='15' y1='%1' x2='300' y2='%1'  />\n"
 					"<rect x='0' y='%2' fill='none' width='300' height='30' id='connector%3pin' stroke-width='0' />\n"
 					"<rect x='0' y='%2' fill='none' width='30' height='30' id='connector%3terminal' stroke-width='0' />\n"
-					"<text id='label%3' x='390' y='%4' font-family='DroidSans' stroke='none' fill='#000000' text-anchor='start' font-size='%6' >%5</text>\n");
+					"<text id='label%3' x='390' y='%4' font-family='Droid Sans' stroke='none' fill='#000000' text-anchor='start' font-size='%6' >%5</text>\n");
   
 	for (int i = 0; i < labels.count(); i++) {
 		svg += repeat
@@ -471,9 +474,9 @@ QString MysteryPart::makeBreadboardDipSvg(const QString & expectedFileName)
 					".percent.2\n"
 					"<rect width='{16.0022}' x='0' y='2.5' height='[6.5]' fill='#000000' id='upper' stroke-width='0' />\n"
 					"<rect width='{16.0022}' x='0' y='[6.5]' fill='#404040' height='3.096' id='lower' stroke-width='0' />\n"
-					"<text id='label' x='2.5894' y='{{6.0}}' fill='#e6e6e6' stroke='none' font-family='DroidSans' text-anchor='start' font-size='7.3' >?</text>\n"
+					"<text id='label' x='2.5894' y='{{6.0}}' fill='#e6e6e6' stroke='none' font-family='Droid Sans' text-anchor='start' font-size='7.3' >?</text>\n"
 					"<circle fill='#8C8C8C' cx='11.0022' cy='{{7.5}}' r='3' stroke-width='0' />\n"
-					"<text x='11.0022' y='{{9.2}}' font-family='DroidSans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='5.5' >?</text>\n"
+					"<text x='11.0022' y='{{9.2}}' font-family='Droid Sans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='5.5' >?</text>\n"
 					".percent.3\n"
 					"</g>\n"
 					"</svg>\n");
@@ -524,9 +527,9 @@ QString MysteryPart::makeBreadboardSipSvg(const QString & expectedFileName)
 					"<g id='breadboard'>\n"
 					"<rect width='[6.0022]' x='0' y='0' height='24.17675' fill='#000000' id='upper' stroke-width='0' />\n"
 					"<rect width='[6.0022]' x='0' y='22' fill='#404040' height='3.096' id='lower' stroke-width='0' />\n"
-					"<text id='label' x='2.5894' y='13' fill='#e6e6e6' stroke='none' font-family='DroidSans' text-anchor='start' font-size='7.3' >?</text>\n"
+					"<text id='label' x='2.5894' y='13' fill='#e6e6e6' stroke='none' font-family='Droid Sans' text-anchor='start' font-size='7.3' >?</text>\n"
 					"<circle fill='#8C8C8C' cx='[1.0022]' cy='5' r='3' stroke-width='0' />\n"
-					"<text x='[1.0022]' y='6.7' font-family='DroidSans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='5.5' >?</text>\n"      
+					"<text x='[1.0022]' y='6.7' font-family='Droid Sans' text-anchor='middle' font-weight='bold' stroke-width='0' font-size='5.5' >?</text>\n"      
 					"%2\n"
 					"</g>\n"
 					"</svg>\n");
@@ -544,14 +547,24 @@ QString MysteryPart::makeBreadboardSipSvg(const QString & expectedFileName)
 bool MysteryPart::changePinLabels(bool singleRow, bool sip) {
 	Q_UNUSED(singleRow);
 
-	if (m_viewIdentifier != ViewIdentifierClass::SchematicView) return true;
+	if (m_viewID != ViewLayer::SchematicView) return true;
 
 	bool hasLocal = false;
 	QStringList labels = getPinLabels(hasLocal);
 	if (labels.count() == 0) return true;
 
+    QTransform  transform = untransform();
+
 	QString svg = MysteryPart::makeSchematicSvg(labels, sip);
-	resetRenderer(svg);
+
+    QString chipLabel = modelPart()->localProp("chip label").toString();
+    if (!chipLabel.isEmpty()) {
+        svg =TextUtils::replaceTextElement(svg, "label", chipLabel);
+    }
+
+    resetLayerKin(svg);
+
+    retransform(transform);
 
 	return true;
 }
@@ -633,6 +646,3 @@ QString MysteryPart::makePcbDipSvg(const QString & expectedFileName)
 
 	return svg;
 }
-
-void MysteryPart::makeLocalMods(QByteArray &, const QString &) {
-}
