@@ -308,11 +308,20 @@ void PaletteItem::transformItem2(const QMatrix & matrix) {
 }
 
 void PaletteItem::setTransforms() {
+    // only ever called when loading from file
+    // jrc 14 july 2013: this call seems redundant--transforms have already been set up by now
+
     QTransform transform = getViewGeometry().transform();
     if (transform.isIdentity()) return;
 
+    //debugInfo("set transforms " + TextUtils::svgMatrix(transform));
+    //debugInfo("\t " + TextUtils::svgMatrix(this->transform()));
+
+
 	setTransform(transform);
 	for (int i = 0; i < m_layerKin.count(); i++) {
+        //debugInfo("\t " + TextUtils::svgMatrix(m_layerKin[i]->getViewGeometry().transform()));
+        //debugInfo("\t " + TextUtils::svgMatrix(m_layerKin[i]->transform()));
 		m_layerKin[i]->setTransform2(m_layerKin[i]->getViewGeometry().transform());
 	}
 }
@@ -541,9 +550,15 @@ QStringList PaletteItem::collectValues(const QString & family, const QString & p
     if (prop.compare("layer") == 0) {
         if (modelPart()->flippedSMD()) {
             QStringList values = PaletteItemBase::collectValues(family, prop, value);
-            if (values.count() == 0) {
+            for (int ix = values.count() - 1; ix >= 0; ix--) {
+                if (values.at(ix).isEmpty()) {
+                    values.removeAt(ix);
+                }
+            }
+            if (values.count() < 2) {
                 ItemBase * itemBase = modelPart()->viewItem(ViewLayer::PCBView);
                 if (itemBase) {
+                    values.clear();
                     values << TranslatedPropertyNames.value("bottom") << TranslatedPropertyNames.value("top");
                     if (itemBase->viewLayerID() == ViewLayer::Copper0) {
                         value = values.at(0);
@@ -949,7 +964,7 @@ QWidget * PaletteItem::createHoleSettings(QWidget * parent, HoleSettings & holeS
 
 	    QLabel * label = new QLabel(tr("Hole Diameter"));
 	    label->setMinimumHeight(RowHeight);
-	    label->setObjectName("infoViewLabel");
+        label->setObjectName("infoViewGroupBoxLabel");
 	    gridLayout->addWidget(label, 0, 0);
 
 	    holeSettings.thicknessEdit = new QLineEdit(subFrame);
@@ -1524,6 +1539,7 @@ void PaletteItem::resetLayerKin(const QString & svg) {
 }
 
 QTransform PaletteItem::untransform() {
+    //DebugDialog::debug("untransform");
     QTransform chiefTransform = this->transform();
     chiefTransform.setMatrix(chiefTransform.m11(), chiefTransform.m12(), chiefTransform.m13(), chiefTransform.m21(), chiefTransform.m22(), chiefTransform.m23(), 0, 0, chiefTransform.m33()); 
     bool identity = chiefTransform.isIdentity();
@@ -1539,6 +1555,7 @@ QTransform PaletteItem::untransform() {
 }
 
 void PaletteItem::retransform(const QTransform & chiefTransform) {
+    //DebugDialog::debug("retransform");
     if (!chiefTransform.isIdentity()) {
         transformItem(chiefTransform, false);
         foreach (ItemBase * lkpi, layerKin()) {    
