@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6268 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-09 08:53:47 +0200 (Thu, 09 Aug 2012) $
+$Revision: 6998 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-28 13:51:10 +0200 (So, 28. Apr 2013) $
 
 ********************************************************************/
 
@@ -78,25 +78,25 @@ class PaletteItem : public PaletteItemBase
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	PaletteItem(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	PaletteItem(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~PaletteItem();
 
 	void removeLayerKin();
 	void addLayerKin(class LayerKinPaletteItem * lkpi);
 	const QList<class ItemBase *> & layerKin();
- 	virtual void loadLayerKin(const LayerHash & viewLayers, ViewLayer::ViewLayerSpec);
-	void rotateItem(double degrees);
+ 	virtual void loadLayerKin(const LayerHash & viewLayers, ViewLayer::ViewLayerPlacement);
+	void rotateItem(double degrees, bool includeRatsnest);
 	void flipItem(Qt::Orientations orientation);
 	void moveItem(ViewGeometry & viewGeometry);
 	void transformItem2(const QMatrix &);
 	void setItemPos(QPointF & pos);
 
-	bool renderImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID, bool doConnectors, QString & error);
+	bool renderImage(ModelPart * modelPart, ViewLayer::ViewID viewID, const LayerHash & viewLayers, ViewLayer::ViewLayerID, bool doConnectors, QString & error);
 
 	void setTransforms();
 	void syncKinMoved(QPointF offset, QPointF loc);
 
-	void setInstanceTitle(const QString&);
+	void setInstanceTitle(const QString&, bool initial);
 
 	bool swap(ModelPart* newModelPart, const LayerHash &layerHash, bool reinit, class SwapCommand *);
 	void setHidden(bool hidden);
@@ -104,20 +104,23 @@ public:
 	bool collectFemaleConnectees(QSet<ItemBase *> & items);
 	void collectWireConnectees(QSet<class Wire *> & wires);
 	void clearModelPart();
-	void mousePressEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *);
-	ItemBase * lowerConnectorLayerVisible(ItemBase *);
+	bool mousePressEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *);
 	void resetID();
 	void slamZ(double z);
-	void resetImage(class InfoGraphicsView *, QDomDocument *);
-	void resetKinImage(ItemBase * layerKin, InfoGraphicsView * infoGraphicsView, QDomDocument *);
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	void resetImage(class InfoGraphicsView *);
+	void resetKinImage(ItemBase * layerKin, InfoGraphicsView * infoGraphicsView);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
+	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 	virtual bool changePinLabels(bool singleRow, bool sip);
 	QStringList getPinLabels(bool & hasLocal);
 	void renamePins(const QStringList & labels, bool singleRow);
 	void resetConnectors();
 	void resetConnectors(ItemBase * otherLayer, FSvgRenderer * otherLayerRenderer);
 	void resetConnector(ItemBase * itemBase, SvgIdLayer * svgIdLayer);
-    QStringList sipOrDipOr(bool & hasLayout, bool & sip);
+    QStringList sipOrDipOrLabels(bool & hasLayout, bool & sip);
+    void resetLayerKin(const QString & svg);
+    QTransform untransform();
+    void retransform(const QTransform &);
 
 public:
 	static QString genFZP(const QString & moduleid, const QString & templateName, int minPins, int maxPins, int steps, bool smd);
@@ -141,7 +144,7 @@ protected slots:
 protected:
 	void syncKinSelection(bool selected, PaletteItemBase * originator);
  	QVariant itemChange(GraphicsItemChange change, const QVariant &value);
-	void updateConnections();
+	void updateConnections(bool includeRatsnest, QList<ConnectorItem *> & already);
 	void mousePressEvent(QGraphicsSceneMouseEvent *event);
 	void figureHover();
 	bool isSingleRow(const QList<ConnectorItem *> & connectorItems);
@@ -150,7 +153,9 @@ protected:
     QString hackFzpHoleSize(const QString & moduleID, const QString & pcbFilename, const QString & holeSize);
     QString appendHoleSize(const QString & moduleID, const QString & holeSize, const QString & ringThickness);
     void generateSwap(const QString & text, GenModuleID, GenFzp, GenSvg makeBreadboardSvg, GenSvg makeSchematicSvg, GenSvg makePcbSvg);
-    void makeLocalMods(QByteArray & svg, const QString & filename);
+    bool makeLocalModifications(QByteArray & svg, const QString & filename);
+    void makeOneKin(qint64 & id, ViewLayer::ViewLayerID, ViewLayer::ViewLayerPlacement, ViewGeometry &, const LayerHash &);
+    void initLayerAttributes(LayerAttributes & layerAttributes, ViewLayer::ViewID, ViewLayer::ViewLayerID, ViewLayer::ViewLayerPlacement, bool doConnectors, bool doCreateShape);
 
 protected:
     void setUpHoleSizes(const QString & type, HoleClassThing &);
@@ -175,6 +180,7 @@ public:
 protected:
  	QList<class ItemBase *> m_layerKin;
     HoleSettings m_holeSettings;
+    int m_flipCount;
 
 };
 
