@@ -401,6 +401,8 @@ bool PaletteItemBase::setUpImage(ModelPart * modelPart, const LayerHash & viewLa
 		return false;
 	}
 
+    cacheLoaded(layerAttributes);
+
 	m_canFlipVertical = modelPart->canFlipVertical(layerAttributes.viewID);
 	m_canFlipHorizontal = modelPart->canFlipHorizontal(layerAttributes.viewID);
 	m_filename = layerAttributes.filename();
@@ -411,6 +413,8 @@ bool PaletteItemBase::setUpImage(ModelPart * modelPart, const LayerHash & viewLa
 
 	//DebugDialog::debug(QString("setting layer %1 view:%2 z:%3").arg(modelPart->title()).arg(viewID).arg(this->z()) );
 	this->setZValue(this->z());
+    //DebugDialog::debug("loaded");
+    //DebugDialog::debug(layerAttributes.loaded());
 	this->setSharedRendererEx(renderer);
 
 	m_svg = true;
@@ -420,7 +424,7 @@ bool PaletteItemBase::setUpImage(ModelPart * modelPart, const LayerHash & viewLa
 	}
 
 	if (!m_viewGeometry.transform().isIdentity()) {
-		setTransform(m_viewGeometry.transform());
+		setInitialTransform(m_viewGeometry.transform());
 		update();
 	}
 
@@ -786,6 +790,14 @@ QString PaletteItemBase::normalizeSvg(QString & svg, ViewLayer::ViewLayerID view
 	return splitter.elementString(xmlName);
 }
 
+void PaletteItemBase::setInitialTransform(const QTransform &matrix)
+{
+    setTransform(matrix);
+}
+
+void PaletteItemBase::cacheLoaded(const LayerAttributes &)
+{
+}
 
 /*
 
