@@ -123,6 +123,9 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewLayer::ViewID
 		case ModelPart::Ruler:
 			return new Ruler(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
 		case ModelPart::Symbol:
+            if (modelPart->moduleID().contains(ModuleIDNames::NetLabelModuleIDName)) {
+			    return new NetLabel(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
+            }
 			return new SymbolPaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
 		case ModelPart::Via:
 			return new Via(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
@@ -173,6 +176,9 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewLayer::ViewID
 					if (moduleID.endsWith(ModuleIDNames::StripboardModuleIDName)) {
 						return new Stripboard(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
 					}
+					if (moduleID.endsWith(ModuleIDNames::Stripboard2ModuleIDName)) {
+						return new Stripboard(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
+					}
 					if (moduleID.endsWith(ModuleIDNames::SchematicFrameModuleIDName)) {
 						return new SchematicFrame(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
 					}
@@ -188,6 +194,10 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewLayer::ViewID
 					}
 
 				}
+                // TODO: use the list in properties.xml
+                if (moduleID == "alps-starter-pot9mm") {
+				    return new Capacitor(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
+                }
 				QString family = modelPart->properties().value("family", "");
 				if (family.compare("mystery part", Qt::CaseInsensitive) == 0) {
 					return new MysteryPart(modelPart, viewID, viewGeometry, id, itemMenu, doLabel);
@@ -214,7 +224,9 @@ QString PartFactory::getSvgFilename(ModelPart * modelPart, const QString & baseN
     QString userStore = FolderUtils::getUserDataStorePath("parts")+postfix;
     QString pfPath = PartFactory::folderPath() + postfix;
 	if(!modelPart->path().isEmpty()) {
-		QDir dir(modelPart->path());			// is a path to a filename
+        QString path = modelPart->path();
+        path.replace("/pdb/", "/parts/");
+		QDir dir(path);			// is a path to a filename
 		dir.cdUp();									// lop off the filename
 		dir.cdUp();									// parts root
 		tempPaths << dir.absolutePath() + postfix;
@@ -471,6 +483,10 @@ QString PartFactory::getFzpFilename(const QString & moduleID)
 		return getFzpFilenameAux(moduleID, &Stripboard::genFZP);
 	}
 
+	if (moduleID.endsWith(ModuleIDNames::Stripboard2ModuleIDName)) {
+		return getFzpFilenameAux(moduleID, &Stripboard::genFZP);
+	}
+
 	if (moduleID.startsWith("generic_ic_dip")) {
 		return getFzpFilenameAux(moduleID, &Dip::genDipFZP);
 	}
