@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6218 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
+$Revision: 6912 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
@@ -118,7 +118,7 @@ PartLabel::PartLabel(ItemBase * owner, QGraphicsItem * parent)
 
 	m_inactive = m_hidden = m_initialized = false;
 	m_displayKeys.append(LabelTextKey);
-	if (m_owner->hasPartNumberProperty() && m_owner->viewIdentifier() != ViewIdentifierClass::PCBView) {
+	if (m_owner->hasPartNumberProperty() && m_owner->viewID() != ViewLayer::PCBView) {
 		m_displayKeys.append(ModelPartShared::PartNumberPropertyName);
 	}
 
@@ -147,7 +147,7 @@ void PartLabel::showLabel(bool showIt, ViewLayer * viewLayer) {
 
 		bool flipped = (viewLayer->viewLayerID() == ViewLayer::Silkscreen0Label);
 
-		if (m_owner->viewIdentifier() != ViewIdentifierClass::PCBView) {
+		if (m_owner->viewID() != ViewLayer::PCBView) {
 			foreach (QString dk, m_owner->modelPart()->displayKeys()) {
 				if (!m_displayKeys.contains(dk)) {
 					m_displayKeys.append(dk);
@@ -444,7 +444,7 @@ void PartLabel::initMenu()
 	QMenu * rlmenu = m_menu.addMenu(tr("Flip/Rotate"));
 	QMenu * fsmenu = m_menu.addMenu(tr("Font Size"));
 
-	bool include45 = (m_owner != NULL) && (m_owner->viewIdentifier() == ViewIdentifierClass::PCBView);
+	bool include45 = (m_owner != NULL) && (m_owner->viewID() == ViewLayer::PCBView);
 
 	if (include45) {
 		QAction *rotate45cwAct = rlmenu->addAction(tr("Rotate 45\x00B0 Clockwise"));
@@ -566,7 +566,7 @@ void PartLabel::transformLabel(QTransform currTransf)
 void PartLabel::setUpText() {
 	InfoGraphicsView *infographics = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infographics != NULL) {
-		infographics->getLabelFont(m_font, m_color, m_owner->viewLayerSpec());
+		infographics->getLabelFont(m_font, m_color, m_owner);
 	}
 }
 
