@@ -44,6 +44,19 @@ $Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 //////////////////////////////////////////////////
 
+QString doubleCopyPinFunction(int pin, const QString & argString, void *)
+{
+	return argString.arg(pin * 2).arg(pin * 2 + 1).arg(pin * 2 + 1).arg(pin * 2 + 2);
+}
+
+QString stdIncCopyPinFunction(int pin, const QString & argString, void *)
+{
+	return argString.arg(pin).arg(pin + 1);
+}
+
+//////////////////////////////////////////////////
+
+
 static QStringList Forms;
 
 QString PinHeader::FemaleFormString;
@@ -592,11 +605,13 @@ void PinHeader::initSpacings() {
 	if (Spacings.count() == 0) {
 		ShroudedSpacing = "0.1in (2.54mm)";
 		Spacings.insert("1mm", "0.03937in (1.0mm)");
+		Spacings.insert("1.25mm", "0.04921in (1.25mm)");
 		Spacings.insert("50mil", "0.05in (1.27mm)");
 		Spacings.insert("1.5mm", "0.0591in (1.5mm)");
 		Spacings.insert("2mm", "0.07874in (2mm)");
-		Spacings.insert("2.5mm", "0.09843in (2.5mm)");
+		Spacings.insert("2.54mm", "0.09843in (2.54mm)");
 		Spacings.insert("100mil", ShroudedSpacing);
+		Spacings.insert("150mil", "0.15in (3.81mm)");
 		Spacings.insert("200mil", "0.2in (5.08mm)");
 	}
 }
@@ -606,22 +621,49 @@ QString PinHeader::makeSchematicSvg(const QString & expectedFileName)
 	QStringList pieces = expectedFileName.split("_");
 	if (pieces.count() < 7) return "";
 
-	int pins = pieces.at(pieces.count() - 3).toInt();
+    QString spacingString;
+    int pins = TextUtils::getPinsAndSpacing(expectedFileName, spacingString);
 	QString form = expectedFileName.contains("female") ? "female" :"male";
-	double unitHeight = GraphicsUtils::StandardSchematicSeparationMils / 1000;  // inches
+    bool sizeTenth = expectedFileName.contains("10thin");
+    bool isDouble = sizeTenth && expectedFileName.contains("double");
+
+    double width, unitHeight;
+    double divisor = isDouble ? 2 : 1;
+    if (sizeTenth) {
+        width = isDouble ? 0.5 : 0.2;
+        unitHeight = GraphicsUtils::StandardSchematicSeparation10thinMils / 1000;  // inches
+    }
+    else {
+        unitHeight = GraphicsUtils::StandardSchematicSeparationMils / 1000;  // inches
+        width = 0.87;
+    }
 	double unitHeightPoints = unitHeight * 72;
 
 	QString header("<?xml version='1.0' encoding='utf-8'?>\n"
 				"<svg version='1.2' baseProfile='tiny' id='svg2' xmlns:svg='http://www.w3.org/2000/svg' "
-				"xmlns='http://www.w3.org/2000/svg'  x='0in' y='0in' width='0.87in' "
-				"height='%1in' viewBox='0 0 62.641 %2'>\n"
+				"xmlns='http://www.w3.org/2000/svg'  x='0in' y='0in' width='%3in' "
+				"height='%1in' viewBox='0 0 %4 %2'>\n"
 				"<g id='schematic' >\n");
 
 
-	QString svg = header.arg(unitHeight * pins).arg(unitHeightPoints * pins);
+	QString svg = header.arg(unitHeight * pins / divisor).arg(unitHeightPoints * pins / divisor).arg(width).arg(width * 72);
 
-	svg += TextUtils::incrementTemplate(QString(":/resources/templates/generic_%1_pin_header_schem_template.txt").arg(form.contains("female") ? "female" : "male"),
-							 pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, TextUtils::standardCopyPinFunction, NULL);
+    QString templateFile = QString(":/resources/templates/generic_%1_%2%3pin_header_schem_template.txt")
+                                                .arg(form.contains("female") ? "female" : "male")
+                                                .arg(sizeTenth ? "10thin_" : "")
+                                                .arg(isDouble ? "double_" : "")
+                                                ;
+    if (sizeTenth) {
+        if (isDouble) {
+	        svg += TextUtils::incrementTemplate(templateFile, pins / 2, unitHeightPoints, TextUtils::standardMultiplyPinFunction, doubleCopyPinFunction, NULL);
+        }
+        else {
+	        svg += TextUtils::incrementTemplate(templateFile, pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, stdIncCopyPinFunction, NULL);
+        }
+    }
+    else {
+	    svg += TextUtils::incrementTemplate(templateFile, pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, TextUtils::standardCopyPinFunction, NULL);
+    }
 		
 
 	svg += "</g>\n</svg>";
