@@ -280,8 +280,8 @@ void Board::fileNameEntry(const QString & filename) {
 	foreach (QString name, getImageNames()) {
 		if (filename.compare(name) == 0) {
 			QString f = FolderUtils::getApplicationSubFolderPath("parts") + "/svg/core/pcb/" + filename + ".svg";
-			return prepLoadImageAux(f, false);
-			break;
+			prepLoadImageAux(f, false);
+			return;
 		}
 	}
 
@@ -435,20 +435,23 @@ void Board::moreCheckImage(const QString & filename) {
         }
     }
 
-    QString msg;
+    QString msg = tr("<b>The custom shape has been loaded, and you will see the new board shortly.</b><br/><br/>");
+    msg += tr("Before actual PCB production we recommend that you test your custom shape by using the 'File > Export for Production > Extended Gerber' option. ");
+    msg += tr("Check the resulting contour file with a Gerber-viewer application to make sure the shape came out as expected.<br/><br/>");
+
+    msg += tr("The rest of this message concerns 'cutouts'. ");
+    msg += tr("These are circular or irregularly-shaped holes that you can optionally incorporate into a custom PCB shape.<br/><br/>");
     if (subpaths == 1) {
-        msg = tr("Fritzing thinks the custom shape has no cutouts.");
+        msg += tr("<b>The custom shape has no cutouts.</b>");
     }
     else {
-        msg = tr("Fritzing thinks the custom shape has %n cutouts.", "", subpaths - 1);
+        msg += tr("<b>The custom shape has %n cutouts.</b>", "", subpaths - 1);
         if (subpaths != mCount) {
-            msg += tr("\nHowever, the cutouts may not be formatted correctly.");
+            msg += tr("<br/>However, the cutouts may not be formatted correctly.");
         }
     }
-    msg +=  tr("\n\nIf you intended your custom shape to have cutouts and you did not get the expected result ");
-    msg += tr("it is because Fritzing requires that you make cutouts using a shape 'subtraction' or 'difference' operation in your vector graphics editor.\n\n");
-    msg += tr("In any case we recommend that you test your custom shape by using the 'File > Export for Production > Extended Gerber' option ");
-    msg += tr("and checking the resulting contour file with a Gerber viewer application.");
+    msg +=  tr("<br/><br/>If you intended your custom shape to have cutouts and you did not get the expected result, ");
+    msg += tr("it is because Fritzing requires that you make cutouts using a shape 'subtraction' or 'difference' operation in your vector graphics editor.");
     QMessageBox::information(NULL, "Custom Shape", msg);
 }
 
@@ -732,9 +735,8 @@ void ResizableBoard::mouseMoveEvent(QGraphicsSceneMouseEvent * event) {
 		if (changeTransform) {
 			QTransform oldT = transform();
 
-			DebugDialog::debug(QString("t old m:%1,%2,%3,%4 d:%5,%6 p:%7,%8 sz:%9,%10")
-				.arg(oldT.m11()).arg(oldT.m12()).arg(oldT.m21()).arg(oldT.m22())
-				.arg(oldT.toAffine().dx()).arg(oldT.toAffine().dy())
+			DebugDialog::debug(QString("t old m:%1 p:%2,%3 sz:%4,%5")
+                .arg(TextUtils::svgMatrix(oldT))
 				.arg(pos().x()).arg(pos().y())
 				.arg(oldSize.width()).arg(oldSize.height()));
 
@@ -755,9 +757,8 @@ void ResizableBoard::mouseMoveEvent(QGraphicsSceneMouseEvent * event) {
 			}
 			
 			QTransform t = transform();
-			DebugDialog::debug(QString("t new m:%1,%2,%3,%4 d:%5,%6 p:%7,%8 sz:%9,%10")
-				.arg(t.m11()).arg(t.m12()).arg(t.m21()).arg(t.m22())
-				.arg(t.toAffine().dx()).arg(t.toAffine().dy())
+			DebugDialog::debug(QString("t new m:%1 p:%2,%3 sz:%4,%5")
+				.arg(TextUtils::svgMatrix(t))
 				.arg(pos().x()).arg(pos().y())
 				.arg(size.width()).arg(size.height()));
 		}
