@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -36,6 +36,7 @@ $Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
 #include <QLabel>
 #include <QCheckBox>
 #include <QComboBox>
+#include <QPushButton>
 
 #include "paletteitem.h"
 
@@ -45,7 +46,7 @@ class Board : public PaletteItem
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	Board(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	Board(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~Board();
 
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
@@ -54,7 +55,7 @@ public:
 	bool stickyEnabled();
 	PluralType isPlural();
 	bool canFindConnectorsUnder();
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 
 protected:
     void setupLoadImage(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
@@ -65,7 +66,11 @@ protected:
 	void unableToLoad(const QString & fileName, const QString & reason);
 	bool canLoad(const QString & fileName, const QString & reason);
 	virtual void prepLoadImageAux(const QString & fileName, bool addName);
-    ViewIdentifierClass::ViewIdentifier useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier, bool swappingEnabled);
+    ViewLayer::ViewID useViewIDForPixmap(ViewLayer::ViewID, bool swappingEnabled);
+
+protected:
+    static void moreCheckImage(const QString & filename);
+    static QString setBoardOutline(const QString & svg);
 
 public:
 	static QString OneLayerTranslated;
@@ -74,6 +79,8 @@ public:
 public:
     static bool isBoard(ItemBase *);
     static bool isBoard(ModelPart *);
+    static QString convertToXmlName(const QString &);
+    static QString convertFromXmlName(const QString &);
 
 protected slots:
 	void prepLoadImage();
@@ -94,16 +101,15 @@ class ResizableBoard : public Board
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	ResizableBoard(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	ResizableBoard(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~ResizableBoard();
 
-	bool setUpImage(ModelPart* modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, bool doConnectors, LayerAttributes &, QString & error);
 	virtual bool resizeMM(double w, double h, const LayerHash & viewLayers);
 	void resizePixels(double w, double h, const LayerHash & viewLayers);
- 	void loadLayerKin(const LayerHash & viewLayers, ViewLayer::ViewLayerSpec);
+ 	void loadLayerKin(const LayerHash & viewLayers, ViewLayer::ViewLayerPlacement);
 	virtual void setInitialSize();
-	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 	void saveParams();
 	void getParams(QPointF &, QSizeF &);
 	bool hasCustomSVG();
@@ -112,12 +118,14 @@ public:
 	bool hasPartNumberProperty();
 	void paintSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 	bool inResize();
+    void figureHover();
 
 public slots:
 	virtual void widthEntry();
 	virtual void heightEntry();
 	void keepAspectRatio(bool checkState);
 	void revertSize(bool);
+    virtual void paperSizeChanged(int);
 
 protected:
 	enum Corner {
@@ -136,13 +144,13 @@ protected:
 	void hoverLeaveEvent(QGraphicsSceneHoverEvent * event );
 	void hoverMoveEvent(QGraphicsSceneHoverEvent * event );
 	QString makeBoardSvg(double mmW, double mmH, double milsW, double milsH);
-	QString makeSilkscreenSvg(double mmW, double mmH, double milsW, double milsH);
+	QString makeSilkscreenSvg(ViewLayer::ViewLayerID, double mmW, double mmH, double milsW, double milsH);
     QString makeSvg(double mmW, double mmH, const QString & layerTemplate);
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 	virtual void loadTemplates();
 	virtual double minWidth();
 	virtual double minHeight();
-	virtual ViewIdentifierClass::ViewIdentifier theViewIdentifier();
+	virtual ViewLayer::ViewID theViewID();
 	virtual QString makeLayerSvg(ViewLayer::ViewLayerID viewLayerID, double mmW, double mmH, double milsW, double milsH);
 	virtual QString makeFirstLayerSvg(double mmW, double mmH, double milsW, double milsH);
 	virtual QString makeNextLayerSvg(ViewLayer::ViewLayerID, double mmW, double mmH, double milsW, double milsH);
@@ -150,10 +158,12 @@ protected:
 	virtual ResizableBoard::Corner findCorner(QPointF p, Qt::KeyboardModifiers);
 	void setKinCursor(QCursor &);
 	void setKinCursor(Qt::CursorShape);
-	QFrame * setUpDimEntry(bool includeAspectRatio, bool includeRevert, QWidget * & returnWidget);
+	QFrame * setUpDimEntry(bool includeAspectRatio, bool includeRevert, bool includePaperSizes, QWidget * & returnWidget);
 	void fixWH();
 	void setWidthAndHeight(double w, double h);
     QString getShapeForRenderer(const QString & svg, ViewLayer::ViewLayerID viewLayerID);
+    void initPaperSizes();
+    void updatePaperSizes(double width, double height);
 
 protected:
 	static const double CornerHandleSize;
@@ -169,6 +179,7 @@ protected:
 	QPointer<QCheckBox> m_aspectRatioCheck;
     QPointer<QLabel> m_aspectRatioLabel;
     QPointer<QPushButton> m_revertButton;
+    QPointer<QComboBox> m_paperSizeComboBox;
 
 	QPointF m_resizeMousePos;
 	QSizeF m_resizeStartSize;
