@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6218 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -46,8 +46,8 @@ static const int IndexIn = 1;
 
 static QString DefaultWidth = "";
 
-Ruler::Ruler( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+Ruler::Ruler( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: PaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 	m_widthEditor = NULL;
 	m_unitsEditor = NULL;
@@ -85,7 +85,7 @@ void Ruler::resizeMM(double magnitude, double unitsFlag, const LayerHash & viewL
 
 }
 
-QString Ruler::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
+QString Ruler::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) 
 {
 	double w = TextUtils::convertToInches(m_modelPart->localProp("width").toString());
 	if (w != 0) {
@@ -101,21 +101,11 @@ QString Ruler::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QS
 		}
 
 		if (!xml.isEmpty()) {
-			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-			SvgFileSplitter splitter;
-			bool result = splitter.splitString(xml, xmlName);
-			if (!result) {
-				return "";
-			}
-			result = splitter.normalize(dpi, xmlName, blackOnly);
-			if (!result) {
-				return "";
-			}
-			return splitter.elementString(xmlName);
+			 return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi, factor);
 		}
 	}
 
-	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 }
 
 QString Ruler::makeSvg(double inches) {
@@ -123,7 +113,7 @@ QString Ruler::makeSvg(double inches) {
 	double offset = 0.125;
 	double mmW = inches * 25.4;
 	QString svg = TextUtils::makeSVGHeader(GraphicsUtils::SVGDPI, GraphicsUtils::StandardFritzingDPI, (inches + offset + offset) * GraphicsUtils::SVGDPI, GraphicsUtils::SVGDPI);
-	svg += "<g font-family='DroidSans' text-anchor='middle' font-size='100' stroke-width='1px' stroke='black'>";
+	svg += "<g font-family='Droid Sans' text-anchor='middle' font-size='100' stroke-width='1' stroke='black'>";
 	int counter = 0;
 	for (int i = 0; i <= qCeil(mmW); i++) {
 		double h = cm / 4;
@@ -187,7 +177,7 @@ QString Ruler::makeSvg(double inches) {
 		}
 	}
 
-    svg += QString("<line x1='%1' y1='%2' x2='%3' y2='%2' stroke-width='1px' stroke='black' />\n")
+    svg += QString("<line x1='%1' y1='%2' x2='%3' y2='%2' stroke-width='1' stroke='black' />\n")
         .arg(offset * GraphicsUtils::StandardFritzingDPI)
         .arg((GraphicsUtils::StandardFritzingDPI / 2) - 40)
         .arg((inches + offset) * GraphicsUtils::StandardFritzingDPI);
@@ -202,19 +192,19 @@ QString Ruler::makeSvg(double inches) {
 }
 
 bool Ruler::hasCustomSVG() {
-	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
-		case ViewIdentifierClass::SchematicView:
-		case ViewIdentifierClass::BreadboardView:
+	switch (m_viewID) {
+		case ViewLayer::PCBView:
+		case ViewLayer::SchematicView:
+		case ViewLayer::BreadboardView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
 	}
 }
 
-bool Ruler::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget)
+bool Ruler::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide)
 {
-	bool result = PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	bool result = PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 
 	if (prop.compare("width", Qt::CaseInsensitive) == 0) {
 		returnProp = tr("width");
@@ -346,7 +336,7 @@ bool Ruler::canFindConnectorsUnder() {
 	return false;
 }
 
-ViewIdentifierClass::ViewIdentifier Ruler::useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier, bool) 
+ViewLayer::ViewID Ruler::useViewIDForPixmap(ViewLayer::ViewID, bool) 
 {
-    return ViewIdentifierClass::IconView;
+    return ViewLayer::IconView;
 }
