@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6218 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -65,8 +65,8 @@ static double FontSize = 11;
 QHash<QString, QString> FrameProps;
 static const QString DisplayFormat("dd MMM yyyy hh:mm:ss");
 
-SchematicFrame::SchematicFrame( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: ResizableBoard(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+SchematicFrame::SchematicFrame( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: ResizableBoard(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 	if (FrameProps.count() == 0) {
 		FrameProps.insert("descr", "");
@@ -217,8 +217,8 @@ QString SchematicFrame::makeFirstLayerSvg(double mmW, double mmH, double milsW,
 	return makeLayerSvg(ViewLayer::SchematicFrame, mmW, mmH, milsW, milsH);
 }
 
-ViewIdentifierClass::ViewIdentifier SchematicFrame::theViewIdentifier() {
-	return ViewIdentifierClass::SchematicView;
+ViewLayer::ViewID SchematicFrame::theViewID() {
+	return ViewLayer::SchematicView;
 }
 
 double SchematicFrame::minWidth() {
@@ -241,9 +241,9 @@ void SchematicFrame::addedToScene(bool temporary)
 	resizeMMAux(m_modelPart->localProp("width").toDouble(), m_modelPart->localProp("height").toDouble());
 }
 
-QString SchematicFrame::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi)
+QString SchematicFrame::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor)
 {
-	return ResizableBoard::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	return ResizableBoard::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 }
 
 bool SchematicFrame::makeLineEdit(QWidget * parent, const QString & family, const QString & propp, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
@@ -268,9 +268,16 @@ bool SchematicFrame::makeLineEdit(QWidget * parent, const QString & family, cons
 	return true;
 }
 
-bool SchematicFrame::collectExtraInfo(QWidget * parent, const QString & family, const QString & propp, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
+bool SchematicFrame::collectExtraInfo(QWidget * parent, const QString & family, const QString & propp, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide) 
 {
-	if (propp.compare("date", Qt::CaseInsensitive) == 0) {
+	if (propp.compare("shape", Qt::CaseInsensitive) == 0) {
+		returnWidget = setUpDimEntry(false, false, true, returnWidget);
+        returnWidget->setEnabled(swappingEnabled);
+		returnProp = tr("shape");
+		return true;
+	}
+
+    if (propp.compare("date", Qt::CaseInsensitive) == 0) {
 		QDateTimeEdit * dateTimeEdit = new QDateTimeEdit(QDateTime::currentDateTime(), parent);
 		QString d = prop("date");
 		if (!d.isEmpty()) {
@@ -341,7 +348,7 @@ bool SchematicFrame::collectExtraInfo(QWidget * parent, const QString & family,
 		return makeLineEdit(parent, family, propp, value, swappingEnabled, returnProp, returnValue, returnWidget);
 	}
 
-	return PaletteItem::collectExtraInfo(parent, family, propp, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	return PaletteItem::collectExtraInfo(parent, family, propp, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 }
 
 void SchematicFrame::setProp(const QString & prop, const QString & value) 
@@ -439,11 +446,11 @@ void SchematicFrame::sheetEntry(int value) {
 	}
 }
 
-ViewIdentifierClass::ViewIdentifier SchematicFrame::useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier vid, bool) 
+ViewLayer::ViewID SchematicFrame::useViewIDForPixmap(ViewLayer::ViewID vid, bool) 
 {
-    if (vid == ViewIdentifierClass::SchematicView) {
-        return ViewIdentifierClass::IconView;
+    if (vid == ViewLayer::SchematicView) {
+        return ViewLayer::IconView;
     }
 
-    return ViewIdentifierClass::UnknownView;
+    return ViewLayer::UnknownView;
 }
