@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -33,10 +33,10 @@ class TraceWire : public ClipableWire
 {
 Q_OBJECT
 public:
-	TraceWire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier,  const ViewGeometry & , long id, QMenu* itemMenu  ); 
+	TraceWire( ModelPart * modelPart, ViewLayer::ViewID,  const ViewGeometry & , long id, QMenu* itemMenu  ); 
 	~TraceWire();
 
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 	bool canSwitchLayers();
 	void setSchematic(bool schematic);
 
@@ -44,6 +44,8 @@ public:
 	static TraceWire * getTrace(ConnectorItem *);
 	static class QComboBox * createWidthComboBox(double currentMils, QWidget * parent);
 	static int widthEntry(const QString & text, QObject * sender);
+    QHash<QString, QString> prepareProps(ModelPart *, bool wantDebug, QStringList & keys);
+	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 
 public:
 	enum WireDirection {
