@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6218 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
+$Revision: 6912 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
@@ -41,8 +41,8 @@ const QString Via::AutorouteViaRingThickness = "autorouteViaRingThickness";
 QString Via::DefaultAutorouteViaHoleSize;
 QString Via::DefaultAutorouteViaRingThickness;
 
-Via::Via( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: Hole(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+Via::Via( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: Hole(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 	QSettings settings;
 	QString ringThickness = settings.value(AutorouteViaRingThickness, "").toString();
@@ -63,11 +63,11 @@ Via::Via( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentif
 		DefaultAutorouteViaHoleSize = TheHoleThing.holeSize;
 	}
 
-	//DebugDialog::debug(QString("creating via %1 %2 %3").arg((long) this, 0, 16).arg(id).arg(m_viewIdentifier));
+	//DebugDialog::debug(QString("creating via %1 %2 %3").arg((long) this, 0, 16).arg(id).arg(m_viewID));
 }
 
 Via::~Via() {
-	//DebugDialog::debug(QString("deleting via %1 %2 %3").arg((long) this, 0, 16).arg(m_id).arg(m_viewIdentifier));
+	//DebugDialog::debug(QString("deleting via %1 %2 %3").arg((long) this, 0, 16).arg(m_id).arg(m_viewID));
 }
 
 void Via::initHoleSettings(HoleSettings & holeSettings) 
@@ -77,7 +77,7 @@ void Via::initHoleSettings(HoleSettings & holeSettings)
 }
 
 void Via::setBoth(const QString & holeDiameter, const QString & ringThickness) {
-	if (this->m_viewIdentifier != ViewIdentifierClass::PCBView) return;
+	if (this->m_viewID != ViewLayer::PCBView) return;
 
 	ItemBase * otherLayer = setBothSvg(holeDiameter, ringThickness);
 	resetConnectors(otherLayer, otherLayer->fsvgRenderer());
