@@ -18,20 +18,24 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6912 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
 #include "virtualwire.h"
 #include "../connectors/connectoritem.h"
+#include "../model/modelpart.h"
 
-VirtualWire::VirtualWire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
-	: ClipableWire(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, false)
+const double VirtualWire::ShapeWidthExtra = 4;
+
+VirtualWire::VirtualWire( ModelPart * modelPart, ViewLayer::ViewID viewID,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
+	: ClipableWire(modelPart, viewID,  viewGeometry,  id, itemMenu, false)
 {
-	m_colorWasNamed = false;
 	// note: at this point in fritzing development, the VirtualWire class is only ever used for ratsnest wires
+	modelPart->setLocalProp("ratsnest", "true");
+	m_colorWasNamed = false;
 	setFlag(QGraphicsItem::ItemIsSelectable, false);
 }
 
@@ -49,8 +53,8 @@ void VirtualWire::connectionChange(ConnectorItem * onMe, ConnectorItem * onIt, b
 	checkVisibility(onMe, onIt, connect);
 }
 
-FSvgRenderer * VirtualWire::setUpConnectors(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier) {
-	FSvgRenderer * renderer = Wire::setUpConnectors(modelPart, viewIdentifier);
+FSvgRenderer * VirtualWire::setUpConnectors(ModelPart * modelPart, ViewLayer::ViewID viewID) {
+	FSvgRenderer * renderer = Wire::setUpConnectors(modelPart, viewID);
 	hideConnectors();
 	return renderer;
 }
@@ -122,3 +126,8 @@ void VirtualWire::setColorWasNamed(bool colorWasNamed) {
 bool VirtualWire::colorWasNamed() {
 	return m_colorWasNamed;
 }
+
+QPainterPath VirtualWire::shape() const
+{
+	return shapeAux(m_hoverStrokeWidth);
+}
