@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 7000 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-29 07:24:08 +0200 (Mo, 29. Apr 2013) $
 
 ********************************************************************/
 
@@ -60,7 +60,7 @@ class Wire : public ItemBase, public CursorKeyListener
 Q_OBJECT
 
 public:
-	Wire(class ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry &, long id, QMenu * itemMenu, bool initLabel);
+	Wire(class ModelPart *, ViewLayer::ViewID, const ViewGeometry &, long id, QMenu * itemMenu, bool initLabel);
 	virtual ~Wire();
 
 
@@ -85,7 +85,7 @@ public:
 	void initDragEnd(ConnectorItem * dragEnd, QPointF scenePos);
 	void initDragCurve(QPointF scenePos);
 	bool initNewBendpoint(QPointF scenePos, class Bezier & left, class Bezier & right);
-	void connectedMoved(ConnectorItem * from, ConnectorItem * to);
+	void connectedMoved(ConnectorItem * from, ConnectorItem * to, QList<ConnectorItem *> & already);
 	void setLineAnd(QLineF line, QPointF pos, bool useLine);
 	ConnectorItem * otherConnector(ConnectorItem *);
 	ConnectorItem * connector0();
@@ -98,7 +98,6 @@ public:
 	void setPcbPenBrush(QBrush & brush);
 	bool getRouted();
 	void setRouted(bool);
-	bool getRatsnest();
 	void setRatsnest(bool);
 	void setAutoroutable(bool);
 	bool getAutoroutable();
@@ -133,7 +132,7 @@ public:
 	bool canChangeColor();
 	void collectDirectWires(QList<Wire *> & wires);
 	bool isGrounded();
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 	bool hasPartLabel();
 	PluralType isPlural();
 	virtual bool canSwitchLayers();
@@ -160,9 +159,14 @@ public:
 	bool hasShadow();
 	bool canChainMultiple();
 	void cursorKeyEvent(Qt::KeyboardModifiers modifiers);
+	void setDisplayBendpointCursor(bool);
+    bool banded();
+    void setBanded(bool);
+	void setProp(const QString & prop, const QString & value);
 
 protected slots:
 	void colorEntry(const QString & text);
+    void setBandedProp(bool);
 
 public:
 	static double STANDARD_TRACE_WIDTH;
@@ -172,6 +176,7 @@ public:
 public:
 	static void initNames();
 	static void cleanup();
+    static QVector<qreal> TheDash;
 
 protected:
 	void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
@@ -190,14 +195,14 @@ protected:
 	bool acceptsMouseDoubleClickConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	bool acceptsMouseMoveConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	bool acceptsMouseReleaseConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
- 	virtual class FSvgRenderer * setUpConnectors(class ModelPart *, ViewIdentifierClass::ViewIdentifier);
+ 	virtual class FSvgRenderer * setUpConnectors(class ModelPart *, ViewLayer::ViewID);
 	void collectChained(ConnectorItem * connectorItem, QList<Wire *> & chained, QList<ConnectorItem *> & ends);
 	void setConnector0Rect();
 	void setConnector1Rect();
 	void collectWiresAux(QList<Wire *> & wires, ConnectorItem * start);
 	void setShadowColor(QColor &);
 	void calcNewLine(ConnectorItem * from, ConnectorItem * to, QPointF & p1, QPointF & p2);
-	void collectDirectWires(ConnectorItem * connectorItem, QList<Wire *> & wires);
+	void collectDirectWires(ConnectorItem * connectorItem, QList<Wire *> & wires, QList<ConnectorItem *> & junctions);
 	QVariant itemChange(GraphicsItemChange change, const QVariant &value);
 	void getConnectedColor(ConnectorItem *, QBrush * &, QPen * &, double & opacity, double & negativePenWidth, bool & negativeOffsetRect);
 	bool connectionIsAllowed(ConnectorItem *);
@@ -212,11 +217,11 @@ protected:
 	void hoverEnterEvent( QGraphicsSceneHoverEvent * event );
     void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
 	void updateCursor(Qt::KeyboardModifiers);
-    ViewIdentifierClass::ViewIdentifier useViewIdentifierForPixmap(ViewIdentifierClass::ViewIdentifier, bool swappingEnabled);
+    ViewLayer::ViewID useViewIDForPixmap(ViewLayer::ViewID, bool swappingEnabled);
 
 protected:
 	QLineF	m_line;
-	QPen	m_pen;	
+	QPen	m_pen;		
 	QPointF m_wireDragOrigin;
 	bool m_dragEnd;
 	bool m_dragCurve;
@@ -240,6 +245,8 @@ protected:
 	double m_hoverStrokeWidth;
 	bool m_canHaveCurve;
 	class Bezier * m_bezier;
+	bool m_displayBendpointCursor;
+    bool m_banded;
 
 public:
 	static QStringList colorNames;
