@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6268 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-09 08:53:47 +0200 (Thu, 09 Aug 2012) $
+$Revision: 6956 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-07 12:14:50 +0200 (So, 07. Apr 2013) $
 
 ********************************************************************/
 
@@ -32,7 +32,6 @@ $Date: 2012-08-09 08:53:47 +0200 (Thu, 09 Aug 2012) $
 #include "../version/version.h"
 #include "../utils/folderutils.h"
 #include "../items/itembase.h"
-#include "../items/virtualwire.h"
 
 #include <QDomElement>
 #include <QBitArray>
@@ -47,6 +46,7 @@ InstanceTitleIncrementHash NullInstanceTitleIncrements;
 
 static const QRegExp InstanceTitleRegExp("^(.*[^\\d])(\\d+)$");
 
+static const QList<ViewImage *> EmptyViewImages;
 
 ////////////////////////////////////////
 
@@ -56,15 +56,14 @@ ModelPart::ModelPart(ItemType type)
 	commonInit(type);
 	m_modelPartShared = NULL;
 	m_index = m_nextIndex++;
-	m_originalModelPartShared = false;  // TODO: make this a QSharedPointer
 }
 
-ModelPart::ModelPart(QDomDocument * domDocument, const QString & path, ItemType type)
+ModelPart::ModelPart(QDomDocument & domDocument, const QString & path, ItemType type)
 	: QObject()
 {
 	commonInit(type);
 	m_modelPartShared = new ModelPartShared(domDocument, path);
-	m_originalModelPartShared = true;		// TODO: make this a QSharedPointer
+    m_modelPartShared->addOwner(this);
 }
 
 void ModelPart::commonInit(ItemType type) {
@@ -87,20 +86,10 @@ ModelPart::~ModelPart() {
 		delete itih;
 	}
 
-	if (m_originalModelPartShared) {		// TODO: make this a QSharedPointer
-		if (m_modelPartShared) {
-			delete m_modelPartShared;
-		}
-	}
-
 	foreach (Connector * connector, m_connectorHash.values()) {
 		delete connector;
 	}
 	m_connectorHash.clear();
-	foreach (Connector * connector, m_deletedConnectors) {
-		delete connector;
-	}
-	m_deletedConnectors.clear();
 
 	clearBuses();
 }
@@ -123,6 +112,12 @@ const QString & ModelPart::author() {
 	return ___emptyString___;
 }
 
+const QString & ModelPart::taxonomy() {
+	if (m_modelPartShared != NULL) return m_modelPartShared->taxonomy();
+
+	return ___emptyString___;
+}
+
 const QString & ModelPart::uri() {
 	if (m_modelPartShared != NULL) return m_modelPartShared->uri();
 
@@ -146,6 +141,7 @@ void ModelPart::copy(ModelPart * modelPart) {
 
 	m_type = modelPart->itemType();
 	m_modelPartShared = modelPart->modelPartShared();
+    if (m_modelPartShared) m_modelPartShared->addOwner(this);
 	m_locationFlags = modelPart->m_locationFlags;
 }
 
@@ -160,7 +156,7 @@ void ModelPart::copyStuff(ModelPart * modelPart) {
 ModelPartShared * ModelPart::modelPartShared() {
 	if(!m_modelPartShared) {
 		m_modelPartShared = new ModelPartShared();
-		m_originalModelPartShared = true;		// TODO: make this a QSharedPointer
+        m_modelPartShared->addOwner(this);
 	}
 	return m_modelPartShared;
 }
@@ -170,7 +166,8 @@ ModelPartSharedRoot * ModelPart::modelPartSharedRoot() {
 }
 
 void ModelPart::setModelPartShared(ModelPartShared * modelPartShared) {
-	m_modelPartShared = modelPartShared;
+	m_modelPartShared = modelPartShared;    
+    if (modelPartShared) m_modelPartShared->addOwner(this);
 }
 
 void ModelPart::addViewItem(ItemBase * item) {
@@ -189,9 +186,9 @@ ItemBase * ModelPart::viewItem(QGraphicsScene * scene) {
 	return NULL;
 }
 
-ItemBase * ModelPart::viewItem(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+ItemBase * ModelPart::viewItem(ViewLayer::ViewID viewID) {
 	foreach (ItemBase * itemBase, m_viewItems) {
-		if (itemBase->viewIdentifier() == viewIdentifier) return itemBase;
+		if (itemBase->viewID() == viewID) return itemBase;
 	}
 
 	return NULL;
@@ -221,7 +218,7 @@ void ModelPart::saveInstances(const QString & fileName, QXmlStreamWriter & strea
 		streamWriter.writeStartElement("instances");
 	}
 
-	if (m_viewItems.size() > 0) {
+	if (parent() != NULL) {  // m_viewItems.size() > 0
 		saveInstance(streamWriter);
 	}
 
@@ -248,15 +245,17 @@ void ModelPart::saveInstances(const QString & fileName, QXmlStreamWriter & strea
 
 void ModelPart::saveInstance(QXmlStreamWriter & streamWriter) 
 {
-	if (qobject_cast<VirtualWire *>(m_viewItems.at(0)) != NULL) return;				// don't save virtual wires
+	if (localProp("ratsnest").toBool()) {
+		return;				// don't save virtual wires
+	}
 
 	streamWriter.writeStartElement("instance");
 	if (m_modelPartShared != NULL) {
-		const QString & moduleIdRef = m_modelPartShared->moduleID();
+		QString moduleIdRef = m_modelPartShared->moduleID();
 		streamWriter.writeAttribute("moduleIdRef", moduleIdRef);
 		streamWriter.writeAttribute("modelIndex", QString::number(m_index));
 		streamWriter.writeAttribute("path", m_modelPartShared->path());
-		if (m_modelPartShared->flippedSMD()) {
+        if (m_modelPartShared->flippedSMD()) {
 			streamWriter.writeAttribute("flippedSMD", "true");
 		}
 	}
@@ -355,6 +354,26 @@ void ModelPart::saveAsPart(QXmlStreamWriter & streamWriter, bool startDocument)
 
     	writeTag(streamWriter,"taxonomy",m_modelPartShared->taxonomy());
     	writeTag(streamWriter,"description",m_modelPartShared->description());
+
+        QString spice = m_modelPartShared->spice();
+        if (!spice.isEmpty()) {
+            streamWriter.writeStartElement("spice");
+            QStringList lines = spice.split("\r",QString::SkipEmptyParts);
+            foreach (QString line, lines) {
+                writeTag(streamWriter, "line", line);
+            }
+            QString spiceModel = m_modelPartShared->spiceModel();
+            if (!spiceModel.isEmpty()) {
+                lines = spiceModel.split("\r",QString::SkipEmptyParts);
+                foreach (QString line, lines) {
+                    writeTag(streamWriter, "model", line);
+                }
+            }
+            streamWriter.writeEndElement();
+        }
+
+
+    	writeTag(streamWriter,"spice",m_modelPartShared->spice());
     	writeTag(streamWriter,"url",m_modelPartShared->url());
 	}
 
@@ -402,8 +421,8 @@ void ModelPart::initConnectors(bool force) {
 	if(force) {
 		foreach (Connector * connector, m_connectorHash.values()) {
 			// due to craziness in the parts editor
-			m_deletedConnectors.append(connector);
-			//delete connector;
+			// m_deletedConnectors.append(connector);
+			delete connector;
 		}
 		m_connectorHash.clear();		
 		clearBuses();
@@ -489,6 +508,13 @@ const QDomElement & ModelPart::instanceDomElement() {
 	return m_instanceDomElement;
 }
 
+const QString & ModelPart::fritzingVersion() {
+
+	if (m_modelPartShared != NULL) return m_modelPartShared->fritzingVersion();
+
+	return ___emptyString___;
+}
+
 const QString & ModelPart::title() {
 	if (!m_localTitle.isEmpty()) return m_localTitle;
 
@@ -519,6 +545,18 @@ const QString & ModelPart::description() {
 	return ___emptyString___;
 }
 
+const QString & ModelPart::spice() {
+	if (m_modelPartShared != NULL) return m_modelPartShared->spice();
+
+	return ___emptyString___;
+}
+
+const QString & ModelPart::spiceModel() {
+	if (m_modelPartShared != NULL) return m_modelPartShared->spiceModel();
+
+	return ___emptyString___;
+}
+
 const QString & ModelPart::url() {
 	if (m_modelPartShared != NULL) return m_modelPartShared->url();
 
@@ -578,6 +616,13 @@ bool ModelPart::isAlien() {
 void ModelPart::setAlien(bool alien) {
 	setLocationFlag(alien, AlienFlag);
 }
+bool ModelPart::isInBin() {
+	return (m_locationFlags & InBinFlag) != 0;;
+}
+
+void ModelPart::setInBin(bool inBin) {
+	setLocationFlag(inBin, InBinFlag);
+}
 
 bool ModelPart::isFzz() {
 	return (m_locationFlags & FzzFlag) != 0;;
@@ -596,16 +641,50 @@ void ModelPart::setLocationFlag(bool setting, LocationFlag flag) {
 	}
 }
 
-bool ModelPart::hasViewIdentifier(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
-	QDomDocument * doc = domDocument();
-	if (doc == NULL) return false;
+bool ModelPart::hasViewID(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->hasViewID(viewID);
 
-	QDomElement viewsElems = doc->documentElement().firstChildElement("views");
-	if(viewsElems.isNull()) return false;
+    return false;
 
-	return !viewsElems.firstChildElement(ViewIdentifierClass::viewIdentifierXmlName(viewIdentifier)).isNull();
 }
 
+bool ModelPart::canFlipVertical(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->canFlipVertical(viewID);
+
+    return false;
+
+}
+
+bool ModelPart::canFlipHorizontal(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->canFlipHorizontal(viewID);
+
+    return false;
+}
+
+LayerList ModelPart::viewLayers(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->viewLayers(viewID);
+
+    LayerList layerList;
+    return layerList;
+}
+
+QString ModelPart::imageFileName(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->imageFileName(viewID);
+
+    return "";
+}
+
+QString ModelPart::imageFileName(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
+    if (m_modelPartShared) return m_modelPartShared->imageFileName(viewID, viewLayerID);
+
+    return "";
+}
+
+bool ModelPart::anySticky(ViewLayer::ViewID viewID) {
+    if (m_modelPartShared) return m_modelPartShared->anySticky(viewID);
+
+    return false;
+}
 
 QList<ModelPart*> ModelPart::getAllParts() {
 	QList<ModelPart*> retval;
@@ -701,8 +780,12 @@ ModelPartList * ModelPart::ensureInstanceTitleIncrements(const QString & prefix)
 	return modelParts;
 }
 
-void ModelPart::setInstanceTitle(QString title) {
-	if (title.compare(m_instanceTitle) == 0) return;
+void ModelPart::setInstanceTitle(QString title, bool initial) {
+    if (initial) {
+        if (setSubpartInstanceTitle()) return;
+    }
+
+    if (title.compare(m_instanceTitle) == 0) return;
 
 	clearOldInstanceTitle(m_instanceTitle);
 
@@ -716,6 +799,38 @@ void ModelPart::setInstanceTitle(QString title) {
 		modelParts->append(this);
 	}
 	//DebugDialog::debug(QString("adding title:%1 ix:%2 c:%3").arg(title).arg(modelIndex()).arg(modelParts->count()));
+
+    if (m_modelPartShared && m_modelPartShared->hasSubparts()) {
+        if (m_viewItems.count() > 0) {
+            ItemBase * itemBase = m_viewItems.last();
+            if (itemBase) {
+                foreach (ItemBase * subpart, itemBase->subparts()) {
+                    subpart->setInstanceTitle("", true);   // will end up calling setSubpartInstanceTitle()
+                }
+            }
+        }
+    }
+}
+
+bool ModelPart::setSubpartInstanceTitle() {
+    if (m_modelPartShared == NULL) return false;
+    if (m_modelPartShared->superpart() == NULL) return false;
+    if (m_viewItems.count() <= 0) return false;
+                
+    ItemBase * itemBase = m_viewItems.last();
+    if (itemBase == NULL) return false;
+
+    itemBase = itemBase->superpart();
+    if (itemBase == NULL) return false;
+
+    QString superTitle = itemBase->instanceTitle();
+    if (superTitle.isEmpty()) return false;
+
+    QString label = m_modelPartShared->label();
+    if (label.isEmpty()) return false;
+
+    m_instanceTitle = superTitle + "_" + label;
+    return true;
 }
 
 QString ModelPart::getNextTitle(const QString & title) {
@@ -769,7 +884,7 @@ void ModelPart::setOrderedChildren(QList<QObject*> children) {
 
 void ModelPart::setLocalProp(const char * name, const QVariant & value) {
     //DebugDialog::debug(QString("mp set prop %1 %2").arg(name).arg(value.toString()));
-	setProperty(name, value);
+	QObject::setProperty(name, value);
 }
 
 QVariant ModelPart::localProp(const char * name) const {
@@ -806,10 +921,6 @@ bool ModelPart::isObsolete() {
 	return false;
 }
 
-void ModelPart::setFlippedSMD(bool f) {
-	if (m_modelPartShared != NULL) m_modelPartShared->setFlippedSMD(f);
-}
-
 bool ModelPart::flippedSMD() {
 	if (m_modelPartShared != NULL) {
 		return m_modelPartShared->flippedSMD();
@@ -826,28 +937,22 @@ bool ModelPart::needsCopper1() {
 	return false;
 }
 
-QDomDocument* ModelPart::domDocument() {
-	if (m_modelPartShared == NULL) return NULL;
-
-	return m_modelPartShared->domDocument();
-}
-
-bool ModelPart::hasViewFor(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+bool ModelPart::hasViewFor(ViewLayer::ViewID viewID) {
 	if (m_modelPartShared == NULL) return false;
 
-	return m_modelPartShared->hasViewFor(viewIdentifier);
+	return m_modelPartShared->hasViewFor(viewID);
 }
 
-bool ModelPart::hasViewFor(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+bool ModelPart::hasViewFor(ViewLayer::ViewID viewID, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_modelPartShared == NULL) return false;
 
-	return m_modelPartShared->hasViewFor(viewIdentifier, viewLayerID);
+	return m_modelPartShared->hasViewFor(viewID, viewLayerID);
 }
 
-QString ModelPart::hasBaseNameFor(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+QString ModelPart::hasBaseNameFor(ViewLayer::ViewID viewID) {
 	if (m_modelPartShared == NULL) return ___emptyString___;
 
-	return m_modelPartShared->hasBaseNameFor(viewIdentifier);
+	return m_modelPartShared->hasBaseNameFor(viewID);
 }
 
 const QStringList & ModelPart::displayKeys() {
@@ -870,6 +975,18 @@ void ModelPart::setConnectorLocalName(const QString & id, const QString & name)
 	}
 }
 
+QString ModelPart::connectorLocalName(const QString & id)
+{
+	if (id.isEmpty()) return "";
+
+	Connector * connector = m_connectorHash.value(id, NULL);
+	if (connector) {
+		return connector->connectorLocalName();
+	}
+
+	return "";
+}
+
 QString ModelPart::family(){
 	if (m_modelPartShared) return m_modelPartShared->family();
 
@@ -879,3 +996,81 @@ QString ModelPart::family(){
 bool ModelPart::hasViewItems() {
 	return (m_viewItems.count() > 0);
 }
+
+void ModelPart::setDBID(qulonglong dbid) {
+    if (m_modelPartShared) m_modelPartShared->setDBID(dbid);
+}
+
+qulonglong ModelPart::dbid() {
+    if (m_modelPartShared) return m_modelPartShared->dbid();
+
+    return 0;
+}
+
+const QList<ViewImage *> ModelPart::viewImages() {
+    if (m_modelPartShared) return m_modelPartShared->viewImages();
+
+    return EmptyViewImages;
+}
+
+void ModelPart::setViewImage(ViewImage * viewImage) {
+    if (m_modelPartShared) m_modelPartShared->setViewImage(viewImage);
+}
+
+void ModelPart::setTag(const QString & tag)
+{
+    if (m_modelPartShared) m_modelPartShared->setTag(tag);
+}
+
+void ModelPart::setProperty(const QString & name, const QString &value, bool showInLabel)
+{
+    if (m_modelPartShared) m_modelPartShared->setProperty(name, value, showInLabel);
+}
+
+bool ModelPart::showInLabel(const QString & propertyName) {
+    if (m_modelPartShared) return m_modelPartShared->showInLabel(propertyName);
+
+    return false;
+}
+
+void ModelPart::addConnector(Connector * connector) {
+    m_connectorHash.insert(connector->connectorSharedID(), connector);
+
+    if (m_modelPartShared) m_modelPartShared->addConnector(connector->connectorShared());
+}
+
+void ModelPart::flipSMDAnd() {
+    if (m_modelPartShared) m_modelPartShared->flipSMDAnd();
+}
+
+void ModelPart::setImageFileName(ViewLayer::ViewID viewID, const QString & filename) {
+    if (m_modelPartShared) m_modelPartShared->setImageFileName(viewID, filename);
+}
+
+void ModelPart::lookForZeroConnector() {
+    if (m_modelPartShared) m_modelPartShared->lookForZeroConnector();
+}
+
+bool ModelPart::hasZeroConnector() {
+    if (m_modelPartShared) return m_modelPartShared->hasZeroConnector();
+
+    return false;
+}
+
+void ModelPart::killViewItems() {
+	foreach (ItemBase * itemBase, m_viewItems) {
+		if (itemBase) delete itemBase;
+	}
+
+    m_viewItems.clear();
+}
+
+bool ModelPart::hasSubparts() {
+    if (m_modelPartShared) return m_modelPartShared->hasSubparts();
+
+    return false;
+}
+
+void ModelPart::setSubpartID(const QString & id) {
+    if (m_modelPartShared) m_modelPartShared->setSubpartID(id);
+}
