@@ -36,6 +36,7 @@ $Date: 2013-04-29 13:10:59 +0200 (Mo, 29. Apr 2013) $
 #include "../version/version.h"
 #include "../layerattributes.h"
 #include "../utils/folderutils.h"
+#include "../utils/fmessagebox.h"
 #include "../utils/textutils.h"
 #include "../items/moduleidnames.h"
 #include "../items/partfactory.h"
@@ -95,7 +96,7 @@ PaletteModel::~PaletteModel()
 void PaletteModel::initParts(bool dbExists) {
 	QDir * dir = FolderUtils::getApplicationSubFolder("parts");
 	if (dir == NULL) {
-	    QMessageBox::information(NULL, QObject::tr("Fritzing"),
+	    FMessageBox::information(NULL, QObject::tr("Fritzing"),
 	                             QObject::tr("Parts folder not found.") );
 		return;
 	}
@@ -105,7 +106,7 @@ void PaletteModel::initParts(bool dbExists) {
 
 	loadParts(dbExists);
 	if (m_root == NULL) {
-	    QMessageBox::information(NULL, QObject::tr("Fritzing"),
+	    FMessageBox::information(NULL, QObject::tr("Fritzing"),
 	                             QObject::tr("No parts found.") );
 	}
 }
@@ -233,7 +234,7 @@ ModelPart * PaletteModel::loadPart(const QString & path, bool update) {
   
     QFile file(path);
     if (!file.open(QFile::ReadOnly | QFile::Text)) {
-        QMessageBox::warning(NULL, QObject::tr("Fritzing"),
+        FMessageBox::warning(NULL, QObject::tr("Fritzing"),
                              QObject::tr("Cannot read file %1:\n%2.")
                              .arg(path)
                              .arg(file.errorString()));
@@ -252,7 +253,7 @@ ModelPart * PaletteModel::loadPart(const QString & path, bool update) {
 	int errorColumn;
 	QDomDocument domDocument;
 	if (!domDocument.setContent(&file, true, &errorStr, &errorLine, &errorColumn)) {
-		QMessageBox::information(NULL, QObject::tr("Fritzing"),
+		FMessageBox::information(NULL, QObject::tr("Fritzing"),
 								QObject::tr("Parse error (2) at line %1, column %2:\n%3\n%4")
 								.arg(errorLine)
 								.arg(errorColumn)
@@ -336,6 +337,9 @@ ModelPart * PaletteModel::loadPart(const QString & path, bool update) {
 	else if (moduleID.endsWith(ModuleIDNames::StripboardModuleIDName)) {
 		type = ModelPart::Breadboard;
 	}
+	else if (moduleID.endsWith(ModuleIDNames::Stripboard2ModuleIDName)) {
+		type = ModelPart::Breadboard;
+	}
 	else if (propertiesText.contains("breadboard", Qt::CaseInsensitive)) {
 		type = ModelPart::Breadboard;
 	}
@@ -371,7 +375,7 @@ ModelPart * PaletteModel::loadPart(const QString & path, bool update) {
 
 	if (m_partHash.value(moduleID, NULL)) {
 		if(!update) {
-			QMessageBox::warning(NULL, QObject::tr("Fritzing"),
+			FMessageBox::warning(NULL, QObject::tr("Fritzing"),
 							 QObject::tr("The part '%1' at '%2' does not have a unique module id '%3'.")
 							 .arg(modelPart->title())
 							 .arg(path)
@@ -492,9 +496,7 @@ void PaletteModel::setOrdererChildren(QList<QObject*> children) {
 QList<ModelPart *> PaletteModel::search(const QString & searchText, bool allowObsolete) {
 	QList<ModelPart *> modelParts;
 
-	QStringList strings = searchText.split(":");
-	if (strings.count() > 2) return modelParts;
-
+	QStringList strings = searchText.split(" ");
     search(m_root, strings, modelParts, allowObsolete);
     return modelParts;
 }
@@ -504,51 +506,59 @@ void PaletteModel::search(ModelPart * modelPart, const QStringList & searchStrin
 	// or use lucene
 	// or google search api
 
+    int count = 0;
+    foreach (QString searchString, searchStrings) {
+        bool gotOne = false;
+        if (modelPart->title().contains(searchString, Qt::CaseInsensitive)) {
+            gotOne = true;
+	    }
+        else if (modelPart->description().contains(searchString, Qt::CaseInsensitive)) {
+            gotOne = true;
+	    }
+        else if (modelPart->url().contains(searchString, Qt::CaseInsensitive)) {
+            gotOne = true;
+	    }
+        else if (modelPart->author().contains(searchString, Qt::CaseInsensitive)) {
+            gotOne = true;
+	    }
+        else if (modelPart->moduleID().contains(searchString, Qt::CaseInsensitive)) {
+            gotOne = true;
+	    }
+        else {
+		    foreach (QString string, modelPart->tags()) {
+			    if (string.contains(searchString, Qt::CaseInsensitive)) {
+                    gotOne = true;
+				    break;
+			    }
+		    }
+	    }
+        if (!gotOne) {
+		    foreach (QString string, modelPart->properties().values()) {
+			    if (string.contains(searchString, Qt::CaseInsensitive)) {
+                    gotOne = true;
+				    break;
+			    }
+		    }
+	    }
+        if (!gotOne) {
+		    foreach (QString string, modelPart->properties().keys()) {
+			    if (string.contains(searchString, Qt::CaseInsensitive)) {
+                    gotOne = true;
+				    break;
+			    }
+		    }
+	    }
+        if (!gotOne) break;
 
-    ModelPart * candidate = NULL;
-    if (!candidate && modelPart->title().contains(searchStrings[0], Qt::CaseInsensitive)) {
-        candidate = modelPart;
-	}
-    if (!candidate && modelPart->description().contains(searchStrings[0], Qt::CaseInsensitive)) {
-        candidate = modelPart;
-	}
-    if (!candidate && modelPart->url().contains(searchStrings[0], Qt::CaseInsensitive)) {
-        candidate = modelPart;
-	}
-    if (!candidate && modelPart->author().contains(searchStrings[0], Qt::CaseInsensitive)) {
-        candidate = modelPart;
-	}
-    if (!candidate) {
-		foreach (QString string, modelPart->tags()) {
-			if (string.contains(searchStrings[0], Qt::CaseInsensitive)) {
-                candidate = modelPart;
-				break;
-			}
-		}
-	}
-    if (!candidate) {
-		foreach (QString string, modelPart->properties().values()) {
-			if (string.contains(searchStrings[0], Qt::CaseInsensitive)) {
-                candidate = modelPart;
-				break;
-			}
-		}
-	}
-    if (!candidate) {
-		foreach (QString string, modelPart->properties().keys()) {
-			if (string.contains(searchStrings[0], Qt::CaseInsensitive)) {
-                candidate = modelPart;
-				break;
-			}
-		}
-	}
+        count++;
+    }
 
-    if (candidate && !modelParts.contains(candidate)) {
-        if (!allowObsolete && candidate->isObsolete()) {
+    if ((count == searchStrings.count()) && !modelParts.contains(modelPart)) {
+        if (!allowObsolete && modelPart->isObsolete()) {
         }
         else
         {
-            modelParts.append(candidate);
+            modelParts.append(modelPart);
             emit addSearchMaximum(1);
         }
     }
@@ -661,4 +671,10 @@ ModelPart * PaletteModel::makeSubpart(ModelPart * originalModelPart, const QDomE
     return modelPart;
 }
 
-
+QList<ModelPart *> PaletteModel::allParts() {
+    QList<ModelPart *> modelParts;
+    foreach (ModelPart * modelPart, m_partHash.values()) {
+        if (!modelPart->isObsolete()) modelParts.append(modelPart);
+    }
+    return modelParts;
+}
