@@ -131,7 +131,7 @@ BinManager::BinManager(class ReferenceModel *referenceModel, class HtmlInfoView
 
 	lo->setMargin(0);
 	lo->setSpacing(0);
-	setMaximumHeight(500);
+    setMaximumHeight(500);
 }
 
 BinManager::~BinManager() {
@@ -163,6 +163,7 @@ void BinManager::initStandardBins()
 	openCoreBinIn();
 		
 	//DebugDialog::debug("after core bin");
+    currentChanged(m_stackTabWidget->currentIndex());
 
 	connectTabWidget();
 }
@@ -303,7 +304,7 @@ QString BinManager::createIfBinNotExists(const QString & dest, const QString & s
 {
     QString binPath = dest;
     QFile file(source);
-	file.copy(binPath);
+	FolderUtils::slamCopy(file, binPath);
 	return binPath;
 }
 
@@ -468,6 +469,24 @@ PartsBinPaletteWidget* BinManager::newBin() {
 }
 
 void BinManager::currentChanged(int index) {
+	for (int i = 0; i < m_stackTabWidget->count(); i++) {
+		PartsBinPaletteWidget* bin = (PartsBinPaletteWidget *) m_stackTabWidget->widget(i);
+        if (bin == NULL) continue;
+        if (!bin->hasMonoIcon()) continue;
+
+        if (i == index) {
+            m_stackTabWidget->setTabIcon(i, bin->icon());
+        }
+        else {
+            m_stackTabWidget->setTabIcon(i, bin->monoIcon());
+        }
+
+    }
+
+        
+
+    
+
 	PartsBinPaletteWidget *bin = getBin(index);
 	if (bin) setAsCurrentBin(bin);
 }
@@ -488,6 +507,12 @@ void BinManager::setAsCurrentBin(PartsBinPaletteWidget* bin) {
 		bin->focusSearch();
 	}
 
+    /*
+
+    // jrc 3-july-2013 commented out this stylesheet change:
+    //      it causes the tab bar to lose its scroll position
+    //      the stylesheet change is commented out in the qss file, so visually it's a no-op
+
 	QString style = m_mainWindow->styleSheet();
 	if(m_currentBin && m_stackTabWidget) {
 		StackTabBar *currTabBar = m_stackTabWidget->stackTabBar();
@@ -502,6 +527,7 @@ void BinManager::setAsCurrentBin(PartsBinPaletteWidget* bin) {
 		currTabBar->setStyleSheet("");
 		currTabBar->setStyleSheet(style);
 	}
+    */
 }
 
 void BinManager::closeBinIn(int index) {
@@ -988,6 +1014,14 @@ void BinManager::createCombinedMenu()
 	m_renameBinAction->setStatusTip(tr("Rename parts bin..."));
 	connect(m_renameBinAction, SIGNAL(triggered()),this, SLOT(renameBin()));
 
+	m_copyToSketchAction = new QAction(tr("Copy to Sketch"), this);
+	m_copyToSketchAction->setStatusTip(tr("Copy all the parts in the bin to a sketch"));
+	connect(m_copyToSketchAction, SIGNAL(triggered()),this, SLOT(copyToSketch()));
+
+	m_copyAllToSketchAction = new QAction(tr("Copy all to Sketch"), this);
+	m_copyAllToSketchAction->setStatusTip(tr("Copy all loaded parts to the sketch"));
+	connect(m_copyAllToSketchAction, SIGNAL(triggered()),this, SLOT(copyAllToSketch()));
+
 	m_showListViewAction = new QAction(tr("Show Bin in List View"), this);
 	m_showListViewAction->setCheckable(true);
 	m_showListViewAction->setStatusTip(tr("Display parts as a list"));
@@ -1008,6 +1042,10 @@ void BinManager::createCombinedMenu()
 	m_combinedMenu->addAction(m_saveBinAsAction);
 	m_combinedMenu->addAction(m_saveBinAsBundledAction);
 	m_combinedMenu->addAction(m_renameBinAction);
+#ifndef QT_NO_DEBUG
+	m_combinedMenu->addAction(m_copyToSketchAction);
+	m_combinedMenu->addAction(m_copyAllToSketchAction);
+#endif
 	m_combinedMenu->addSeparator();
 	m_combinedMenu->addAction(m_showIconViewAction);
 	m_combinedMenu->addAction(m_showListViewAction);
@@ -1258,7 +1296,7 @@ void BinManager::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 	QFile fzp(path);
 	
 	QString parts = FolderUtils::getUserDataStorePath("parts");
-	fzp.copy(parts + "/contrib/" + info.fileName());
+    FolderUtils::slamCopy(fzp, parts + "/contrib/" + info.fileName());
 	QString prefix = parts + "/svg/contrib/";
 
 	QDir dir = info.absoluteDir();
@@ -1272,7 +1310,7 @@ void BinManager::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 		QString fn = mp->hasBaseNameFor(viewID);
 		if (!fn.isEmpty()) {
 			QFile svg(dir.absoluteFilePath(fn));
-			svg.copy(prefix + fn);
+            FolderUtils::slamCopy(svg, prefix + fn);
 		}
 	}
 }
@@ -1325,3 +1363,24 @@ void BinManager::reloadPart(const QString & moduleID) {
 		bin->reloadPart(moduleID);
 	}
 }
+
+void BinManager::copyToSketch() {
+	PartsBinPaletteWidget * bin = currentBin();
+	if (bin == NULL) return;
+
+    QList<ModelPart *> modelParts = bin->getAllParts();
+    if (modelParts.count() == 0) return;
+
+    if (m_mainWindow) {
+        m_mainWindow->addToSketch(modelParts);
+    }
+}
+
+void BinManager::copyAllToSketch() {
+    QList<ModelPart *> modelParts;
+
+    if (m_mainWindow) {
+        m_mainWindow->addToSketch(modelParts);
+    }
+}
+
