@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6549 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-11 06:54:26 +0200 (Do, 11. Okt 2012) $
 
 ********************************************************************/
 
@@ -90,6 +90,7 @@ void StackTabBar::dragMoveEvent(QDragMoveEvent* event) {
 			event->acceptProposedAction();
 			m_dragMoveTimer.setProperty("index", index);
 			if (!m_dragMoveTimer.isActive()) {
+                DebugDialog::debug("starting drag move timer");
 				m_dragMoveTimer.start();
 			}
 			//DebugDialog::debug(QString("setting index %1").arg(index));
