@@ -84,7 +84,7 @@ class PartsBinListView : public QListWidget, public PartsBinView {
 		bool dropMimeData(int index, const QMimeData *data, Qt::DropAction action);
 		QMimeData * mimeData(const QList<QListWidgetItem *> items) const;
 		QStringList mimeTypes() const;
-		void loadImage(QListWidgetItem * lwi, const QString & moduleID); 
+		void loadImage(ModelPart *, QListWidgetItem * lwi, const QString & moduleID); 
 
 	protected:
 		class HtmlInfoView * m_infoView;
