@@ -59,13 +59,15 @@ inline bool isCustomSvg(const QString & string) {
 
 static QHash<QString, PaletteModel *> PaletteBinModels;
 
+static QIcon EmptyIcon;
+
 //////////////////////////////////////////////
 
 PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *referenceModel, HtmlInfoView *infoView, WaitPushUndoStack *undoStack, BinManager* manager) :
 	QFrame(manager)
 {
     m_binLabel = NULL;
-	m_icon = NULL;
+	m_monoIcon = m_icon = NULL;
 	m_searchLineEdit = NULL;
 	m_saveQuietly = false;
 	m_fastLoaded = false;
@@ -149,6 +151,7 @@ PartsBinPaletteWidget::~PartsBinPaletteWidget() {
 	}
    
     if (m_icon) delete m_icon;
+    if (m_monoIcon) delete m_monoIcon;
 }
 
 void PartsBinPaletteWidget::cleanup() {
@@ -331,13 +334,34 @@ void PartsBinPaletteWidget::grabTitle(const QString & title, QString & iconFilen
 		painter.end();	
 		//image.save(FolderUtils::getUserDataStorePath("") + "/test icon.png");
 		m_icon = new QIcon(QPixmap::fromImage(image));
+        m_monoIcon = new QIcon(":resources/bins/icons/Custom1-mono.png");
+
+        // TODO: hack svg to make a mono icon
 	}
 	else {
-		QString path = ":resources/bins/icons/" + iconFilename;
-		QFile file(path);
-		if (file.exists()) {
-			m_icon = new QIcon(path);
-		}
+        QFileInfo info(m_fileName);
+        QDir dir = info.absoluteDir();
+        QString path = dir.absoluteFilePath(iconFilename);
+        QFile file1(path);
+        if (file1.exists()) {
+            m_icon = new QIcon(path);
+        }
+        else {
+            path = ":resources/bins/icons/" + iconFilename;
+		    QFile file2(path);
+		    if (file2.exists()) {
+			    m_icon = new QIcon(path);
+		    }
+        }
+
+        if (m_icon) {
+            int ix = path.lastIndexOf(".");
+            path.insert(ix, "-mono");
+            QFile file3(path);
+            if (file3.exists()) {
+                m_monoIcon = new QIcon(path);
+            }
+        }
 	}
 }
 
@@ -816,10 +840,19 @@ bool PartsBinPaletteWidget::currentViewIsIconView() {
 }
 
 QIcon PartsBinPaletteWidget::icon() {
-	static QIcon emptyIcon;
 	if (m_icon) return *m_icon;
 
-	return emptyIcon;
+	return EmptyIcon;
+}
+
+bool PartsBinPaletteWidget::hasMonoIcon() {
+    return m_monoIcon != NULL;
+}
+
+QIcon PartsBinPaletteWidget::monoIcon() {
+	if (m_monoIcon) return *m_monoIcon;
+
+	return EmptyIcon;
 }
 
 QMenu * PartsBinPaletteWidget::combinedMenu()
@@ -874,8 +907,14 @@ void PartsBinPaletteWidget::changeIconColor() {
 		}
 	}
 
+#ifndef QT_NO_DEBUG
+    //QFileInfo info(m_fileName);
+    //image.save(FolderUtils::getUserDataStorePath("") + "/" + info.completeBaseName() + ".png");
+#endif
+
 	delete m_icon;
 	m_icon = new QIcon(QPixmap::fromImage(image));
+
 	m_manager->setTabIcon(this, m_icon);
 	setDirty();
 
@@ -942,3 +981,14 @@ void PartsBinPaletteWidget::reloadPart(const QString & moduleID) {
 	m_iconView->reloadPart(moduleID);
 	m_listView->reloadPart(moduleID);
 }
+
+QList<ModelPart *> PartsBinPaletteWidget::getAllParts() {
+    QList<ModelPart*> empty;
+    if (m_model == NULL) return empty;
+
+    if (m_model->root() == NULL) return empty;
+
+    return m_model->root()->getAllParts();
+}
+
+
