@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6264 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-07 17:59:08 +0200 (Tue, 07 Aug 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sa, 29. Sep 2012) $
 
 ********************************************************************/
 
@@ -38,7 +38,7 @@ $Date: 2012-08-07 17:59:08 +0200 (Tue, 07 Aug 2012) $
 QHash<QString, QString> PartsBinView::TranslatedCategoryNames;
 QHash<QString, ItemBase *> PartsBinView::ItemBaseHash;
 
-PartsBinView::PartsBinView(ReferenceModel *refModel, PartsBinPaletteWidget *parent) {
+PartsBinView::PartsBinView(ReferenceModel *referenceModel, PartsBinPaletteWidget *parent) {
 	if (TranslatedCategoryNames.count() == 0) {
 		TranslatedCategoryNames.insert("Basic", QObject::tr("Basic"));
 		TranslatedCategoryNames.insert("Input", QObject::tr("Input"));
@@ -57,7 +57,7 @@ PartsBinView::PartsBinView(ReferenceModel *refModel, PartsBinPaletteWidget *pare
 		TranslatedCategoryNames.insert("Sensors",  QObject::tr("Sensors"));
 	}
 
-	m_refModel = refModel;
+	m_referenceModel = referenceModel;
 	m_parent = parent;
 }
 
@@ -86,7 +86,15 @@ void PartsBinView::reloadParts(PaletteModel * model) {
 }
 
 void PartsBinView::doClear() {
-	m_partHash.clear();
+	m_itemBaseHash.clear();
+}
+
+void PartsBinView::removePartReference(const QString & moduleID) {
+	ItemBase * itemBase = ItemBaseHash.value(moduleID);
+	if (itemBase) {
+		ItemBaseHash.remove(moduleID);
+		itemBase->deleteLater();
+	}
 }
 
 void PartsBinView::setItem(ModelPart * modelPart) {
@@ -208,7 +216,7 @@ void PartsBinView::dropEventAux(QDropEvent* event, bool justAppend) {
 		QPointF offset;
 		dataStream >> moduleID >> offset;
 
-		ModelPart * mp = m_refModel->retrieveModelPart(moduleID);
+		ModelPart * mp = m_referenceModel->retrieveModelPart(moduleID);
 		m_parent->copyFilesToContrib(mp, ItemDrag::originator());
 		if(mp) {
 			if(m_parent->contains(moduleID)) {
@@ -223,7 +231,7 @@ void PartsBinView::dropEventAux(QDropEvent* event, bool justAppend) {
 }
 
 bool PartsBinView::contains(const QString &moduleID) {
-	return m_partHash.contains(moduleID);
+	return m_itemBaseHash.contains(moduleID);
 }
 
 void PartsBinView::setInfoViewOnHover(bool infoViewOnHover) {
