@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6268 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-09 08:53:47 +0200 (Thu, 09 Aug 2012) $
+$Revision: 6934 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-22 08:35:24 +0100 (Fr, 22. Mrz 2013) $
 
 ********************************************************************/
 
@@ -81,7 +81,7 @@ void SvgIconPixmapItem::paint(QPainter *painter, const QStyleOptionGraphicsItem
 
 ////////////////////////////////////////////////////////////
 
-SvgIconWidget::SvgIconWidget(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, ItemBase * itemBase, bool plural)
+SvgIconWidget::SvgIconWidget(ModelPart * modelPart, ViewLayer::ViewID viewID, ItemBase * itemBase, bool plural)
 	: QGraphicsWidget() 
 {
 	m_moduleId = modelPart->moduleID();
@@ -105,46 +105,7 @@ SvgIconWidget::SvgIconWidget(ModelPart * modelPart, ViewIdentifierClass::ViewIde
 		this->setMaximumSize(PluralImage->size());
 		setAcceptHoverEvents(true);
 		setFlags(QGraphicsItem::ItemIsSelectable);
-
-		QString error;
-		LayerAttributes layerAttributes;
-		FSvgRenderer * renderer = m_itemBase->setUpImage(modelPart, viewIdentifier, ViewLayer::Icon, ViewLayer::ThroughHoleThroughTop_OneLayer, layerAttributes, error);
-        if (renderer == NULL) {
-            DebugDialog::debug(QString("missing renderer for icon %1").arg(modelPart->moduleID()));
-        }
-		if (renderer && m_itemBase) {
-			m_itemBase->setFilename(renderer->filename());
-		}
-
-		QPixmap pixmap(plural ? *PluralImage : *SingularImage);
-		QPixmap * icon = (renderer == NULL) ? NULL : FSvgRenderer::getPixmap(renderer, QSize(ICON_SIZE, ICON_SIZE));
-		if (icon) {
-			QPainter painter;
-			painter.begin(&pixmap);
-			if (plural) {
-				painter.drawPixmap(PLURAL_OFFSET, PLURAL_OFFSET, *icon);
-			}
-			else {
-				painter.drawPixmap(SINGULAR_OFFSET, SINGULAR_OFFSET, *icon);
-			}
-			painter.end();
-			delete icon;
-		}
-
-		m_pixmapItem = new SvgIconPixmapItem(pixmap, this);
-		m_pixmapItem->setPlural(plural);
-
-		m_pixmapItem->setFlags(0);
-		m_pixmapItem->setPos(0, 0);
-
-		if (m_itemBase) {
-			m_itemBase->setTooltip();
-			setToolTip(m_itemBase->toolTip());
-		}
-
-        if (renderer) {
-            itemBase->setSharedRendererEx(renderer);
-        }
+		setupImage(plural, viewID);
 	}
 }
 
@@ -227,3 +188,55 @@ void SvgIconWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
 	QGraphicsWidget::paint(painter, option, widget);
 }
 
+void SvgIconWidget::setItemBase(ItemBase * itemBase, bool plural)
+{
+	m_itemBase = itemBase;
+	setupImage(plural, itemBase->viewID());
+}
+
+void SvgIconWidget::setupImage(bool plural, ViewLayer::ViewID viewID)
+{
+	LayerAttributes layerAttributes;
+    layerAttributes.viewID = viewID;
+    layerAttributes.viewLayerID = ViewLayer::Icon;
+    layerAttributes.viewLayerPlacement = ViewLayer::NewTop;
+    layerAttributes.createShape = layerAttributes.doConnectors = false;
+	ModelPart * modelPart = m_itemBase->modelPart();
+	FSvgRenderer * renderer = m_itemBase->setUpImage(modelPart, layerAttributes);
+    if (renderer == NULL) {
+        DebugDialog::debug(QString("missing renderer for icon %1").arg(modelPart->moduleID()));
+    }
+	if (renderer && m_itemBase) {
+		m_itemBase->setFilename(renderer->filename());
+	}
+
+	QPixmap pixmap(plural ? *PluralImage : *SingularImage);
+	QPixmap * icon = (renderer == NULL) ? NULL : FSvgRenderer::getPixmap(renderer, QSize(ICON_SIZE, ICON_SIZE));
+	if (icon) {
+		QPainter painter;
+		painter.begin(&pixmap);
+		if (plural) {
+			painter.drawPixmap(PLURAL_OFFSET, PLURAL_OFFSET, *icon);
+		}
+		else {
+			painter.drawPixmap(SINGULAR_OFFSET, SINGULAR_OFFSET, *icon);
+		}
+		painter.end();
+		delete icon;
+	}
+
+	m_pixmapItem = new SvgIconPixmapItem(pixmap, this);
+	m_pixmapItem->setPlural(plural);
+
+	m_pixmapItem->setFlags(0);
+	m_pixmapItem->setPos(0, 0);
+
+	if (m_itemBase) {
+		m_itemBase->setTooltip();
+		setToolTip(m_itemBase->toolTip());
+	}
+
+    if (renderer) {
+        m_itemBase->setSharedRendererEx(renderer);
+    }
+}
