@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,12 +18,25 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
+/////////////////////////////////////////////
+//
+// TODO
+//
+//  integrate menus
+//  integrate dirty
+//  remove old program window
+//  enable all buttons, and give error messages (i.e. where is IDE)
+//  why is locate a menu button (puts programmers on a list)
+//  locate needs to say what it is locating
+//  move all tabs up?
+
+
 #include "programwindow.h"
 #include "highlighter.h"
 #include "syntaxer.h"
@@ -156,25 +169,26 @@ void ProgramWindow::initLanguages() {
 	nameFilters << "*.xml";
 	QFileInfoList list = dir.entryInfoList(nameFilters, QDir::Files | QDir::NoSymLinks);
 	foreach (QFileInfo fileInfo, list) {
-		if (fileInfo.baseName().compare("styles") == 0) {
+		if (fileInfo.completeBaseName().compare("styles") == 0) {
 			Highlighter::loadStyles(fileInfo.absoluteFilePath());
 		}
 		else {
 			QString name = Syntaxer::parseForName(fileInfo.absoluteFilePath());
-			if (!name.isEmpty()) {		// Arduino is not really available      && !name.contains("arduino", Qt::CaseInsensitive)
+			if (!name.isEmpty() /* && !name.contains("arduino", Qt::CaseInsensitive) */) {		// Arduino is not really available      
 				m_languages.insert(name, fileInfo.absoluteFilePath());
 			}
 		}
 	}
 }
 
-void ProgramWindow::setup(const QList<LinkedFile *> & linkedFiles, const QString & alternativePath)
+void ProgramWindow::setup()
 {
+    if (parentWidget() == NULL) {
+        resize(500,700);
+        setAttribute(Qt::WA_DeleteOnClose, true);
+    }
 
-    resize(500,700);
-
-    setAttribute(Qt::WA_DeleteOnClose, true);
-    QFrame * mainFrame = new QFrame(this);
+    QFrame * mainFrame =  new QFrame(this);
 
 	QFrame * headerFrame = createHeader();
 	QFrame * centerFrame = createCenter();
@@ -203,114 +217,119 @@ void ProgramWindow::setup(const QList<LinkedFile *> & linkedFiles, const QString
 	installEventFilter(this);
 
     // Setup new menu bar for the programming window
-    QMenuBar *menubar = menuBar();
+    QMenuBar * menubar = NULL;
+    if (parentWidget()) {
+        QMainWindow * mainWindow = qobject_cast<QMainWindow *>(parentWidget());
+        if (mainWindow) menubar = mainWindow->menuBar();
+    }
+    if (menubar == NULL) menubar = menuBar();
 
-    QMenu *currentMenu = menubar->addMenu(tr("&File"));
+    m_fileMenu = menubar->addMenu(tr("&File"));
 
-    QAction *currentAction = new QAction(tr("New"), this);
+    QAction *currentAction = new QAction(tr("New Code File"), this);
     currentAction->setShortcut(tr("Ctrl+N"));
     currentAction->setStatusTip(tr("Create a new program"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(addTab()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
-    currentAction = new QAction(tr("&Open..."), this);
+    currentAction = new QAction(tr("&Open Code File..."), this);
     currentAction->setShortcut(tr("Ctrl+O"));
     currentAction->setStatusTip(tr("Open a program"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(loadProgramFile()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
-    currentMenu->addSeparator();
+    m_fileMenu->addSeparator();
 
-    m_saveAction = new QAction(tr("&Save"), this);
+    m_saveAction = new QAction(tr("&Save Code File"), this);
     m_saveAction->setShortcut(tr("Ctrl+S"));
     m_saveAction->setStatusTip(tr("Save the current program"));
     connect(m_saveAction, SIGNAL(triggered()), this, SLOT(save()));
-    currentMenu->addAction(m_saveAction);
+    m_fileMenu->addAction(m_saveAction);
 
-    currentAction = new QAction(tr("Rename"), this);
+    currentAction = new QAction(tr("Rename Code File"), this);
     currentAction->setStatusTip(tr("Rename the current program"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(rename()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
     currentAction = new QAction(tr("Duplicate tab"), this);
     currentAction->setStatusTip(tr("Copies the current program into a new tab"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(duplicateTab()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
-    currentMenu->addSeparator();
+    m_fileMenu->addSeparator();
 
     currentAction = new QAction(tr("Remove tab"), this);
     currentAction->setShortcut(tr("Ctrl+W"));
     currentAction->setStatusTip(tr("Remove the current program from the sketch"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(closeCurrentTab()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
-    currentMenu->addSeparator();
+    m_fileMenu->addSeparator();
 
     m_printAction = new QAction(tr("&Print..."), this);
     m_printAction->setShortcut(tr("Ctrl+P"));
     m_printAction->setStatusTip(tr("Print the current program"));
     connect(m_printAction, SIGNAL(triggered()), this, SLOT(print()));
-    currentMenu->addAction(m_printAction);
+    m_fileMenu->addAction(m_printAction);
 
-    currentMenu->addSeparator();
+    m_fileMenu->addSeparator();
 
     currentAction = new QAction(tr("&Quit"), this);
     currentAction->setShortcut(tr("Ctrl+Q"));
     currentAction->setStatusTip(tr("Quit the application"));
     currentAction->setMenuRole(QAction::QuitRole);
     connect(currentAction, SIGNAL(triggered()), qApp, SLOT(closeAllWindows2()));
-    currentMenu->addAction(currentAction);
+    m_fileMenu->addAction(currentAction);
 
-    currentMenu = menubar->addMenu(tr("&Edit"));
+    m_editMenu = menubar->addMenu(tr("&Edit"));
 
     m_undoAction = new QAction(tr("Undo"), this);
     m_undoAction->setShortcuts(QKeySequence::Undo);
     m_undoAction->setEnabled(false);
     connect(m_undoAction, SIGNAL(triggered()), this, SLOT(undo()));
-    currentMenu->addAction(m_undoAction);
+    m_editMenu->addAction(m_undoAction);
 
     m_redoAction = new QAction(tr("Redo"), this);
     m_redoAction->setShortcuts(QKeySequence::Redo);
     m_redoAction->setEnabled(false);
     connect(m_redoAction, SIGNAL(triggered()), this, SLOT(redo()));
-    currentMenu->addAction(m_redoAction);
+    m_editMenu->addAction(m_redoAction);
 
-    currentMenu->addSeparator();
+    m_editMenu->addSeparator();
 
     m_cutAction = new QAction(tr("&Cut"), this);
     m_cutAction->setShortcut(tr("Ctrl+X"));
     m_cutAction->setStatusTip(tr("Cut selection"));
     m_cutAction->setEnabled(false);
     connect(m_cutAction, SIGNAL(triggered()), this, SLOT(cut()));
-    currentMenu->addAction(m_cutAction);
+    m_editMenu->addAction(m_cutAction);
 
     m_copyAction = new QAction(tr("&Copy"), this);
     m_copyAction->setShortcut(tr("Ctrl+C"));
     m_copyAction->setStatusTip(tr("Copy selection"));
     m_copyAction->setEnabled(false);
     connect(m_copyAction, SIGNAL(triggered()), this, SLOT(copy()));
-    currentMenu->addAction(m_copyAction);
+    m_editMenu->addAction(m_copyAction);
 
     currentAction = new QAction(tr("&Paste"), this);
     currentAction->setShortcut(tr("Ctrl+V"));
     currentAction->setStatusTip(tr("Paste clipboard contents"));
     // TODO: Check clipboard status and disable appropriately here
     connect(currentAction, SIGNAL(triggered()), this, SLOT(paste()));
-    currentMenu->addAction(currentAction);
+    m_editMenu->addAction(currentAction);
 
-    currentMenu->addSeparator();
+    m_editMenu->addSeparator();
 
     currentAction = new QAction(tr("&Select All"), this);
     currentAction->setShortcut(tr("Ctrl+A"));
     currentAction->setStatusTip(tr("Select all text"));
     connect(currentAction, SIGNAL(triggered()), this, SLOT(selectAll()));
-    currentMenu->addAction(currentAction);
+    m_editMenu->addAction(currentAction);
 
-    currentMenu = menuBar()->addMenu(tr("&Program"));
+    m_programMenu = menubar->addMenu(tr("&Code"));
 
     QMenu *languageMenu = new QMenu(tr("Select language"), this);
-    currentMenu->addMenu(languageMenu);
+    m_programMenu->addMenu(languageMenu);
 
 	QString currentLanguage = settings.value("programwindow/language", "").toString();
 	QStringList languages = getAvailableLanguages();
@@ -331,7 +350,7 @@ void ProgramWindow::setup(const QList<LinkedFile *> & linkedFiles, const QString
     connect(languageMenu, SIGNAL(triggered(QAction*)), this, SLOT(setLanguage(QAction*)));
 
     m_serialPortMenu = new QMenu(tr("Select port"), this);
-    currentMenu->addMenu(m_serialPortMenu);
+    m_programMenu->addMenu(m_serialPortMenu);
 
     m_serialPortActionGroup = new QActionGroup(this);
 	updateSerialPorts();
@@ -340,7 +359,7 @@ void ProgramWindow::setup(const QList<LinkedFile *> & linkedFiles, const QString
 	connect(m_serialPortMenu, SIGNAL(aboutToShow()), this, SLOT(updateSerialPorts()), Qt::DirectConnection);
 
 	m_programmerMenu = new QMenu(tr("Select programmer"), this);
-    currentMenu->addMenu(m_programmerMenu);
+    m_programMenu->addMenu(m_programmerMenu);
 
 	m_programmerActionGroup = new QActionGroup(this);
 	QHash<QString, QString> programmerNames = getProgrammerNames();
@@ -350,46 +369,50 @@ void ProgramWindow::setup(const QList<LinkedFile *> & linkedFiles, const QString
 	
     connect(m_programmerMenu, SIGNAL(triggered(QAction*)), this, SLOT(setProgrammer(QAction*)));
 
-    currentMenu->addSeparator();
+    m_programMenu->addSeparator();
 
     m_programAction = new QAction(tr("Program"), this);
     m_programAction->setStatusTip(tr("Load the current program onto a microcontroller"));
     m_programAction->setEnabled(false);
     connect(m_programAction, SIGNAL(triggered()), this, SLOT(sendProgram()));
-    currentMenu->addAction(m_programAction);
+    m_programMenu->addAction(m_programAction);
 
-    if (!linkedFiles.isEmpty()) {
-        bool firstTime = true;
-        foreach (LinkedFile * linkedFile, linkedFiles) {
-            ProgramTab * programTab = NULL;
-            if (firstTime) {
-                firstTime = false;
-                programTab = indexWidget(0);
-            }
-            else {
-                programTab = addTab();
-            }
-            QDir dir(alternativePath);
-            QFileInfo fileInfo(linkedFile->linkedFilename);
-            programTab->loadProgramFile(linkedFile->linkedFilename, dir.absoluteFilePath(fileInfo.fileName()), false);
-			if ((linkedFile->fileFlags & LinkedFile::InBundleFlag) && ((linkedFile->fileFlags & LinkedFile::ReadOnlyFlag) == 0)) { 
-				if (linkedFile->fileFlags & LinkedFile::SameMachineFlag) {
-					programTab->appendToConsole(tr("File '%1' was restored from the .fzz file; the local copy was not found.").arg(fileInfo.fileName()));
-				}
-				else {
-					programTab->appendToConsole(tr("File '%1' was restored from the .fzz file; save a local copy to work with an external editor.").arg(fileInfo.fileName()));
-				}
-			}
-			if (!m_languages.value(linkedFile->language, "").isEmpty()) {
-				programTab->setLanguage(linkedFile->language, false);
+    m_viewMenu = menubar->addMenu(tr("&View"));
+}
+
+void ProgramWindow::linkFiles(const QList<LinkedFile *> & linkedFiles, const QString & alternativePath) {
+    if (linkedFiles.isEmpty()) return;
+
+    bool firstTime = true;
+    foreach (LinkedFile * linkedFile, linkedFiles) {
+        ProgramTab * programTab = NULL;
+        if (firstTime) {
+            firstTime = false;
+            programTab = indexWidget(0);
+        }
+        else {
+            programTab = addTab();
+        }
+        QDir dir(alternativePath);
+        QFileInfo fileInfo(linkedFile->linkedFilename);
+        programTab->loadProgramFile(linkedFile->linkedFilename, dir.absoluteFilePath(fileInfo.fileName()), false);
+		if ((linkedFile->fileFlags & LinkedFile::InBundleFlag) && ((linkedFile->fileFlags & LinkedFile::ReadOnlyFlag) == 0)) { 
+			if (linkedFile->fileFlags & LinkedFile::SameMachineFlag) {
+				programTab->appendToConsole(tr("File '%1' was restored from the .fzz file; the local copy was not found.").arg(fileInfo.fileName()));
 			}
 			else {
-				linkedFile->language.clear();
+				programTab->appendToConsole(tr("File '%1' was restored from the .fzz file; save a local copy to work with an external editor.").arg(fileInfo.fileName()));
 			}
-			if (programTab->setProgrammer(linkedFile->programmer)) {
-				linkedFile->programmer.clear();
-			}
-        }
+		}
+		if (!m_languages.value(linkedFile->language, "").isEmpty()) {
+			programTab->setLanguage(linkedFile->language, false);
+		}
+		else {
+			linkedFile->language.clear();
+		}
+		if (programTab->setProgrammer(linkedFile->programmer)) {
+			linkedFile->programmer.clear();
+		}
     }
 }
 
@@ -397,6 +420,7 @@ QFrame * ProgramWindow::createHeader() {
 	QFrame * headerFrame = new QFrame();
 	headerFrame->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Fixed));
 	headerFrame->setObjectName("header");
+
 	return headerFrame;
 }
 
@@ -465,7 +489,8 @@ bool ProgramWindow::eventFilter(QObject * object, QEvent * event) {
  * Reimplement closeEvent to save any modified documents before closing.
  */
 void ProgramWindow::closeEvent(QCloseEvent *event) {
-	if(beforeClosing()) {
+	bool discard;
+	if(beforeClosing(true, discard)) {
 		cleanUp();
 		QMainWindow::closeEvent(event);
 		emit closed();
@@ -509,11 +534,11 @@ int & ProgramWindow::untitledFileCount() {
 }
 
 void ProgramWindow::setTitle() {
-    setWindowTitle(tr("Programming Window"));
+    setWindowTitle(tr("Code Window"));
 }
 
 void ProgramWindow::setTitle(const QString & filename) {
-        setWindowTitle(tr("Programming Window - %1").arg(filename));
+        setWindowTitle(tr("Code Window - %1").arg(filename));
 }
 
 /**
@@ -626,7 +651,8 @@ void ProgramWindow::setProgrammer(QAction* action) {
     currentWidget()->chooseProgrammer(action->data().toString());
 }
 
-bool ProgramWindow::beforeClosing(bool showCancel) {
+bool ProgramWindow::beforeClosing(bool showCancel, bool & discard) {
+	discard = false;
 	for (int i = 0; i < m_tabWidget->count(); i++) {
 		if (!beforeClosingTab(i, showCancel)) {
 			return false;
@@ -938,7 +964,7 @@ const QHash<QString, QString> ProgramWindow::getProgrammerNames()
 
 void ProgramWindow::initProgrammerNames()
 {
-	ProgrammerNames.insert(tr("Locate..."), LocateName);
+	ProgrammerNames.insert(tr("Find file..."), LocateName);
 
 	// TODO: eventually save a list of programmer names (a la recent files)
 
@@ -964,6 +990,7 @@ QAction * ProgramWindow::addProgrammer(const QString & name, const QString & pat
 }
 
 void ProgramWindow::loadProgramFile() {
+    DebugDialog::debug("loading program file");
 	currentWidget()->loadProgramFile();
 	
 }
@@ -1018,6 +1045,7 @@ ProgramTab * ProgramWindow::indexWidget(int index) {
 }
 
 bool ProgramWindow::alreadyHasProgram(const QString & filename) {
+    DebugDialog::debug("already has program");
 	for (int i = 0; i < m_tabWidget->count(); i++) {
 		ProgramTab * tab = indexWidget(i);
 		if (tab->filename() == filename) {
@@ -1082,6 +1110,7 @@ void ProgramWindow::updateSerialPorts() {
 
 void ProgramWindow::updateLink(const QString & filename, const QString & language, const QString & programmer, bool addlink, bool strong)
 {
+    DebugDialog::debug("updating link");
 	emit linkToProgramFile(filename, language, programmer, addlink, strong);
 }
 
@@ -1115,3 +1144,16 @@ void ProgramWindow::portProcessReadyRead() {
     }
 }
 
+void ProgramWindow::showMenus(bool show) {
+    if (m_fileMenu) m_fileMenu->menuAction()->setVisible(show);
+    if (m_editMenu) m_editMenu->menuAction()->setVisible(show);
+    if (m_programMenu) m_programMenu->menuAction()->setVisible(show);
+    if (m_viewMenu) m_viewMenu->menuAction()->setVisible(show);
+}
+
+void ProgramWindow::initViewMenu(QList<QAction *> & actions) {
+    foreach (QAction * action, actions) {
+        m_viewMenu->addAction(action);
+    }
+}
+
