@@ -122,14 +122,6 @@ void SchematicSketchWidget::ensureTraceLayerVisible() {
 	ensureLayerVisible(ViewLayer::SchematicTrace);
 }
 
-double SchematicSketchWidget::getRatsnestOpacity() {
-	return 0.7;
-}
-
-double SchematicSketchWidget::getRatsnestWidth() {
-	return 0.7;
-}
-
 void SchematicSketchWidget::setClipEnds(ClipableWire * vw, bool) {
 	vw->setClipEnds(false);
 }
@@ -226,13 +218,11 @@ void SchematicSketchWidget::updateBigDots()
 		//DebugDialog::debug(QString("update big dot %1 %2").arg(traceWire->id()).arg(connectorItem->connectorSharedID()));
 
 		connectorItems.append(connectorItem);
-		connectorItem->setMarked(false);
 	}
 
+    QList<ConnectorItem *> visited;
 	foreach (ConnectorItem * connectorItem, connectorItems) {
-		if (!connectorItem->marked()) {
-			connectorItem->restoreColor(false, 0, false);
-		}
+	    connectorItem->restoreColor(visited);
 	}
 }
 
@@ -366,10 +356,6 @@ bool SchematicSketchWidget::routeBothSides() {
 	return false;
 }
 
-QPoint SchematicSketchWidget::calcFixedToCenterItemOffset(const QRect & viewPortRect, const QSizeF & helpSize) {
-	return SketchWidget::calcFixedToCenterItemOffset(viewPortRect, helpSize);
-}
-
 void SchematicSketchWidget::addDefaultParts() {
 	SketchWidget::addDefaultParts();
 }
