@@ -35,6 +35,7 @@ $Date: 2013-04-28 14:14:07 +0200 (So, 28. Apr 2013) $
 #include <QGraphicsEllipseItem>
 #include <QSet>
 #include <QHash>
+#include <QMap>
 #include <QTimer>
 
 #include "../items/paletteitem.h"
@@ -74,6 +75,7 @@ struct SwapThing {
     QHash<ConnectorItem *, ConnectorItem *> toConnectorItems;
     QHash<ConnectorItem *, Connector *> swappedGender;
     SketchWidget * bbView;
+    QMap<QString, QString> propsMap;
 };
 
 struct RenderThing {
@@ -102,6 +104,9 @@ public:
 class SketchWidget : public InfoGraphicsView
 {
 	Q_OBJECT
+    Q_PROPERTY(QColor gridColor READ gridColor WRITE setGridColor DESIGNABLE true)
+    Q_PROPERTY(double ratsnestWidth READ ratsnestWidth WRITE setRatsnestWidth DESIGNABLE true)
+    Q_PROPERTY(double ratsnestOpacity READ ratsnestOpacity WRITE setRatsnestOpacity DESIGNABLE true)
 
 public:
     SketchWidget(ViewLayer::ViewID, QWidget *parent=0, int size=400, int minSize=300);
@@ -125,6 +130,7 @@ public:
     void selectItem(ItemBase * itemBase);
     void selectItems(QList<ItemBase *>);
     void selectItemsWithModuleID(ModelPart *);
+    void addToSketch(QList<ModelPart *> &);
     void selectDeselectAllCommand(bool state);
     void changeWire(long fromID, QLineF line, QPointF pos, bool updateConnections, bool updateRatsnest);   
     void changeLeg(long fromID, const QString & connectorID, const QPolygonF &, bool relative, const QString & why);   
@@ -254,7 +260,7 @@ public:
 	virtual ViewLayer::ViewLayerID getWireViewLayerID(const ViewGeometry & viewGeometry, ViewLayer::ViewLayerPlacement);
 	ItemBase * findItem(long id);
 	long createWire(ConnectorItem * from, ConnectorItem * to, ViewGeometry::WireFlags, bool dontUpdate, BaseCommand::CrossViewType, QUndoCommand * parentCommand);
-	int selectAllObsolete();
+	QList<ItemBase *> selectAllObsolete();
 	int selectAllMoveLock();
 	void setMoveLock(long id, bool lock);
 	bool partLabelsVisible();
@@ -276,7 +282,6 @@ public:
 	virtual double defaultGridSizeInches();
 	void clearPasteOffset();
 	virtual ViewLayer::ViewLayerPlacement defaultViewLayerPlacement(ModelPart *);
-	void addFixedToCenterItem2(class SketchMainHelp *item);
 	void collectAllNets(QHash<class ConnectorItem *, int> & indexer, QList< QList<class ConnectorItem *>* > & allPartConnectorItems, bool includeSingletons, bool bothSides);
 	virtual bool routeBothSides();
 	virtual void changeLayer(long id, double z, ViewLayer::ViewLayerID viewLayerID);
@@ -289,7 +294,7 @@ public:
 	void copyHeart(QList<ItemBase *> & bases, bool saveBoundingRects, QByteArray & itemData, QList<long> & modelIndexes);
 	void pasteHeart(QByteArray & itemData, bool seekOutsideConnections);
 	ViewGeometry::WireFlag getTraceFlag();
-	void changeBus(ItemBase *, bool connec, const QString & oldBus, const QString & newBus, QList<ConnectorItem *> &, const QString & message);
+	void changeBus(ItemBase *, bool connec, const QString & oldBus, const QString & newBus, QList<ConnectorItem *> &, const QString & message, const QString & oldLayout, const QString & newLayout);
 	const QString & filenameIf();
 	void setItemDropOffset(long id, QPointF offset);
 	void prepLegBendpointMove(ConnectorItem * from, int index, QPointF oldPos, QPointF newPos, ConnectorItem * to, bool changeConnections);
@@ -310,8 +315,10 @@ public:
 	void renamePins(long itemID, const QStringList & labels, bool singleRow);
 	void getRatsnestColor(QColor &);
 	VirtualWire * makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor color, bool force);
-	virtual double getRatsnestOpacity();
-	virtual double getRatsnestWidth();
+	double ratsnestOpacity();
+    void setRatsnestOpacity(double);
+	double ratsnestWidth();
+    void setRatsnestWidth(double);
 	void setAnyInRotation();
 	ConnectorItem * findConnectorItem(ConnectorItem * foreignConnectorItem);
 	void setGroundFillSeed(long id, const QString & connectorID, bool seed);
@@ -330,6 +337,10 @@ public:
     void hidePartLayer(long id, ViewLayer::ViewLayerID, bool hide);
     void hidePartLayer(ItemBase *, ViewLayer::ViewLayerID, bool hide);
     void moveItem(ItemBase *, double x, double y);
+    QColor gridColor() const;
+    void setGridColor(QColor);
+    bool everZoomed() const;
+    void setEverZoomed(bool);
 
 protected:
     void dragEnterEvent(QDragEnterEvent *);
@@ -456,8 +467,8 @@ protected:
 	QString makeWireSVGAux(Wire * wire, double width, const QString & color, QPointF offset, double dpi, double printerScale, bool blackOnly, bool dashed);
 
 	QString makeMoveSVG(double printerScale, double dpi, QPointF & offset); 
-	void prepDeleteProps(ItemBase * itemBase, long id, const QString & newModuleID, QUndoCommand * parentCommand);
-	void prepDeleteOtherProps(ItemBase * itemBase, long id, const QString & newModuleID, QUndoCommand * parentCommand);
+	void prepDeleteProps(ItemBase * itemBase, long id, const QString & newModuleID, QMap<QString, QString> & propsMap, QUndoCommand * parentCommand);
+	void prepDeleteOtherProps(ItemBase * itemBase, long id, const QString & newModuleID, QMap<QString, QString> & propsMap, QUndoCommand * parentCommand);
 	virtual ViewLayer::ViewLayerPlacement getViewLayerPlacement(ModelPart *, QDomElement & instance, QDomElement & view, ViewGeometry &);
 	virtual ViewLayer::ViewLayerPlacement wireViewLayerPlacement(ConnectorItem *);
 
@@ -467,7 +478,6 @@ protected:
 	bool resizingBoardRelease();
 	void resizeBoard();
     void resizeWithHandle(ItemBase * itemBase, double mmW, double mmH);
-	virtual QPoint calcFixedToCenterItemOffset(const QRect & viewPortRect, const QSizeF & helpSize);
 	virtual bool acceptsTrace(const ViewGeometry &);
 	virtual ItemBase * placePartDroppedInOtherView(ModelPart *, ViewLayer::ViewLayerPlacement, const ViewGeometry & viewGeometry, long id, SketchWidget * dropOrigin);
 	void showPartLabelsAux(bool show, QList<ItemBase *> & itemBases);
@@ -506,6 +516,7 @@ protected:
     QList<ItemBase *> collectSuperSubs(ItemBase *);
     void squashShapes(QPointF scenePos);
     void unsquashShapes();
+    virtual bool updateOK(ConnectorItem *, ConnectorItem *);
 
 protected:
 	static bool lessThan(int a, int b);
@@ -541,7 +552,6 @@ signals:
 	void showLabelFirstTimeSignal(long itemID, bool show, bool doEmit);
 	void dropPasteSignal(SketchWidget *);
 	void changeBoardLayersSignal(int, bool doEmit);
-	void firstTimeHelpHidden();
 	void deleteTracesSignal(QSet<ItemBase *> & deletedItems, QHash<ItemBase *, SketchWidget *> & otherDeletedItems, QList<long> & deletedIDs, bool isForeign, QUndoCommand * parentCommand);
 	void makeDeleteItemCommandPrepSignal(ItemBase * itemBase, bool foreign, QUndoCommand * parentCommand);
 	void makeDeleteItemCommandFinalSignal(ItemBase * itemBase, bool foreign, QUndoCommand * parentCommand);
@@ -561,6 +571,7 @@ signals:
     void cleanupRatsnestsSignal(bool doEmit);
     void addSubpartSignal(long id, long subpartID, bool doEmit);
     void getDroppedItemViewLayerPlacementSignal(ModelPart * modelPart, ViewLayer::ViewLayerPlacement &);
+    void packItemsSignal(int columns, const QList<long> & ids, QUndoCommand *parent, bool doEmit);
 
 protected slots:
 	void itemAddedSlot(ModelPart *, ItemBase *, ViewLayer::ViewLayerPlacement, const ViewGeometry &, long id, SketchWidget * dropOrigin);
@@ -576,7 +587,6 @@ protected slots:
 	void wireConnectedSlot(long fromID, QString fromConnectorID, long toID, QString toConnectorID);
 	void wireDisconnectedSlot(long fromID, QString fromConnectorID);
 	void changeConnectionSlot(long fromID, QString fromConnectorID, long toID, QString toConnectorID, ViewLayer::ViewLayerPlacement, bool connect, bool updateConnections);
-	void navigatorScrollChange(double x, double y);
 	void restartPasteCount();
 	void dragIsDoneSlot(class ItemDrag *);
 	void statusMessage(QString message, int timeout = 0);
@@ -629,6 +639,7 @@ public slots:
 	void ratsnestConnect(long id, const QString & connectorID, bool connect, bool doEmit);
     void cleanupRatsnests(bool doEmit);
     void addSubpart(long id, long subpartid, bool doEmit);
+    void packItems(int columns, const QList<long> & ids, QUndoCommand *parent, bool doEmit);
 
 protected:
 	enum StatusConnectStatus {
@@ -687,9 +698,6 @@ protected:
 	int m_ignoreSelectionChangeEvents;
 	bool m_current;
 
-	class SketchMainHelp * m_fixedToCenterItem;
-	QPoint m_fixedToCenterItemOffset;
-
 	QString m_lastColorSelected;
 
 	ConnectorPairHash m_moveDisconnectedFromFemale;
@@ -743,6 +751,10 @@ protected:
     bool m_pasting;
 	QPointer<class ResizableBoard> m_resizingBoard;
     QList< QPointer<ItemBase> > m_squashShapes;
+    QColor m_gridColor;
+    bool m_everZoomed;
+    double m_ratsnestOpacity;
+    double m_ratsnestWidth;
 
 public:
 	static ViewLayer::ViewLayerID defaultConnectorLayer(ViewLayer::ViewID viewId);
