@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6976 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-21 09:50:09 +0200 (So, 21. Apr 2013) $
 
 ********************************************************************/
 
@@ -33,6 +33,8 @@ $Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
 #include "../utils/zoomslider.h"
 #include "../utils/misc.h"
 
+const int ZoomableGraphicsView::MaxScaleValue = 3000;
+
 
 ZoomableGraphicsView::WheelMapping ZoomableGraphicsView::m_wheelMapping =
 #ifdef Q_WS_WIN
@@ -46,8 +48,9 @@ bool FirstTime = true;
 ZoomableGraphicsView::ZoomableGraphicsView( QWidget * parent )
 	: QGraphicsView(parent)
 {
+    m_viewFromBelow = false;
 	m_scaleValue = 100;
-	m_maxScaleValue = 2000;
+	m_maxScaleValue = MaxScaleValue;
 	m_minScaleValue = 1;
 	m_acceptWheelEvents = true;
 	if (FirstTime) {
@@ -66,6 +69,10 @@ void ZoomableGraphicsView::wheelEvent(QWheelEvent* event) {
 		QGraphicsView::wheelEvent(event);
 		return;
 	}
+    if ((event->modifiers() & Qt::ShiftModifier) != 0) {
+		QGraphicsView::wheelEvent(event);
+		return;
+    }
 
 	bool doZoom = false;
 	bool doHorizontal = false;
@@ -153,7 +160,9 @@ void ZoomableGraphicsView::relativeZoom(double step, bool centerOnCursor) {
 	//QPointF r = this->mapToScene(q);
 
 	QMatrix matrix;
-	matrix.scale(tempScaleValue, tempScaleValue);
+    double multiplier = 1;
+    if (m_viewFromBelow) multiplier = -1;
+	matrix.scale(multiplier * tempScaleValue, tempScaleValue);
 	if (centerOnCursor) {
 		//this->setMatrix(QMatrix().translate(-r.x(), -r.y()) * matrix * QMatrix().translate(r.x(), r.y()));
         this->setTransformationAnchor(QGraphicsView::AnchorUnderMouse);
@@ -186,3 +195,18 @@ ZoomableGraphicsView::WheelMapping ZoomableGraphicsView::wheelMapping() {
 	return m_wheelMapping;
 }
 
+bool ZoomableGraphicsView::viewFromBelow() {
+    return m_viewFromBelow;
+}
+
+void ZoomableGraphicsView::setViewFromBelow(bool viewFromBelow) {
+    if (m_viewFromBelow == viewFromBelow) return;
+
+    m_viewFromBelow = viewFromBelow;
+
+    this->setTransformationAnchor(QGraphicsView::AnchorViewCenter);
+    QTransform transform;
+    transform.scale(-1, 1);
+    this->setTransform(transform, true);
+}
+
