@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,18 +18,20 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5143 $:
-$Author: cohen@irascible.com $:
-$Date: 2011-07-01 02:37:01 +0200 (Fri, 01 Jul 2011) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
 #include "kicadschematic2svg.h"
 #include "../utils/textutils.h"
+#include "../utils/graphicsutils.h"
 #include "../version/version.h"
 #include "../debugdialog.h"
 #include "../viewlayer.h"
 #include "../fsvgrenderer.h"
+#include "../utils/misc.h"
 
 #include <QFile>
 #include <QTextStream>
@@ -199,7 +201,7 @@ QString KicadSchematic2Svg::convert(const QString & filename, const QString & de
 
 	contents += "</g>\n";
 
-	QString svg = TextUtils::makeSVGHeader(1000, 1000, m_maxX - m_minX, m_maxY - m_minY) 
+	QString svg = TextUtils::makeSVGHeader(GraphicsUtils::StandardFritzingDPI, GraphicsUtils::StandardFritzingDPI, m_maxX - m_minX, m_maxY - m_minY) 
 					+ m_title + m_description + metadata + offsetMin(contents) + "</svg>";
 
 	return svg;
@@ -258,9 +260,9 @@ QString KicadSchematic2Svg::convertField(const QString & xString, const QString
 	}
 
 	QFont font;
-	font.setFamily("OCRA");
+	font.setFamily(OCRAFontName);
 	font.setWeight(QFont::Normal);
-	font.setPointSizeF(72 * fontSize / 1000.0);
+	font.setPointSizeF(72.0 * fontSize / GraphicsUtils::StandardFritzingDPI);
 
 	QString style;
 	if (vjustify.contains("I")) {
@@ -285,13 +287,13 @@ QString KicadSchematic2Svg::convertField(const QString & xString, const QString
 		anchor = "end";
 	}
 
-	QFontMetrics metrics(font);
-	QRect bri = metrics.boundingRect(text);
+	QFontMetricsF metrics(font);
+	QRectF bri = metrics.boundingRect(text);
 
 	// convert back to 1000 dpi
 	QRectF brf(0, 0,
-			   bri.width() * 1000 / FSvgRenderer::printerScale(), 
-			   bri.height() * 1000 / FSvgRenderer::printerScale());
+			   bri.width() * GraphicsUtils::StandardFritzingDPI / GraphicsUtils::SVGDPI, 
+			   bri.height() * GraphicsUtils::StandardFritzingDPI / GraphicsUtils::SVGDPI);
 
 	if (anchor == "start") {
 		brf.translate(x, y - (brf.height() / 2));
@@ -312,14 +314,16 @@ QString KicadSchematic2Svg::convertField(const QString & xString, const QString
 	checkYLimit(brf.top());
 	checkYLimit(brf.bottom());
 
-	QString s = QString("<text x='%1' y='%2' font-size='%3' font-family='OCRA' stroke='none' fill='#000000' text-anchor='%4' %5 %6>%7</text>\n")
+	QString s = QString("<text x='%1' y='%2' font-size='%3' font-family='%8' stroke='none' fill='#000000' text-anchor='%4' %5 %6>%7</text>\n")
 					.arg(x)		
 					.arg(y + (fontSize / 3))		
 					.arg(fontSize)		
 					.arg(anchor)
 					.arg(style)
 					.arg(rotation)
-					.arg(TextUtils::escapeAnd(unquote(text)));		
+					.arg(TextUtils::escapeAnd(unquote(text)))
+                    .arg(OCRAFontName)
+                    ;		
 	if (notName) {
 		s += QString("<line fill='none' stroke='#000000' x1='%1' y1='%2' x2='%3' y2='%4' stroke-width='2' />\n")
 			.arg(brf.left())
@@ -560,13 +564,13 @@ QString KicadSchematic2Svg::convertArc(const QString & line)
 	int x = s[1].toInt();
 	int y = -s[2].toInt();					// KiCad flips y-axis w.r.t. svg
 	int r = s[3].toInt();
-	qreal startAngle = (s[4].toInt() % 3600) / 10.0;
-	qreal endAngle = (s[5].toInt() % 3600) / 10.0;
+	double startAngle = (s[4].toInt() % 3600) / 10.0;
+	double endAngle = (s[5].toInt() % 3600) / 10.0;
 
-	qreal x1 = s[10].toInt();
-	qreal y1 = -s[11].toInt();					// KiCad flips y-axis w.r.t. svg
-	qreal x2 = s[12].toInt();
-	qreal y2 = -s[13].toInt();					// KiCad flips y-axis w.r.t. svg
+	double x1 = s[10].toInt();
+	double y1 = -s[11].toInt();					// KiCad flips y-axis w.r.t. svg
+	double x2 = s[12].toInt();
+	double y2 = -s[13].toInt();					// KiCad flips y-axis w.r.t. svg
 
 	if (calcPoints) {
 		x1 = x + (r * cos(startAngle * M_PI / 180.0));
@@ -576,7 +580,7 @@ QString KicadSchematic2Svg::convertArc(const QString & line)
 	}
 
 	// kicad arcs will always sweep < 180, kicad uses multiple arcs for > 180 sweeps
-	qreal diffAngle = endAngle - startAngle;
+	double diffAngle = endAngle - startAngle;
 	if (diffAngle > 180) diffAngle -= 360;
 	else if (diffAngle < -180) diffAngle += 360;
 
