@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6181 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-18 15:52:11 +0200 (Wed, 18 Jul 2012) $
+$Revision: 6980 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -38,8 +38,6 @@ $Date: 2012-07-18 15:52:11 +0200 (Wed, 18 Jul 2012) $
 #include <QtDebug>
 #include <QXmlStreamReader>
 
-static QString findStyle("%1[\\s]*:[\\s]*([^;]*)[;]?");
-
 struct HVConvertData {
 	double x;
 	double y;
@@ -86,7 +84,7 @@ bool SvgFileSplitter::splitString(QString & contents, const QString & elementID)
 	contents.replace('\r', ' ');
 
 	// get rid of inkscape stuff too
-	contents.remove(TextUtils::SodipodiDetector);
+	TextUtils::cleanSodipodi(contents);
 
 	QString errorStr;
 	int errorLine;
@@ -191,13 +189,15 @@ QString SvgFileSplitter::elementString(const QString & elementID) {
 	return document.toString();
 }
 
-bool SvgFileSplitter::normalize(double dpi, const QString & elementID, bool blackOnly)
+bool SvgFileSplitter::normalize(double dpi, const QString & elementID, bool blackOnly, double & factor)
 {
 	// get the viewbox and the width and height
 	// then normalize them
 	// then normalize all the internal stuff
 	// if there are translations, we're probably ok
 
+    factor = 1;
+
 	QDomElement root = m_domDocument.documentElement();
 	if (root.isNull()) return false;
 
@@ -217,6 +217,8 @@ bool SvgFileSplitter::normalize(double dpi, const QString & elementID, bool blac
 
 	normalizeChild(mainElement, sWidth * dpi, sHeight * dpi, vbWidth, vbHeight, blackOnly);
 
+    factor = sWidth * dpi / vbWidth;
+
 	return true;
 }
 
@@ -226,7 +228,8 @@ QPainterPath SvgFileSplitter::painterPath(double dpi, const QString & elementID)
 
 	QPainterPath ppath;
 
-	bool result = normalize(dpi, elementID, false);
+    double factor;
+	bool result = normalize(dpi, elementID, false, factor);
 	if (!result) return ppath;
 
 	QDomElement root = m_domDocument.documentElement();
@@ -356,13 +359,14 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 	bool doChildren = false;
 	QString nodeName = element.nodeName();
 	if (nodeName.compare("g") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
+		normalizeAttribute(element, "font-size", sNewWidth, vbWidth);
 		setStrokeOrFill(element, blackOnly, "black", false);
 		doChildren = true;
 	}
 	else if (nodeName.compare("circle") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "cx", sNewWidth, vbWidth);
 		normalizeAttribute(element, "cy", sNewHeight, vbHeight);
 		normalizeAttribute(element, "r", sNewWidth, vbWidth);
@@ -370,7 +374,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("line") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "x1", sNewWidth, vbWidth);
 		normalizeAttribute(element, "y1", sNewHeight, vbHeight);
 		normalizeAttribute(element, "x2", sNewWidth, vbWidth);
@@ -379,7 +383,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("rect") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "width", sNewWidth, vbWidth);
 		normalizeAttribute(element, "height", sNewHeight, vbHeight);
 		normalizeAttribute(element, "x", sNewWidth, vbWidth);
@@ -396,7 +400,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("ellipse") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "cx", sNewWidth, vbWidth);
 		normalizeAttribute(element, "cy", sNewHeight, vbHeight);
 		normalizeAttribute(element, "rx", sNewWidth, vbWidth);
@@ -405,7 +409,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("polygon") == 0 || nodeName.compare("polyline") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
 		QString data = element.attribute("points");
 		if (!data.isEmpty()) {
@@ -424,7 +428,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("path") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
 		setStrokeOrFill(element, blackOnly, "black", false);
 		QString data = element.attribute("d").trimmed();
@@ -442,7 +446,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		}
 	}
 	else if (nodeName.compare("text") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "x", sNewWidth, vbWidth);
 		normalizeAttribute(element, "y", sNewHeight, vbHeight);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
@@ -487,9 +491,20 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 
 bool SvgFileSplitter::normalizeAttribute(QDomElement & element, const char * attributeName, double num, double denom)
 {
-	double n = element.attribute(attributeName).toDouble() * num / denom;
+    QString attributeValue = element.attribute(attributeName);
+    if (attributeValue.isEmpty()) return true;
+
+    bool ok;
+	double n = attributeValue.toDouble(&ok) * num / denom;
+    if (!ok) {
+        QString string;
+        QTextStream stream(&string);
+        element.save(stream, 0);
+        //DebugDialog::debug("bad attribute " + string);
+    }
+
 	element.setAttribute(attributeName, QString::number(n));
-	return true;
+	return ok;
 }
 
 QString SvgFileSplitter::shift(double x, double y, const QString & elementID, bool shiftTransforms)
@@ -1053,7 +1068,7 @@ void SvgFileSplitter::setStrokeOrFill(QDomElement & element, bool blackOnly, con
 }
 
 void SvgFileSplitter::fixStyleAttributeRecurse(QDomElement & element) {
-	fixStyleAttribute(element);
+	TextUtils::fixStyleAttribute(element);
 	QDomElement childElement = element.firstChildElement();
 	while (!childElement.isNull()) {
 		fixStyleAttributeRecurse(childElement);
@@ -1062,7 +1077,7 @@ void SvgFileSplitter::fixStyleAttributeRecurse(QDomElement & element) {
 }
 
 void SvgFileSplitter::fixColorRecurse(QDomElement & element, const QString & newColor, const QStringList & exceptions) {
-	fixStyleAttribute(element);
+	TextUtils::fixStyleAttribute(element);
 	bool gotException = false;
 	QString s = element.attribute("stroke");
 	QString f = element.attribute("fill");
@@ -1104,42 +1119,6 @@ void SvgFileSplitter::fixColorRecurse(QDomElement & element, const QString & new
 	}
 }
 
-void SvgFileSplitter::fixStyleAttribute(QDomElement & element)
-{
-	QString style = element.attribute("style");
-	if (style.isEmpty()) return;
-
-	fixStyleAttribute(element, style, "stroke-width");
-	fixStyleAttribute(element, style, "stroke");
-	fixStyleAttribute(element, style, "fill");
-	fixStyleAttribute(element, style, "fill-opacity");
-	fixStyleAttribute(element, style, "stroke-opacity");
-	fixStyleAttribute(element, style, "font-size");
-
-	if (style.trimmed().isEmpty()) {
-		element.removeAttribute("style");
-	}
-	else {
-		element.setAttribute("style", style);
-	}
-
-	//QString deleteMe;
-	//QTextStream stream(&deleteMe);
-	//stream << element;
-	//DebugDialog::debug(deleteMe);
-}
-
-void SvgFileSplitter::fixStyleAttribute(QDomElement & element, QString & style, const QString & attributeName)
-{
-	QString str = findStyle.arg(attributeName);
-	QRegExp sw(str);
-	if (sw.indexIn(style) >= 0) {
-		QString value = sw.cap(1);
-		style.remove(sw);
-		element.setAttribute(attributeName, value);
-	}
-}
-
 bool SvgFileSplitter::getSvgSizeAttributes(const QString & svg, QString & width, QString & height, QString & viewBox)
 {
 	QXmlStreamReader xml(svg);
@@ -1213,6 +1192,24 @@ void SvgFileSplitter::changeStrokeWidth(QDomElement & element, double delta, boo
 	}
 }
 
+void SvgFileSplitter::forceStrokeWidth(QDomElement & element, double delta, const QString & stroke, bool recurse, bool fill) {
+	bool ok;
+	double sw = element.attribute("stroke-width").toDouble(&ok);
+    if (!ok) sw = 0;
+
+	element.setAttribute("stroke-width", QString::number(qMax(0, sw + delta)));
+	element.setAttribute("stroke", stroke);
+    if (fill) element.setAttribute("fill", stroke);
+
+    if (recurse) {
+	    QDomElement child = element.firstChildElement();
+	    while (!child.isNull()) {
+		    forceStrokeWidth(child, delta, stroke, recurse, fill);
+		    child = child.nextSiblingElement();
+	    }
+    }
+}
+
 bool SvgFileSplitter::changeColors(const QString & svg, QString & toColor, QStringList & exceptions, QByteArray & byteArray) {
 	QString errorStr;
 	int errorLine;
@@ -1313,3 +1310,142 @@ void SvgFileSplitter::gReplace(const QString & id)
 
 	element.setTagName("g");
 }
+
+QByteArray SvgFileSplitter::hideText(const QString & filename) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+    QFile file(filename);
+	if (!doc.setContent(&file, true, &errorStr, &errorLine, &errorColumn)) {
+        return QByteArray();
+    }
+
+    QDomElement root = doc.documentElement();
+    hideTextAux(root, false);
+
+    return TextUtils::removeXMLEntities(doc.toString()).toUtf8();
+}
+
+QByteArray SvgFileSplitter::hideText2(const QByteArray & svg) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+	if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
+        return QByteArray();
+    }
+
+    QDomElement root = doc.documentElement();
+    hideTextAux(root, false);
+
+    return TextUtils::removeXMLEntities(doc.toString()).toUtf8();
+}
+
+QString SvgFileSplitter::hideText3(const QString & svg) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+	if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
+        return "";
+    }
+
+    QDomElement root = doc.documentElement();
+    hideTextAux(root, false);
+
+    return TextUtils::removeXMLEntities(doc.toString());
+}
+
+
+void SvgFileSplitter::hideTextAux(QDomElement & parent, bool hideChildren) {
+    if (hideChildren || parent.tagName() == "text") {
+        parent.setTagName("g");
+        hideChildren = true;
+    }
+
+    QDomElement child = parent.firstChildElement();
+    while (!child.isNull()) {
+        hideTextAux(child, hideChildren);
+        child = child.nextSiblingElement();
+    }
+}
+
+QByteArray SvgFileSplitter::showText(const QString & filename, bool & hasText) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+    QFile file(filename);
+	if (!doc.setContent(&file, true, &errorStr, &errorLine, &errorColumn)) {
+        return QByteArray();
+    }
+
+    QDomElement root = doc.documentElement();
+    showTextAux(root, hasText, true);
+    if (!hasText) {
+        return QByteArray();
+    }
+
+    return TextUtils::removeXMLEntities(doc.toString()).toUtf8();
+}
+
+QByteArray SvgFileSplitter::showText2(const QByteArray & svg, bool & hasText) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+	if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
+        return QByteArray();
+    }
+
+    QDomElement root = doc.documentElement();
+    showTextAux(root, hasText, true);
+    if (!hasText) {
+        return QByteArray();
+    }
+
+    return TextUtils::removeXMLEntities(doc.toString()).toUtf8();
+}
+
+QString SvgFileSplitter::showText3(const QString & svg, bool & hasText) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+    QDomDocument doc;
+
+	if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
+        return "";
+    }
+
+    QDomElement root = doc.documentElement();
+    showTextAux(root, hasText, true);
+    if (!hasText) {
+        return "";
+    }
+
+    return TextUtils::removeXMLEntities(doc.toString());
+}
+
+void SvgFileSplitter::showTextAux(QDomElement & parent, bool & hasText, bool root) {
+    if (parent.tagName() == "text") {
+        hasText = true;
+        return;
+    }
+
+    if (!root) {
+        parent.setTagName("g");
+    }
+
+    QDomElement child = parent.firstChildElement();
+    while (!child.isNull()) {
+        showTextAux(child, hasText, false);
+        child = child.nextSiblingElement();
+    }
+}
+
