@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6112 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Revision: 6980 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -59,7 +59,7 @@ public:
 	bool splitString(QString & contents, const QString & elementID);
 	const QByteArray & byteArray();
 	const QDomDocument & domDocument();
-	bool normalize(double dpi, const QString & elementID, bool blackOnly);
+	bool normalize(double dpi, const QString & elementID, bool blackOnly, double & factor);
 	QString shift(double x, double y, const QString & elementID, bool shiftTransforms);
 	QString elementString(const QString & elementID);
     virtual bool parsePath(const QString & data, const char * slot, PathUserData &, QObject * slotTarget, bool convertHV);
@@ -76,11 +76,18 @@ public:
 public:
 	static bool getSvgSizeAttributes(const QString & svg, QString & width, QString & height, QString & viewBox);
 	static bool changeStrokeWidth(const QString & svg, double delta, bool absolute, bool changeOpacity, QByteArray &);
+	static void changeStrokeWidth(QDomElement & element, double delta, bool absolute, bool changeOpacity);
+	static void forceStrokeWidth(QDomElement & element, double delta, const QString & stroke, bool recurse, bool fill);
 	static bool changeColors(const QString & svg, QString & toColor, QStringList & exceptions, QByteArray &);
 	static void changeColors(QDomElement & element, QString & toColor, QStringList & exceptions);
 	static void fixStyleAttributeRecurse(QDomElement & element);
 	static void fixColorRecurse(QDomElement & element, const QString & newColor, const QStringList & exceptions);
-	static void fixStyleAttribute(QDomElement & element, QString & style, const QString & attributeName);
+    static QByteArray hideText(const QString & filename);
+    static QByteArray showText(const QString & filename, bool & hasText);
+    static QByteArray hideText2(const QByteArray & svg);
+    static QByteArray showText2(const QByteArray & svg, bool & hasText);
+    static QString hideText3(const QString & svg);
+    static QString showText3(const QString & svg, bool & hasText);
 
 protected:
 	void normalizeChild(QDomElement & childElement, 
@@ -95,10 +102,10 @@ protected:
 	void standardArgs(bool relative, bool starting, QList<double> & args, PathUserData * pathUserData);
 
 protected:
-	static void changeStrokeWidth(QDomElement & element, double delta, bool absolute, bool changeOpacity);
-	static void fixStyleAttribute(QDomElement & element);
 	static bool shiftAttribute(QDomElement & element, const char * attributeName, double d);
 	static void setStrokeOrFill(QDomElement & element, bool doIt, const QString & color, bool force);
+    static void hideTextAux(QDomElement & parent, bool hideChildren);
+    static void showTextAux(QDomElement & parent, bool & hasText, bool root);
 
 protected slots:
 	void normalizeCommandSlot(QChar command, bool relative, QList<double> & args, void * userData);
