@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 4353 $:
-$Author: cohen@irascible.com $:
-$Date: 2010-07-12 10:57:33 +0200 (Mon, 12 Jul 2010) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
@@ -35,8 +35,8 @@ class X2Svg
 public:
 	X2Svg();
 
-	void checkXLimit(qreal x);
-	void checkYLimit(qreal y);
+	void checkXLimit(double x);
+	void checkYLimit(double y);
 
 protected:
 	QString offsetMin(const QString & svg);
@@ -44,10 +44,10 @@ protected:
 	QString unquote(const QString &);
 
 protected:
-	qreal m_maxX;
-	qreal m_maxY;
-	qreal m_minX;
-	qreal m_minY;
+	double m_maxX;
+	double m_maxY;
+	double m_minX;
+	double m_minY;
 	QString m_attribute;
 	QString m_comment;
 };
