@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6141 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-04 21:20:05 +0200 (Wed, 04 Jul 2012) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
@@ -75,6 +75,11 @@ FileProgressDialog::FileProgressDialog(QWidget *parent) : QDialog(parent)
 	init(QObject::tr("File Progress..."), 0);
 }
 
+
+FileProgressDialog::~FileProgressDialog() {
+    m_timer.stop();
+}
+
 void FileProgressDialog::init(const QString & title, int initialMaximum)
 {
 	Qt::WindowFlags flags = windowFlags();
@@ -107,9 +112,6 @@ void FileProgressDialog::init(const QString & title, int initialMaximum)
 	this->setLayout(vLayout);
 }
 
-FileProgressDialog::~FileProgressDialog() {
-}
-
 void FileProgressDialog::setMinimum(int minimum) {
 	m_progressBar->setMinimum(minimum);
 }
@@ -208,3 +210,17 @@ void FileProgressDialog::resizeEvent(QResizeEvent * event)
 void FileProgressDialog::setIncValueMod(int mod) {
     m_incValueMod = mod;
 }
+
+void FileProgressDialog::setIndeterminate() {
+    m_progressBar->setRange(0, 0);
+    m_timer.setSingleShot(false);
+    m_timer.setInterval(1000);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(updateIndeterminate()));
+    m_timer.start();
+}
+
+void FileProgressDialog::updateIndeterminate() {
+    if (m_progressBar) {
+        m_progressBar->setValue(0);
+    }
+}
