@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6141 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-07-04 21:20:05 +0200 (Wed, 04 Jul 2012) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
@@ -32,6 +32,7 @@ $Date: 2012-07-04 21:20:05 +0200 (Wed, 04 Jul 2012) $
 #include <QProgressBar>
 #include <QLabel>
 #include <QDomElement>
+#include <QTimer>
 
 class FileProgressDialog : public QDialog
 {
@@ -46,6 +47,7 @@ public:
 	void setBinLoadingCount(int);
 	void setBinLoadingChunk(int);
     void setIncValueMod(int);
+    void setIndeterminate();
 
 protected:
 	void closeEvent(QCloseEvent *);
@@ -64,6 +66,9 @@ public slots:
 	void loadingInstanceSlot(class ModelBase *, QDomElement & instance);
 	void settingItemSlot();
 
+protected slots:
+    void updateIndeterminate();
+
 
 signals:
 	void cancel();
@@ -82,6 +87,7 @@ protected:
     int m_incValueMod;
 	double m_binLoadingInc;
 	double m_binLoadingValue;
+    QTimer m_timer;
 };
 
 
