@@ -29,7 +29,6 @@ $Date: 2013-03-10 21:27:34 +0100 (So, 10. Mrz 2013) $
 #include <QList>
 #include <QLineF>
 #include <QBuffer>
-#include <QSvgRenderer>
 #include <qmath.h>
 #include <QtDebug>
 
@@ -38,6 +37,7 @@ const double GraphicsUtils::StandardFritzingDPI = 1000;
 const double GraphicsUtils::SVGDPI = 90;
 const double GraphicsUtils::InchesPerMeter = 39.370078;
 const double GraphicsUtils::StandardSchematicSeparationMils = 295.275591;   // 7.5mm
+const double GraphicsUtils::StandardSchematicSeparation10thinMils = 100;   // 0.1 inches
 
 
 void GraphicsUtils::distanceFromLine(double cx, double cy, double ax, double ay, double bx, double by, 
@@ -544,13 +544,3 @@ bool GraphicsUtils::isFlipped(const QMatrix & matrix, double & rotation) {
     return false;
 }
 
-void GraphicsUtils::renderOne(QDomDocument * masterDoc, QImage * image, const QRectF & renderRect) {
-    QByteArray byteArray = masterDoc->toByteArray();
-	QSvgRenderer renderer(byteArray);
-	QPainter painter;
-	painter.begin(image);
-	painter.setRenderHint(QPainter::Antialiasing, false);
-    painter.setRenderHint(QPainter::SmoothPixmapTransform, false);
-	renderer.render(&painter, renderRect);
-	painter.end();
-}
