@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6289 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-08-14 04:06:50 +0200 (Tue, 14 Aug 2012) $
+$Revision: 6904 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
@@ -63,7 +63,6 @@ $Date: 2012-08-14 04:06:50 +0200 (Tue, 14 Aug 2012) $
 #define ALLMOUSEBUTTONS (Qt::LeftButton | Qt::MidButton | Qt::RightButton | Qt::XButton1 | Qt::XButton2)
 
 typedef QPair<double, double> RealPair;
-typedef QPair<QString, QString> StringPair;
 
 static QString ___emptyString___;
 static QDomElement ___emptyElement___;
@@ -72,6 +71,10 @@ static QHash<QString, QString> ___emptyStringHash___;
 static QDir ___emptyDir___;
 static QByteArray ___emptyByteArray___;
 
+static const QString OCRAFontName("OCRA"); 
+
+static const QString ResourcePath(":/resources/");
+
 bool isParent(QObject * candidateParent, QObject * candidateChild);
 
 static const QString FritzingSketchExtension(".fz");
@@ -81,6 +84,22 @@ static const QString FritzingPartExtension(".fzp");
 static const QString FritzingBundledPartExtension(".fzpz");
 static const QString FritzingBundleExtension(".fzz");
 
+inline double qMin(float f, double d) {
+    return qMin((double) f, d);
+}
+
+inline double qMin(double d, float f) {
+    return qMin((double) f, d);
+}
+
+inline double qMax(float f, double d) {
+    return qMax((double) f, d);
+}
+
+inline double qMax(double d, float f) {
+    return qMax((double) f, d);
+}
+
 const QStringList & fritzingExtensions();
 
 static const QString FemaleSymbolString = QString("%1").arg(QChar(0x2640));
@@ -88,4 +107,12 @@ static const QString MaleSymbolString = QString("%1").arg(QChar(0x2642));
 
 Qt::KeyboardModifier altOrMetaModifier();
 
+static QRegExp IntegerFinder("\\d+");
+
+static const int PartsBinHeightDefault = 240;
+static const int InfoViewHeightDefault = 220;
+static const int InfoViewMinHeight = 50;
+static const int DockWidthDefault = 300;
+static const int DockHeightDefault = 50;
+
 #endif
