@@ -20,7 +20,7 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 																		
 $Revision: 6112 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Date: 2012-06-28 00:18:10 +0200 (Do, 28. Jun 2012) $
 		
 ********************************************************************/
 
@@ -97,7 +97,7 @@ void VersionChecker::finished(int id, bool error)
 
 void VersionChecker::parseXml()
 {
-	DebugDialog::debug("parsing xml");
+	//DebugDialog::debug("parsing xml");
     while (!m_xml.atEnd()) {
         m_xml.readNext();
         if (m_xml.isStartElement()) {
